;; -*- geiser-scheme-implementation: guile; mode: scheme; -*-
;;; GNU Guix --- Functional package management for GNU
;;; Copyright © 2020 Ekaitz Zarraga <ekaitz@elenq.tech>
;;; Copyright © 2020 Evan Hanson <evhan@foldling.org>
;;; Copyright © 2020 raingloom <raingloom@riseup.net>
;;; Copyright © 2024 Daniel Ziltener <dziltener@lyrion.ch>
;;;
;;; This file is part of GNU Guix.
;;;
;;; GNU Guix is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or (at
;;; your option) any later version.
;;;
;;; GNU Guix is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.

(define-module (zilti packages chicken)
  #:use-module (gnu packages)
  #:use-module (guix packages)
  #:use-module (zilti build-system chicken)
  #:use-module (guix build-system gnu)
  #:use-module (guix download)
  #:use-module (guix git-download)
  #:use-module (guix svn-download)
  #:use-module (gnu packages commencement)
  #:use-module (gnu packages chicken)
  #:use-module ((guix licenses)
                #:prefix license:))

(define-public chicken
  (package
    (name "chicken")
    (version "5.3.0")
    (source (origin
              (method url-fetch)
              (uri (string-append "https://code.call-cc.org/releases/"
                                  version "/chicken-" version ".tar.gz"))
              (sha256
               (base32
                "0xhdvcdwlv9vbhxh7k0fzd32ybhc7fn83y9fj48dhzp1z7c9kbf3"))))
    (build-system gnu-build-system)
    (arguments
     `(#:modules ((guix build gnu-build-system)
                  (guix build utils)
                  (srfi srfi-1))

       ;; No `configure' script; run "make check" after "make install" as
       ;; prescribed by README.
       #:phases
       (modify-phases %standard-phases
         (delete 'configure)
         (delete 'check)
         (add-after 'install 'check
           (assoc-ref %standard-phases 'check)))

       #:make-flags (let ((out (assoc-ref %outputs "out")))
                      (list "PLATFORM=linux"
                            (string-append "PREFIX=" out)
                            (string-append "VARDIR=" out "/var/lib")))

       ;; Parallel builds are not supported, as noted in README.
       #:parallel-build? #f))
    (native-search-paths
     (list (search-path-specification
            (variable "CHICKEN_REPOSITORY_PATH")
            ;; TODO extract binary version into a module level definition.
            (files (list "var/lib/chicken/11")))))
    (propagated-inputs (list gcc-toolchain))
    (home-page "https://www.call-cc.org/")
    (synopsis "R5RS Scheme implementation that compiles native code via C")
    (description
     "CHICKEN is a compiler for the Scheme programming language.  CHICKEN
produces portable and efficient C, supports almost all of the R5RS Scheme
language standard, and includes many enhancements and extensions.")
    (license license:bsd-3)))
(define-public
  chicken-json
  (package
    (name "chicken-json")
    (version "1.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "json" "1.6"))
        (sha256
          (base32 "1h27h6z7awadijk9w51df9dyk3wma27fp180j7xwl27sbw7h76wz"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-packrat" "chicken-srfi-1" "chicken-srfi-69")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "json"))
    (synopsis "A JSON library")
    (home-page "https://wiki.call-cc.org/eggref/5/json")
    (description "A JSON library")
    (license license:expat)))

(define-public
  chicken-memoize
  (package
    (name "chicken-memoize")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "memoize" "0.3"))
        (sha256
          (base32 "1xh9cfxbr28x2kmsr4n54ynmpz9z5wl9b0rc455mhb6ilsl5nyzi"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-69")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "memoize"))
    (synopsis "Procedures memoization")
    (home-page "https://wiki.call-cc.org/eggref/5/memoize")
    (description "Procedures memoization")
    (license license:bsd-2)))

(define-public
  chicken-srfi-101
  (package
    (name "chicken-srfi-101")
    (version "0.0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-101" "0.0.3"))
        (sha256
          (base32 "0jfkprl6jxyh2s241x0cmxnqdb3s1bl32jyfqyqzpadbbvrixm56"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-69" "chicken-vector-lib")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-101"))
    (synopsis "SRFI 101")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-101")
    (description "SRFI 101")
    (license license:bsd-2)))

(define-public
  chicken-srfi-197
  (package
    (name "chicken-srfi-197")
    (version "0.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-197" "0.2.0"))
        (sha256
          (base32 "19lxc4id9k7hqi1d8fm2mxn32gh18lv35xiash018r6cscz9hh01"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-197"))
    (synopsis "SRFI-197: Pipeline Operators")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-197")
    (description "SRFI-197: Pipeline Operators")
    (license license:expat)))

(define-public
  chicken-stb-image
  (package
    (name "chicken-stb-image")
    (version "0.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "stb-image" "0.6"))
        (sha256
          (base32 "0h8a8212miihqnd93s6svj3gs5yw7ix787mpzj7bgd34vx5srbsy"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "stb-image"))
    (synopsis "read png/jpg/tga/bmp/psd/gif/hdr/pic/pnm images into pixels")
    (home-page "https://wiki.call-cc.org/eggref/5/stb-image")
    (description "read png/jpg/tga/bmp/psd/gif/hdr/pic/pnm images into pixels")
    (license license:public-domain)))

(define-public
  chicken-sdl2-image
  (package
    (name "chicken-sdl2-image")
    (version "0.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sdl2-image" "0.2.0"))
        (sha256
          (base32 "08kxmx97rw760vlqsfl6s89mjb2gxzynk2fvc6dd0s7spdjvjk34"))))
    (propagated-inputs (specifications->packages (list "chicken-sdl2")))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sdl2-image"))
    (synopsis "Bindings to SDL_image 2")
    (home-page "https://wiki.call-cc.org/eggref/5/sdl2-image")
    (description "Bindings to SDL_image 2")
    (license license:bsd-2)))

(define-public
  chicken-spiffy-sexpr-log
  (package
    (name "chicken-spiffy-sexpr-log")
    (version "0.3.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "spiffy-sexpr-log" "0.3.2"))
        (sha256
          (base32 "0z2sxvjgnri80rvlgyajx6hbwdhs6qrxvida05j8dh25xj5kyiyj"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-spiffy" "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "spiffy-sexpr-log"))
    (synopsis "Symbolic expression log format for Spiffy")
    (home-page "https://wiki.call-cc.org/eggref/5/spiffy-sexpr-log")
    (description "Symbolic expression log format for Spiffy")
    (license license:bsd-2)))

(define-public
  chicken-tiny-prolog
  (package
    (name "chicken-tiny-prolog")
    (version "2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "tiny-prolog" "2.1"))
        (sha256
          (base32 "0zz468zvr7v1dh2sg48kmlq43dbim66md3dv2dchdpzfjg378w8k"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-69")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "tiny-prolog"))
    (synopsis "Tiny PROLOG interpreter.")
    (home-page "https://wiki.call-cc.org/eggref/5/tiny-prolog")
    (description "Tiny PROLOG interpreter.")
    (license license:bsd-2)))

(define-public
  chicken-7off
  (package
    (name "chicken-7off")
    (version "1.32")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "7off" "1.32"))
        (sha256
          (base32 "06nzh23bpf9f011wr5sxqnq4nb1b7af6148qz52ri9hbb8r2mi4i"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-anaphora"
              "chicken-define-options"
              "chicken-lowdown"
              "chicken-matchable"
              "chicken-srfi-1"
              "chicken-sxml-transforms"
              "chicken-sxpath"
              "chicken-utf8"
              "chicken-srfi-42"
              "chicken-srfi-69"
              "chicken-strse"
              "chicken-uri-common")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "7off"))
    (synopsis "Markdown to Gemini text")
    (home-page "https://wiki.call-cc.org/eggref/5/7off")
    (description "Markdown to Gemini text")
    (license license:agpl3+)))

(define-public
  chicken-tiger-hash
  (package
    (name "chicken-tiger-hash")
    (version "4.1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "tiger-hash" "4.1.2"))
        (sha256
          (base32 "0hcmp58byk2wg0nbmb5zh2zc7z670dhva21qjpix6l8hqgrf0151"))))
    (propagated-inputs
      (specifications->packages (list "chicken-message-digest-primitive")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-test-utils"
              "chicken-srfi-13"
              "chicken-message-digest-utils"
              "chicken-message-digest-primitive")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "tiger-hash"))
    (synopsis "Tiger/192 Message Digest")
    (home-page "https://wiki.call-cc.org/eggref/5/tiger-hash")
    (description "Tiger/192 Message Digest")
    (license license:bsd-2)))

(define-public
  chicken-regex
  (package
    (name "chicken-regex")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "regex" "2.0"))
        (sha256
          (base32 "1hxkva5jvk08wnj3x4lnyxhhyr5vkbs7q99qzpnwmfphbrzmmqzr"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "regex"))
    (synopsis "Compatibility library for old regular expression API")
    (home-page "https://wiki.call-cc.org/eggref/5/regex")
    (description "Compatibility library for old regular expression API")
    (license license:bsd-2)))

(define-public
  chicken-leveldb
  (package
    (name "chicken-leveldb")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "leveldb" "1.2"))
        (sha256
          (base32 "14wjgiaclxm6f3m88fakg5hdpxd1f8d8yzm6vgwv01dd6izqpvfv"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "leveldb"))
    (synopsis "Bindings to Google's LevelDB Key-Value Store")
    (home-page "https://wiki.call-cc.org/eggref/5/leveldb")
    (description "Bindings to Google's LevelDB Key-Value Store")
    (license license:bsd-2)))

(define-public
  chicken-expand-full
  (package
    (name "chicken-expand-full")
    (version "2.1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "expand-full" "2.1.3"))
        (sha256
          (base32 "072c5xvmsgkbz5wj4ihj0y4k5fvx9lsz5vjydvzmhnmwd613cg46"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "expand-full"))
    (synopsis "Full macro expansion")
    (home-page "https://wiki.call-cc.org/eggref/5/expand-full")
    (description "Full macro expansion")
    (license license:bsd-2)))

(define-public
  chicken-magic
  (package
    (name "chicken-magic")
    (version "0.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "magic" "0.1.0"))
        (sha256
          (base32 "17j25ckrhpm1k2ivl7qa1k87kylid466bb23ic96h64n111qhhdk"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "magic"))
    (synopsis "libmagic bindings")
    (home-page "https://wiki.call-cc.org/eggref/5/magic")
    (description "libmagic bindings")
    (license license:bsd-2)))

(define-public
  chicken-spiffy-request-vars
  (package
    (name "chicken-spiffy-request-vars")
    (version "0.19")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "spiffy-request-vars" "0.19"))
        (sha256
          (base32 "06wzpmwnn7djr7iz9v8qqn6nrxcddqi4d751ym7g7na4aqypcc80"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-intarweb"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-69"
              "chicken-spiffy"
              "chicken-uri-common")))
    (native-inputs
      (specifications->packages
        (list "chicken-http-client" "chicken-server-test" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "spiffy-request-vars"))
    (synopsis "Easy access to variables from HTTP requests")
    (home-page "https://wiki.call-cc.org/eggref/5/spiffy-request-vars")
    (description "Easy access to variables from HTTP requests")
    (license license:bsd-2)))

(define-public
  chicken-soil
  (package
    (name "chicken-soil")
    (version "1.6.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "soil" "1.6.0"))
        (sha256
          (base32 "0h562n1ql23kjwkx5dvsxrzpyc3rnfp61i1mss88kcnrwy6hk6ad"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "soil"))
    (synopsis
      "Lightweight, simple library for loading image files into OpenGL-friendly format.")
    (home-page "https://wiki.call-cc.org/eggref/5/soil")
    (description
      "Lightweight, simple library for loading image files into OpenGL-friendly format.")
    (license license:bsd-2)))

(define-public
  chicken-tree-walkers
  (package
    (name "chicken-tree-walkers")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "tree-walkers" "2.0"))
        (sha256
          (base32 "0zsgrw8sxg3fc8z42ghjh47jq2ycwsmsgdw3kn7fbhvypz4yrmfy"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "tree-walkers"))
    (synopsis
      "replacement of car, cdr and consorts and other tree- and\nlist-routines")
    (home-page "https://wiki.call-cc.org/eggref/5/tree-walkers")
    (description
      "replacement of car, cdr and consorts and other tree- and\nlist-routines")
    (license license:bsd-2)))

(define-public
  chicken-xml-rpc
  (package
    (name "chicken-xml-rpc")
    (version "3.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "xml-rpc" "3.0.1"))
        (sha256
          (base32 "05qn5fd872q3zh0ic9gq32j8rnvpg6l1p5bj86pdyan1iqxypnsq"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-base64"
              "chicken-http-client"
              "chicken-intarweb"
              "chicken-ssax"
              "chicken-sxpath"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-18"
              "chicken-srfi-69")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "xml-rpc"))
    (synopsis "XML-RPC client/server")
    (home-page "https://wiki.call-cc.org/eggref/5/xml-rpc")
    (description "XML-RPC client/server")
    (license license:bsd-2)))

(define-public
  chicken-unsafe
  (package
    (name "chicken-unsafe")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "unsafe" "1.0"))
        (sha256
          (base32 "0nainz77q0a1pzac92dp4nbmpq4g20vqa4qxzaqg86rhy7rpr01x"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "unsafe"))
    (synopsis "Unsafe operations")
    (home-page "https://wiki.call-cc.org/eggref/5/unsafe")
    (description "Unsafe operations")
    (license license:bsd-2)))

(define-public
  chicken-icu
  (package
    (name "chicken-icu")
    (version "0.3.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "icu" "0.3.3"))
        (sha256
          (base32 "1hii4n3mraqaznaiwznwbx06yy99157pxxarkj558zarkn43k82y"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-utf8"
              "chicken-srfi-13"
              "chicken-srfi-1"
              "chicken-foreigners"
              "chicken-chalk")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "icu"))
    (synopsis "Chicken bindings to the ICU unicode library")
    (home-page "https://wiki.call-cc.org/eggref/5/icu")
    (description "Chicken bindings to the ICU unicode library")
    (license license:unicode)))

(define-public
  chicken-simple-timer
  (package
    (name "chicken-simple-timer")
    (version "0.1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "simple-timer" "0.1.2"))
        (sha256
          (base32 "1xnkf4xd7hx1lki1nxzkdpwynxx1zry6j8a8cyxk9hb72ygcd9p0"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-18" "chicken-pigeon-hole" "chicken-llrb-tree")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-matchable")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "simple-timer"))
    (synopsis "Simple, cancel-able, efficient timer API")
    (home-page "https://wiki.call-cc.org/eggref/5/simple-timer")
    (description "Simple, cancel-able, efficient timer API")
    (license license:bsd-2)))

(define-public
  chicken-srfi-193
  (package
    (name "chicken-srfi-193")
    (version "0.1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-193" "0.1.3"))
        (sha256
          (base32 "18raq9r8nvs6dvb9fq7095bi9sxh655pjs4k7jwj486369jn90di"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-193"))
    (synopsis "SRFI 193: Command line")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-193")
    (description "SRFI 193: Command line")
    (license license:isc)))

(define-public
  chicken-type-extensions
  (package
    (name "chicken-type-extensions")
    (version "0.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "type-extensions" "0.1.0"))
        (sha256
          (base32 "0l4hp89v0x10is29fczhr6y89qrsd16bgdgbl2pf2l36pmlgqfmr"))))
    (propagated-inputs (specifications->packages (list "chicken-matchable")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "type-extensions"))
    (synopsis "Miscellaneous type system extensions")
    (home-page "https://wiki.call-cc.org/eggref/5/type-extensions")
    (description "Miscellaneous type system extensions")
    (license license:bsd-2)))

(define-public
  chicken-pigeon-hole
  (package
    (name "chicken-pigeon-hole")
    (version "0.2.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pigeon-hole" "0.2.8"))
        (sha256
          (base32 "0sz97xznai8a2gsfc2f2aink8rhmksz7iqbl7k061wfgf4w8vrvk"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-18")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pigeon-hole"))
    (synopsis "A mailbox constrained by capacity.")
    (home-page "https://wiki.call-cc.org/eggref/5/pigeon-hole")
    (description "A mailbox constrained by capacity.")
    (license license:bsd-2)))

(define-public
  chicken-monad
  (package
    (name "chicken-monad")
    (version "5.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "monad" "5.0"))
        (sha256
          (base32 "1xd24plxnwi9yssmw2in008biv2xf4iwwln6xswx781ankppqpg9"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-compile-file")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "monad"))
    (synopsis "Monads")
    (home-page "https://wiki.call-cc.org/eggref/5/monad")
    (description "Monads")
    (license license:bsd-2)))

(define-public
  chicken-modular-arithmetic
  (package
    (name "chicken-modular-arithmetic")
    (version "1.0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "modular-arithmetic" "1.0.3"))
        (sha256
          (base32 "0gh4017knjkqhp4rcvjwiw727235yhpmn0dybd3v0cckbsxhic1a"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-matchable")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "modular-arithmetic"))
    (synopsis "Modular Arithmetic on Finite Fields")
    (home-page "https://wiki.call-cc.org/eggref/5/modular-arithmetic")
    (description "Modular Arithmetic on Finite Fields")
    (license license:bsd-2)))

(define-public
  chicken-sandbox
  (package
    (name "chicken-sandbox")
    (version "1.91")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sandbox" "1.91"))
        (sha256
          (base32 "1vsr4nx20rgdszkrrsyl23lw1mf3qldyqcxlnf56s8swzfxcss3y"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable" "chicken-defstruct")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sandbox"))
    (synopsis "A safe evaluation environment")
    (home-page "https://wiki.call-cc.org/eggref/5/sandbox")
    (description "A safe evaluation environment")
    (license license:bsd-2)))

(define-public
  chicken-srfi-160
  (package
    (name "chicken-srfi-160")
    (version "0.5.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-160" "0.5.3"))
        (sha256
          (base32 "1zwvc79q46rdb06p3skvqb7v0akgj80z56g8hhbk9qni6hjkq938"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-128")))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-srfi-128" "chicken-srfi-133")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-160"))
    (synopsis "SRFI 160: Homogeneous numeric vector libraries")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-160")
    (description "SRFI 160: Homogeneous numeric vector libraries")
    (license license:expat)))

(define-public
  chicken-sysexits
  (package
    (name "chicken-sysexits")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sysexits" "1.0.0"))
        (sha256
          (base32 "00hymhdqwn3s2wqmaw3182kkp392hxx6h1xicqga4nxjjm4rnw24"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sysexits"))
    (synopsis "Exit status codes for system programs")
    (home-page "https://wiki.call-cc.org/eggref/5/sysexits")
    (description "Exit status codes for system programs")
    (license license:public-domain)))

(define-public
  chicken-pledge
  (package
    (name "chicken-pledge")
    (version "0.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pledge" "0.1.0"))
        (sha256
          (base32 "1fj53zvsld6n2sasp3lwnjxsmn11z5zf53928gygh6rb84mfhq22"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-module-declarations")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pledge"))
    (synopsis "Bindings for OpenBSD's pledge(2)")
    (home-page "https://wiki.call-cc.org/eggref/5/pledge")
    (description "Bindings for OpenBSD's pledge(2)")
    (license license:bsd-2)))

(define-public
  chicken-feature-test
  (package
    (name "chicken-feature-test")
    (version "0.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "feature-test" "0.2.0"))
        (sha256
          (base32 "1m9p5zhgj8g1n604pwp7fyd73jbra8fpjqcsz3a4mrgmc5sjvba1"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "feature-test"))
    (synopsis "Foreign feature testing")
    (home-page "https://wiki.call-cc.org/eggref/5/feature-test")
    (description "Foreign feature testing")
    (license license:bsd-2)))

(define-public
  chicken-awful-static-pages
  (package
    (name "chicken-awful-static-pages")
    (version "0.1.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "awful-static-pages" "0.1.6"))
        (sha256
          (base32 "1v4micnkci3lkknx0x1ph7apvlq2zzzjxgr2h13i7l0zm0bhf1nl"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-awful"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-69")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "awful-static-pages"))
    (synopsis "Tool to generate static pages out of awful applications")
    (home-page "https://wiki.call-cc.org/eggref/5/awful-static-pages")
    (description "Tool to generate static pages out of awful applications")
    (license license:bsd-2)))

(define-public
  chicken-random-mtzig
  (package
    (name "chicken-random-mtzig")
    (version "5.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "random-mtzig" "5.1"))
        (sha256
          (base32 "0swkhz2ifg2f5cwpi4njfgjfzvdhr0crkz4w77bnsk4fip86vk6h"))))
    (propagated-inputs (specifications->packages (list "chicken-bind")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "random-mtzig"))
    (synopsis
      "MT19937 random number generator with Marsaglia and Tang's Ziggurat algorithm to generate random numbers from a non-uniform distribution.")
    (home-page "https://wiki.call-cc.org/eggref/5/random-mtzig")
    (description
      "MT19937 random number generator with Marsaglia and Tang's Ziggurat algorithm to generate random numbers from a non-uniform distribution.")
    (license license:bsd-2)))

(define-public
  chicken-bindings
  (package
    (name "chicken-bindings")
    (version "5.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "bindings" "5.0"))
        (sha256
          (base32 "1r193n8h8bbq8yx8xwgpfd0yxwipn58skhi258y64hnb88pzjfy3"))))
    (propagated-inputs
      (specifications->packages (list "chicken-simple-sequences")))
    (native-inputs
      (specifications->packages
        (list "chicken-simple-tests" "chicken-biglists")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "bindings"))
    (synopsis "Pattern matching with destructuring bindings and setters")
    (home-page "https://wiki.call-cc.org/eggref/5/bindings")
    (description "Pattern matching with destructuring bindings and setters")
    (license license:bsd-2)))

(define-public
  chicken-gl-utils
  (package
    (name "chicken-gl-utils")
    (version "0.8.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "gl-utils" "0.8.0"))
        (sha256
          (base32 "1krm8qs0h9vn6sp62imv6arwr6l1pg5amimkci35l4n4jsrmd6ag"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-z3"
              "chicken-matchable"
              "chicken-miscmacros"
              "chicken-srfi-99"
              "chicken-srfi-42"
              "chicken-epoxy"
              "chicken-gl-math")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "gl-utils"))
    (synopsis "High(er) level tools for OpenGL")
    (home-page "https://wiki.call-cc.org/eggref/5/gl-utils")
    (description "High(er) level tools for OpenGL")
    (license license:bsd-2)))

(define-public
  chicken-glls
  (package
    (name "chicken-glls")
    (version "0.12.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "glls" "0.12.2"))
        (sha256
          (base32 "0mx2lpj4mly86fgnlkv7kw1xmabqkzxmjdahp9p0387v4a8nwzas"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-epoxy"
              "chicken-gl-utils"
              "chicken-miscmacros"
              "chicken-matchable"
              "chicken-fmt"
              "chicken-srfi-1"
              "chicken-srfi-42"
              "chicken-srfi-69")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "glls"))
    (synopsis "A compiler for a Scheme-like language targeting the GLSL")
    (home-page "https://wiki.call-cc.org/eggref/5/glls")
    (description "A compiler for a Scheme-like language targeting the GLSL")
    (license license:bsd-2)))

(define-public
  chicken-queues
  (package
    (name "chicken-queues")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "queues" "0.1"))
        (sha256
          (base32 "0i7ywz4p5fhninfgf0fk8h6cdqdp4hdqb76y5cgnzspnmv5qpg26"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "queues"))
    (synopsis "A queue data structure")
    (home-page "https://wiki.call-cc.org/eggref/5/queues")
    (description "A queue data structure")
    (license license:public-domain)))

(define-public
  chicken-intarweb
  (package
    (name "chicken-intarweb")
    (version "2.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "intarweb" "2.1.0"))
        (sha256
          (base32 "0khzz6w8dh8sbiaqw3b68p0v8lv4bjwxipkb9cqj2q9r7zl84555"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14"
              "chicken-defstruct"
              "chicken-uri-common"
              "chicken-base64")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "intarweb"))
    (synopsis "A more convenient HTTP library")
    (home-page "https://wiki.call-cc.org/eggref/5/intarweb")
    (description "A more convenient HTTP library")
    (license license:bsd-2)))

(define-public
  chicken-fuse
  (package
    (name "chicken-fuse")
    (version "0.1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "fuse" "0.1.1"))
        (sha256
          (base32 "1ywgjrhkr45837xf5vnb2i3aacby7yjkhm62drdf70c09za860dd"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-18")))
    (native-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-test"
              "chicken-foreigners"
              "chicken-matchable"
              "chicken-module-declarations")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "fuse"))
    (synopsis "Filesystems in Userspace")
    (home-page "https://wiki.call-cc.org/eggref/5/fuse")
    (description "Filesystems in Userspace")
    (license license:bsd-2)))

(define-public
  chicken-msgpack
  (package
    (name "chicken-msgpack")
    (version "1.0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "msgpack" "1.0.3"))
        (sha256
          (base32 "1plmvyy274c1qg2d3x44wpddjkj4hz6lglkkg1km4jn4h7f81gwq"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable" "chicken-srfi-1" "chicken-srfi-69")))
    (native-inputs
      (specifications->packages
        (list "chicken-matchable"
              "chicken-srfi-1"
              "chicken-srfi-69"
              "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "msgpack"))
    (synopsis "MessagePack implementation for CHICKEN")
    (home-page "https://wiki.call-cc.org/eggref/5/msgpack")
    (description "MessagePack implementation for CHICKEN")
    (license license:bsd-2)))

(define-public
  chicken-rest-bind
  (package
    (name "chicken-rest-bind")
    (version "0.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "rest-bind" "0.6"))
        (sha256
          (base32 "04c3rh2xjm6qrl0swlyh697r8f02rrfkiccajdvbngbq9c2cjk39"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-intarweb" "chicken-uri-common")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "rest-bind"))
    (synopsis "Generates wrappers to REST-like HTTP APIs.")
    (home-page "https://wiki.call-cc.org/eggref/5/rest-bind")
    (description "Generates wrappers to REST-like HTTP APIs.")
    (license license:bsd-2)))

(define-public
  chicken-stack
  (package
    (name "chicken-stack")
    (version "3.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "stack" "3.1.0"))
        (sha256
          (base32 "0fcpsh9rgibkz807jwr062bcjzz7x93pv5x9xniycpjp6i3s5r2x"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-record-variants" "chicken-check-errors")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "stack"))
    (synopsis "Provides LIFO queue (stack) operations")
    (home-page "https://wiki.call-cc.org/eggref/5/stack")
    (description "Provides LIFO queue (stack) operations")
    (license license:bsd-2)))

(define-public
  chicken-autocompile
  (package
    (name "chicken-autocompile")
    (version "1.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "autocompile" "1.1.0"))
        (sha256
          (base32 "1yq819vbb813svxvxad4h99vrhvf7rs8cv9dsnj85rcvi60w7299"))))
    (propagated-inputs (specifications->packages (list "chicken-matchable")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "autocompile"))
    (synopsis "Automatically compile Scheme scripts on demand")
    (home-page "https://wiki.call-cc.org/eggref/5/autocompile")
    (description "Automatically compile Scheme scripts on demand")
    (license license:public-domain)))

(define-public
  chicken-awful-path-matchers
  (package
    (name "chicken-awful-path-matchers")
    (version "0.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "awful-path-matchers" "0.0.2"))
        (sha256
          (base32 "12y90z3rlvjid6lxnhwg8f5x0wcm4qiq2nqvpg5klp1rmwsibbzh"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages
        (list "chicken-awful"
              "chicken-http-client"
              "chicken-server-test"
              "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "awful-path-matchers"))
    (synopsis "Path matchers for awful")
    (home-page "https://wiki.call-cc.org/eggref/5/awful-path-matchers")
    (description "Path matchers for awful")
    (license license:bsd-2)))

(define-public
  chicken-endian-blob
  (package
    (name "chicken-endian-blob")
    (version "2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "endian-blob" "2.1"))
        (sha256
          (base32 "04f4d3kjagd9d12pigcwydyf39i1q3pbf6c88h9gs1ddfz13arq1"))))
    (propagated-inputs (specifications->packages (list "chicken-byte-blob")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "endian-blob"))
    (synopsis
      "Endian-specific procedures for converting blobs to numeric values and vectors.")
    (home-page "https://wiki.call-cc.org/eggref/5/endian-blob")
    (description
      "Endian-specific procedures for converting blobs to numeric values and vectors.")
    (license license:gpl3)))

(define-public
  chicken-fp-utils
  (package
    (name "chicken-fp-utils")
    (version "4.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "fp-utils" "4.2.0"))
        (sha256
          (base32 "02k8ayj30gh36cz0p2xirjnvbb845ng43yxb2b7x8ih39jyps9py"))))
    (propagated-inputs (specifications->packages (list "chicken-fx-utils")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "fp-utils"))
    (synopsis "fp utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/fp-utils")
    (description "fp utilities")
    (license license:bsd-2)))

(define-public
  chicken-json-abnf
  (package
    (name "chicken-json-abnf")
    (version "7.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "json-abnf" "7.0"))
        (sha256
          (base32 "1fi5k13pmjx008xq9ny7rz1h48gjdrrx99sm8jhwaivcsg8bikqd"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-abnf" "chicken-utf8" "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "json-abnf"))
    (synopsis "Parser combinators for JavaScript Object Notation (JSON).")
    (home-page "https://wiki.call-cc.org/eggref/5/json-abnf")
    (description "Parser combinators for JavaScript Object Notation (JSON).")
    (license license:gpl3)))

(define-public
  chicken-lmdb-ht
  (package
    (name "chicken-lmdb-ht")
    (version "3.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "lmdb-ht" "3.4"))
        (sha256
          (base32 "1ragkv9xpgsq9lfz0p6aknw54m4rynby2vq6xlhrlhwwq0g5v1ld"))))
    (propagated-inputs
      (specifications->packages (list "chicken-rabbit" "chicken-srfi-69")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-srfi-69"
              "chicken-srfi-13"
              "chicken-compile-file")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "lmdb-ht"))
    (synopsis "Hashtable-like interface to the LMDB key-value database.")
    (home-page "https://wiki.call-cc.org/eggref/5/lmdb-ht")
    (description "Hashtable-like interface to the LMDB key-value database.")
    (license license:bsd-2)))

(define-public
  chicken-system-information
  (package
    (name "chicken-system-information")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "system-information" "0.1"))
        (sha256
          (base32 "04974zimmahsbvk73bj487rj75ca6g91mr9b882859awbmc00d4g"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "system-information"))
    (synopsis "Obtaining system and host information")
    (home-page "https://wiki.call-cc.org/eggref/5/system-information")
    (description "Obtaining system and host information")
    (license license:bsd-2)))

(define-public
  chicken-record-variants
  (package
    (name "chicken-record-variants")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "record-variants" "1.1"))
        (sha256
          (base32 "1ha392k88389ls5yj08mf7gnnlysy5vzcz30ndiihlcwk2q49sq5"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "record-variants"))
    (synopsis "Optimized record access")
    (home-page "https://wiki.call-cc.org/eggref/5/record-variants")
    (description "Optimized record access")
    (license license:bsd-2)))

(define-public
  chicken-yaml
  (package
    (name "chicken-yaml")
    (version "0.2.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "yaml" "0.2.2"))
        (sha256
          (base32 "0h80jim818a3ks0qa6q123hj9gabky9zyvam724sglvx3zj897is"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-sql-null" "chicken-srfi-13" "chicken-srfi-69")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "yaml"))
    (synopsis "Bindings to libyaml")
    (home-page "https://wiki.call-cc.org/eggref/5/yaml")
    (description "Bindings to libyaml")
    (license license:expat)))

(define-public
  chicken-message-digest-type
  (package
    (name "chicken-message-digest-type")
    (version "4.3.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "message-digest-type" "4.3.6"))
        (sha256
          (base32 "15cp3km0lv4s28yq0ynabqmd902325692xyq2hmsv0n68j5jckdz"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-blob-utils"
              "chicken-string-utils"
              "chicken-message-digest-primitive"
              "chicken-check-errors")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "message-digest-type"))
    (synopsis "Message Digest Type")
    (home-page "https://wiki.call-cc.org/eggref/5/message-digest-type")
    (description "Message Digest Type")
    (license license:bsd-2)))

(define-public
  chicken-uri-common
  (package
    (name "chicken-uri-common")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "uri-common" "2.0"))
        (sha256
          (base32 "0zpdwzsiys6y3vb7mh6ca55qzn3l86m1b0f4kjd7v9y9d47pywl3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-uri-generic"
              "chicken-defstruct"
              "chicken-matchable"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "uri-common"))
    (synopsis "Parser for common URI schemes")
    (home-page "https://wiki.call-cc.org/eggref/5/uri-common")
    (description "Parser for common URI schemes")
    (license license:bsd-2)))

(define-public
  chicken-stalin
  (package
    (name "chicken-stalin")
    (version "0.11.11")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "stalin" "0.11.11"))
        (sha256
          (base32 "034mc1rgmp6r44bycknja6c4snvs3li75f1kr686g0lgzg1n0jjq"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "stalin"))
    (synopsis "An aggressively optimizing Scheme->C compiler")
    (home-page "https://wiki.call-cc.org/eggref/5/stalin")
    (description "An aggressively optimizing Scheme->C compiler")
    (license license:gpl2)))

(define-public
  chicken-datatype
  (package
    (name "chicken-datatype")
    (version "1.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "datatype" "1.6"))
        (sha256
          (base32 "09l14hiaas7mdibnh0i3a9jgpvgsy67m37zp948d3c5l16f3c826"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "datatype"))
    (synopsis
      "A facility for creating and deconstructing variant records (from EOPL)")
    (home-page "https://wiki.call-cc.org/eggref/5/datatype")
    (description
      "A facility for creating and deconstructing variant records (from EOPL)")
    (license license:bsd-2)))

(define-public
  chicken-sparse-vectors
  (package
    (name "chicken-sparse-vectors")
    (version "1.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sparse-vectors" "1.1.0"))
        (sha256
          (base32 "0nmk6c9mhls38lyp0d8a9f3xh94jbl2dqbmqr9pab23pnx4hha1j"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-record-variants")))
    (native-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sparse-vectors"))
    (synopsis "Arbitrarily large vectors")
    (home-page "https://wiki.call-cc.org/eggref/5/sparse-vectors")
    (description "Arbitrarily large vectors")
    (license license:bsd-2)))

(define-public
  chicken-pseudolists
  (package
    (name "chicken-pseudolists")
    (version "3.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pseudolists" "3.0"))
        (sha256
          (base32 "0x9pgg0wfk7c9by77s2kf72vksgqmfdk5rzsx0shc5rwr4k3jn6c"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pseudolists"))
    (synopsis "pseudolists as a generalisation of ordinary lists")
    (home-page "https://wiki.call-cc.org/eggref/5/pseudolists")
    (description "pseudolists as a generalisation of ordinary lists")
    (license license:bsd-2)))

(define-public
  chicken-srfi-67
  (package
    (name "chicken-srfi-67")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-67" "0.1"))
        (sha256
          (base32 "0vi8l6nmbv14mfqqyyck1ayr5xdiiqypr2bcwvawfi6aanfl6xxb"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-27")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-67"))
    (synopsis "SRFI-67: Compare Procedures")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-67")
    (description "SRFI-67: Compare Procedures")
    (license license:expat)))

(define-public
  chicken-srfi-173
  (package
    (name "chicken-srfi-173")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-173" "0.1"))
        (sha256
          (base32 "14m763qmx7xdsqv5gkf4xqxvi0nnr5ykwhn3g9mmgazab5g32i0s"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-173"))
    (synopsis "SRFI-173 Hooks")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-173")
    (description "SRFI-173 Hooks")
    (license license:expat)))

(define-public
  chicken-statistics
  (package
    (name "chicken-statistics")
    (version "0.13")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "statistics" "0.13"))
        (sha256
          (base32 "0s659vg9na72brl1bs336vbv7jxy3blf113mifax7ya5vpvxnl71"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-25"
              "chicken-srfi-69"
              "chicken-vector-lib"
              "chicken-random-mtzig"
              "chicken-yasos")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-srfi-1"
              "chicken-compile-file"
              "chicken-srfi-13")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "statistics"))
    (synopsis "Statistics library")
    (home-page "https://wiki.call-cc.org/eggref/5/statistics")
    (description "Statistics library")
    (license license:gpl3)))

(define-public
  chicken-srfi-95
  (package
    (name "chicken-srfi-95")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-95" "2.0"))
        (sha256
          (base32 "0qya20jn78zwhl89q3jp5jx5iasl0gwjwl8acmq3hlgl5d3nivcd"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-63")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-95"))
    (synopsis "SRFI-95: Sorting and merging")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-95")
    (description "SRFI-95: Sorting and merging")
    (license license:public-domain)))

(define-public
  chicken-sxml-serializer
  (package
    (name "chicken-sxml-serializer")
    (version "0.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sxml-serializer" "0.5"))
        (sha256
          (base32 "1q34n5akg7dc2ylvwbwlahmrdhbxjv9i9lhbfx4p32vsxaay8bib"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sxml-serializer"))
    (synopsis "Serialize SXML to XML and HTML")
    (home-page "https://wiki.call-cc.org/eggref/5/sxml-serializer")
    (description "Serialize SXML to XML and HTML")
    (license license:bsd-2)))

(define-public
  chicken-ephem
  (package
    (name "chicken-ephem")
    (version "v1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ephem" "v1.1"))
        (sha256
          (base32 "0mg43ynh2s8r335sz1938wqjssz1wfk1mkicrg56nmkhc74p9181"))))
    (propagated-inputs (specifications->packages (list "chicken-foreigners")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ephem"))
    (synopsis
      "A wrapper for libnova a 'general purpose, double precision, Celestial Mechanics, Astrometry and Astrodynamics library.'")
    (home-page "https://wiki.call-cc.org/eggref/5/ephem")
    (description
      "A wrapper for libnova a 'general purpose, double precision, Celestial Mechanics, Astrometry and Astrodynamics library.'")
    (license license:gpl3)))

(define-public
  chicken-uuid-lib
  (package
    (name "chicken-uuid-lib")
    (version "0.0.15")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "uuid-lib" "0.0.15"))
        (sha256
          (base32 "16b03b6d29mjn8bcil0ln0vq85dxxvzlxrpnpblf68n7l9ix8qnc"))))
    (propagated-inputs
      (specifications->packages (list "chicken-record-variants")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "uuid-lib"))
    (synopsis "OSF DCE 1.1 UUID")
    (home-page "https://wiki.call-cc.org/eggref/5/uuid-lib")
    (description "OSF DCE 1.1 UUID")
    (license license:bsd-2)))

(define-public
  chicken-amqp
  (package
    (name "chicken-amqp")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "amqp" "1.0.0"))
        (sha256
          (base32 "0mwnjcsrcm024qrip9h3fap93n72slkrib1la075ra0zx0j6yc53"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-bitstring"
              "chicken-mailbox"
              "chicken-srfi-18"
              "chicken-uri-generic")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "amqp"))
    (synopsis "AMPQ")
    (home-page "https://wiki.call-cc.org/eggref/5/amqp")
    (description "AMPQ")
    (license license:bsd-2)))

(define-public
  chicken-simple-md5
  (package
    (name "chicken-simple-md5")
    (version "0.1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "simple-md5" "0.1.1"))
        (sha256
          (base32 "1aq7iqbh1jb3j61nylsrzf7rcmf204v1jl2l559q0jdycij6yn5z"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-memory-mapped-files" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "simple-md5"))
    (synopsis "Computes MD5 (RFC1321) checksums")
    (home-page "https://wiki.call-cc.org/eggref/5/simple-md5")
    (description "Computes MD5 (RFC1321) checksums")
    (license license:public-domain)))

(define-public
  chicken-srfi-171
  (package
    (name "chicken-srfi-171")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-171" "0.2"))
        (sha256
          (base32 "0q951jn8zcrh9snpz95bfqicgsmfznlxcq4qhr2rdp0k2h6pwjyb"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-r6rs-bytevectors"
              "chicken-vector-lib"
              "chicken-srfi-1"
              "chicken-srfi-69")))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-171"))
    (synopsis "SRFI-171: Transducers")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-171")
    (description "SRFI-171: Transducers")
    (license license:expat)))

(define-public
  chicken-object-evict
  (package
    (name "chicken-object-evict")
    (version "0.1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "object-evict" "0.1.1"))
        (sha256
          (base32 "1g0vzz1j7p6h0y994hqpdrqydssyakyizf2in41crwkn3b7d8b8f"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-69")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "object-evict"))
    (synopsis "Evict data to unmanaged memory")
    (home-page "https://wiki.call-cc.org/eggref/5/object-evict")
    (description "Evict data to unmanaged memory")
    (license license:bsd-2)))

(define-public
  chicken-ftl
  (package
    (name "chicken-ftl")
    (version "0.9")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ftl" "0.9"))
        (sha256
          (base32 "0qqpf0sng3g5wrp6038b5h757naw4g58cfzn3j67kywbl9ai3kjr"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ftl"))
    (synopsis "Interface based sequence library")
    (home-page "https://wiki.call-cc.org/eggref/5/ftl")
    (description "Interface based sequence library")
    (license license:lgpl2.1)))

(define-public
  chicken-srfi-18
  (package
    (name "chicken-srfi-18")
    (version "0.1.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-18" "0.1.7"))
        (sha256
          (base32 "0mkg3g045md9v74p4ac24q0c4xvvinz1nggakyg7wlg7c176i2l9"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-compile-file")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-18"))
    (synopsis "SRFI-18 thread library")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-18")
    (description "SRFI-18 thread library")
    (license license:bsd-2)))

(define-public
  chicken-gemini
  (package
    (name "chicken-gemini")
    (version "0.2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "gemini" "0.2.1"))
        (sha256
          (base32 "1kx70kp1r1dz23wcpqdrgjh49vcn2lhl50cg4b48v3rc37rpa4vz"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-openssl" "chicken-r7rs" "chicken-uri-generic")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "gemini"))
    (synopsis "Client library for the gemini:// protocol")
    (home-page "https://wiki.call-cc.org/eggref/5/gemini")
    (description "Client library for the gemini:// protocol")
    (license license:isc)))

(define-public
  chicken-combinators
  (package
    (name "chicken-combinators")
    (version "1.2.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "combinators" "1.2.2"))
        (sha256
          (base32 "054bik2zrdw4crdamarph11bk353aj8afk63wlivi6jx02bqq7zk"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "combinators"))
    (synopsis "Combinators")
    (home-page "https://wiki.call-cc.org/eggref/5/combinators")
    (description "Combinators")
    (license license:public-domain)))

(define-public
  chicken-srfi-127
  (package
    (name "chicken-srfi-127")
    (version "1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-127" "1.3"))
        (sha256
          (base32 "0gjzz7q7frzd97i9skxragznm3as1423nng3kmgpgk1wmi4jmsi5"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-127"))
    (synopsis "SRFI-127: Lazy Sequences")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-127")
    (description "SRFI-127: Lazy Sequences")
    (license license:bsd-2)))

(define-public
  chicken-srfi-5
  (package
    (name "chicken-srfi-5")
    (version "0.3.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-5" "0.3.2"))
        (sha256
          (base32 "0n50xzkwq4mainjlzjihiqiknbyzx9js1d8d796hvcy9v613vivk"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-5"))
    (synopsis
      "SRFI-5: A compatible let form with signatures and rest arguments")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-5")
    (description
      "SRFI-5: A compatible let form with signatures and rest arguments")
    (license license:expat)))

(define-public
  chicken-defstruct
  (package
    (name "chicken-defstruct")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "defstruct" "2.0"))
        (sha256
          (base32 "1n8qy9bxlnacdq9gr4z4zjkwqsh9m34ij66qffah5nvqwskcavfy"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "defstruct"))
    (synopsis "A more convenient form of define-record")
    (home-page "https://wiki.call-cc.org/eggref/5/defstruct")
    (description "A more convenient form of define-record")
    (license license:bsd-2)))

(define-public
  chicken-compile-file
  (package
    (name "chicken-compile-file")
    (version "1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "compile-file" "1.3"))
        (sha256
          (base32 "1029i5ifr48vb3clvl8n50iq23rzc42szdcsl9320qmj1ksg9y93"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "compile-file"))
    (synopsis "Programmatic compiler invocation")
    (home-page "https://wiki.call-cc.org/eggref/5/compile-file")
    (description "Programmatic compiler invocation")
    (license license:bsd-2)))

(define-public
  chicken-lmdb
  (package
    (name "chicken-lmdb")
    (version "1.0.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "lmdb" "1.0.6"))
        (sha256
          (base32 "1ymy7ji9q7zvy8708f4zzavxkvajmq8l8m1z6v6873qkxgv6jkw8"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "lmdb"))
    (synopsis "Bindings to LMDB")
    (home-page "https://wiki.call-cc.org/eggref/5/lmdb")
    (description "Bindings to LMDB")
    (license license:openldap2.8)))

(define-public
  chicken-breadcrumbs
  (package
    (name "chicken-breadcrumbs")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "breadcrumbs" "1.2"))
        (sha256
          (base32 "1n60k0ryp447fh4f1an7ki8c1kc2ll1v1cbhgrxvmwcx3v03d767"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "breadcrumbs"))
    (synopsis "Breadcrumbs for web pages")
    (home-page "https://wiki.call-cc.org/eggref/5/breadcrumbs")
    (description "Breadcrumbs for web pages")
    (license license:bsd-2)))

(define-public
  chicken-micro-stats
  (package
    (name "chicken-micro-stats")
    (version "0.1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "micro-stats" "0.1.2"))
        (sha256
          (base32 "1y4lh2g8fvfi3wz9k0x00nq0n0w80rfrc69pmxhjrbg1w0arl83h"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-sequences" "chicken-sequences-utils")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "micro-stats"))
    (synopsis "Easily create micro-stats")
    (home-page "https://wiki.call-cc.org/eggref/5/micro-stats")
    (description "Easily create micro-stats")
    (license license:gpl3)))

(define-public
  chicken-this
  (package
    (name "chicken-this")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "this" "0.1"))
        (sha256
          (base32 "1gl2p50nc0zzpzwm6h9gxkpdhwnqmm92grsvr26cb2wrrxzj2ffy"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "this"))
    (synopsis "Python's \"this\" module ported to CHICKEN")
    (home-page "https://wiki.call-cc.org/eggref/5/this")
    (description "Python's \"this\" module ported to CHICKEN")
    (license license:bsd-2)))

(define-public
  chicken-shen
  (package
    (name "chicken-shen")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "shen" "0.1"))
        (sha256
          (base32 "1pdqfsi3n4g3glj9dw705l30vf5rgnjqfysz1hlf7pahr1sn3983"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-args"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-69")))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "shen"))
    (synopsis "Port of the Shen language for Chicken Scheme")
    (home-page "https://wiki.call-cc.org/eggref/5/shen")
    (description "Port of the Shen language for Chicken Scheme")
    (license license:bsd-2)))

(define-public
  chicken-ck-macros
  (package
    (name "chicken-ck-macros")
    (version "0.3.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ck-macros" "0.3.1"))
        (sha256
          (base32 "1xry5blp0vjmxidp47f9i8axji2q5f7csjkqi0n1gdwkm54755jz"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ck-macros"))
    (synopsis "Composable macros based on the CK abstract machine")
    (home-page "https://wiki.call-cc.org/eggref/5/ck-macros")
    (description "Composable macros based on the CK abstract machine")
    (license license:public-domain)))

(define-public
  chicken-slib-charplot
  (package
    (name "chicken-slib-charplot")
    (version "1.2.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "slib-charplot" "1.2.2"))
        (sha256
          (base32 "1ijcvs9y2vxmxg5834s4mprkinxhky0xdl3yksysmg9h9p82il2z"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-slib-arraymap"
              "chicken-srfi-63"
              "chicken-slib-compat")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "slib-charplot"))
    (synopsis "The SLIB character plotting library")
    (home-page "https://wiki.call-cc.org/eggref/5/slib-charplot")
    (description "The SLIB character plotting library")
    (license license:clarified-artistic)))

(define-public
  chicken-callable-data-structures
  (package
    (name "chicken-callable-data-structures")
    (version "1.0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "callable-data-structures" "1.0.3"))
        (sha256
          (base32 "1qqs3ycqg0bnq5ia3plw86vdv6fnk5d8c2l9bk06c0j4wqx4g9mp"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-69")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "callable-data-structures"))
    (synopsis "\"Callable\" data structures")
    (home-page "https://wiki.call-cc.org/eggref/5/callable-data-structures")
    (description "\"Callable\" data structures")
    (license license:bsd-2)))

(define-public
  chicken-srfi-128
  (package
    (name "chicken-srfi-128")
    (version "0.11")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-128" "0.11"))
        (sha256
          (base32 "00rb21x0fgli80gzs5hjszrwix198mp7az2c34m44sb3rjb9h3xw"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-128"))
    (synopsis "SRFI-128: Comparators (reduced)")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-128")
    (description "SRFI-128: Comparators (reduced)")
    (license license:bsd-2)))

(define-public
  chicken-trace
  (package
    (name "chicken-trace")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "trace" "2.0"))
        (sha256
          (base32 "1dcfpwnlmmmnfmzr7byml0ja9b36d6mggnw9mmrdv51q74pzkww3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-advice" "chicken-miscmacros")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "trace"))
    (synopsis "tracing and breakpoints")
    (home-page "https://wiki.call-cc.org/eggref/5/trace")
    (description "tracing and breakpoints")
    (license license:public-domain)))

(define-public
  chicken-postgresql
  (package
    (name "chicken-postgresql")
    (version "4.1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "postgresql" "4.1.4"))
        (sha256
          (base32 "06sqn5gz5n2zfdk5z2c20mz4r6w9mslxvlanvmq1wdzr5qnvkh9s"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-sql-null"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-69")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-18")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "postgresql"))
    (synopsis "Bindings for PostgreSQL's C-api")
    (home-page "https://wiki.call-cc.org/eggref/5/postgresql")
    (description "Bindings for PostgreSQL's C-api")
    (license license:bsd-2)))

(define-public
  chicken-format
  (package
    (name "chicken-format")
    (version "3.2.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "format" "3.2.3"))
        (sha256
          (base32 "0jrllvm63850q42w7kcc4zl0537fa7iffbj4mk336r4rfgp9yxxk"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "format"))
    (synopsis "Common-Lisp style formatted output")
    (home-page "https://wiki.call-cc.org/eggref/5/format")
    (description "Common-Lisp style formatted output")
    (license license:public-domain)))

(define-public
  chicken-srfi-78
  (package
    (name "chicken-srfi-78")
    (version "0.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-78" "0.5"))
        (sha256
          (base32 "0x50wcb0nsi5p355y0kma23y8wbikk3as2wlspwgfmp25g9ld0il"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-42")))
    (native-inputs
      (specifications->packages
        (list "chicken-r7rs" "chicken-srfi-13" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-78"))
    (synopsis "SRFI-78: Lightweight testing")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-78")
    (description "SRFI-78: Lightweight testing")
    (license license:expat)))

(define-public
  chicken-zmq
  (package
    (name "chicken-zmq")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "zmq" "0.2"))
        (sha256
          (base32 "04iyk76fi557r3y7wxhgr2kra0764qgcc84dar5pz3qjlql33bhq"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-18"
              "chicken-foreigners")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "zmq"))
    (synopsis "Bindings for the ZeroMQ API")
    (home-page "https://wiki.call-cc.org/eggref/5/zmq")
    (description "Bindings for the ZeroMQ API")
    (license license:lgpl3+)))

(define-public
  chicken-srfi-209
  (package
    (name "chicken-srfi-209")
    (version "1.3.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-209" "1.3.1"))
        (sha256
          (base32 "04fghjk0rfcz0fp71dvwvlxmxshrbmrs85g4l5cx8sp74y047qlv"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-69"
              "chicken-srfi-113"
              "chicken-srfi-128"
              "chicken-srfi-178"
              "chicken-typed-records")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-209"))
    (synopsis "SRFI 209: Enums and enum sets")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-209")
    (description "SRFI 209: Enums and enum sets")
    (license license:expat)))

(define-public
  chicken-continuations
  (package
    (name "chicken-continuations")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "continuations" "1.2"))
        (sha256
          (base32 "1grsf94zv8l3s1ypbc8qcwqvqan26s523x4cs0kpd3symm5b5xwk"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "continuations"))
    (synopsis "two continuation interfaces")
    (home-page "https://wiki.call-cc.org/eggref/5/continuations")
    (description "two continuation interfaces")
    (license license:bsd-2)))

(define-public
  chicken-genann
  (package
    (name "chicken-genann")
    (version "0.2.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "genann" "0.2.2"))
        (sha256
          (base32 "15q4ybxb04y4alkik99dkl5i3brh8dazahgmwjn51xk2s389gba1"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "genann"))
    (synopsis
      "Chicken bindings to genann - a simple neural network library in ANSI C")
    (home-page "https://wiki.call-cc.org/eggref/5/genann")
    (description
      "Chicken bindings to genann - a simple neural network library in ANSI C")
    (license license:zlib)))

(define-public
  chicken-fancypants
  (package
    (name "chicken-fancypants")
    (version "0.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "fancypants" "0.5"))
        (sha256
          (base32 "1pibvw1qzsb27411gajhk5m1kr8jvhdxk1l0dxhysd8kx5xjj862"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs
      (specifications->packages
        (list "chicken-sxml-transforms" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "fancypants"))
    (synopsis "Automatic ASCII smart quotes and ligature handling for SXML")
    (home-page "https://wiki.call-cc.org/eggref/5/fancypants")
    (description "Automatic ASCII smart quotes and ligature handling for SXML")
    (license license:bsd-2)))

(define-public
  chicken-ansi-escape-sequences
  (package
    (name "chicken-ansi-escape-sequences")
    (version "0.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ansi-escape-sequences" "0.6"))
        (sha256
          (base32 "1693zqbcva4h3562x3hmy7xpijc20yv1bmglz1hzr8jfm30hrc2p"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ansi-escape-sequences"))
    (synopsis "Procedures to generate ANSI escape sequences")
    (home-page "https://wiki.call-cc.org/eggref/5/ansi-escape-sequences")
    (description "Procedures to generate ANSI escape sequences")
    (license license:bsd-2)))

(define-public
  chicken-llrb-syntax
  (package
    (name "chicken-llrb-syntax")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "llrb-syntax" "0.2"))
        (sha256
          (base32 "1yn9ilxdx4cx1famay0rxkzljxs7vfdcqsv74lidqd84z39swy2c"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "llrb-syntax"))
    (synopsis "Expands LLRB code customized to data structures.")
    (home-page "https://wiki.call-cc.org/eggref/5/llrb-syntax")
    (description "Expands LLRB code customized to data structures.")
    (license license:bsd-2)))

(define-public
  chicken-webview
  (package
    (name "chicken-webview")
    (version "1.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "webview" "1.0.1"))
        (sha256
          (base32 "1xd7h0z2j5vfhckw28s52y752lyx77q8gqj9cwlrgxhhirylh5n6"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-18"
              "chicken-srfi-69"
              "chicken-utf8")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "webview"))
    (synopsis "Multi-platform HTML user interface shell")
    (home-page "https://wiki.call-cc.org/eggref/5/webview")
    (description "Multi-platform HTML user interface shell")
    (license license:bsd-2)))

(define-public
  chicken-error-utils
  (package
    (name "chicken-error-utils")
    (version "2.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "error-utils" "2.1.0"))
        (sha256
          (base32 "1s58jisckjzjf0v1cmr67ajzzs6dc67w0kzmynqpk9kwxd01asr5"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "error-utils"))
    (synopsis "Error Utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/error-utils")
    (description "Error Utilities")
    (license license:bsd-2)))

(define-public
  chicken-integer-map
  (package
    (name "chicken-integer-map")
    (version "1.0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "integer-map" "1.0.3"))
        (sha256
          (base32 "093d3dz892g3jw77fzdk5ayjz7qjs7mzd2knil7ci9zs5i8flxyi"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-128"
              "chicken-srfi-143"
              "chicken-srfi-158")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "integer-map"))
    (synopsis "SRFI 224 integer mappings")
    (home-page "https://wiki.call-cc.org/eggref/5/integer-map")
    (description "SRFI 224 integer mappings")
    (license license:expat)))

(define-public
  chicken-chicken-doc-html
  (package
    (name "chicken-chicken-doc-html")
    (version "0.3.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "chicken-doc-html" "0.3.1"))
        (sha256
          (base32 "0pl2fid82jx7h34y9fwfn8bwgjkh8rk13hd7mbqnrv74ga46l5yf"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-regex"
              "chicken-matchable"
              "chicken-sxml-transforms"
              "chicken-colorize"
              "chicken-svnwiki-sxml"
              "chicken-srfi-1"
              "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "chicken-doc-html"))
    (synopsis "Generate HTML from (svn)wiki SXML")
    (home-page "https://wiki.call-cc.org/eggref/5/chicken-doc-html")
    (description "Generate HTML from (svn)wiki SXML")
    (license license:bsd-2)))

(define-public
  chicken-clojurian
  (package
    (name "chicken-clojurian")
    (version "3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "clojurian" "3"))
        (sha256
          (base32 "0zmpld6j3zv91r8jwq83sz61495agddnmzqnx4qkclnb3wzvjw3f"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-18")))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "clojurian"))
    (synopsis "Syntax and utility functions inspired by Clojure")
    (home-page "https://wiki.call-cc.org/eggref/5/clojurian")
    (description "Syntax and utility functions inspired by Clojure")
    (license license:bsd-2)))

(define-public
  chicken-condition-utils
  (package
    (name "chicken-condition-utils")
    (version "2.2.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "condition-utils" "2.2.3"))
        (sha256
          (base32 "11mkmbyciyrqyakp1gyfvmbfayglhzx2x6j6zyp9kj31vhi2y4hd"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-69" "chicken-check-errors")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "condition-utils"))
    (synopsis "SRFI 12 Condition Utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/condition-utils")
    (description "SRFI 12 Condition Utilities")
    (license license:bsd-2)))

(define-public
  chicken-xlib
  (package
    (name "chicken-xlib")
    (version "1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "xlib" "1.3"))
        (sha256
          (base32 "17r7w5w7fwmhr5n37zq0yhg4s8pm8505lzal4mq7i2m6y591xfc0"))))
    (propagated-inputs
      (specifications->packages (list "chicken-matchable" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "xlib"))
    (synopsis "Xlib bindings")
    (home-page "https://wiki.call-cc.org/eggref/5/xlib")
    (description "Xlib bindings")
    (license license:unlicense)))

(define-public
  chicken-quasiwalk
  (package
    (name "chicken-quasiwalk")
    (version "1.10")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "quasiwalk" "1.10"))
        (sha256
          (base32 "1w9lvcqdipsmxzpg8ka7y2yy46vklbzad9lzkml873ijfn23bw27"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable" "chicken-brev-separate")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "quasiwalk"))
    (synopsis "A tree map that respects quote, quasiquote, and unquote")
    (home-page "https://wiki.call-cc.org/eggref/5/quasiwalk")
    (description "A tree map that respects quote, quasiquote, and unquote")
    (license license:bsd-1)))

(define-public
  chicken-simple-sequences
  (package
    (name "chicken-simple-sequences")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "simple-sequences" "1.0"))
        (sha256
          (base32 "06z122b53q32x4wzdhq71ksc51ydj6bwg7xxkmgdmsffv2pyyq1z"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "simple-sequences"))
    (synopsis "A common interface to sequences")
    (home-page "https://wiki.call-cc.org/eggref/5/simple-sequences")
    (description "A common interface to sequences")
    (license license:bsd-2)))

(define-public
  chicken-typed-records
  (package
    (name "chicken-typed-records")
    (version "0.82")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "typed-records" "0.82"))
        (sha256
          (base32 "0giy38ra6s6cq2qnpy7ljgal2wq3ckgxs9w81wivckyz66r5x6il"))))
    (propagated-inputs (specifications->packages (list "chicken-defstruct")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-compile-file")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "typed-records"))
    (synopsis "Typed variants of various record-definition macros")
    (home-page "https://wiki.call-cc.org/eggref/5/typed-records")
    (description "Typed variants of various record-definition macros")
    (license license:bsd-2)))

(define-public
  chicken-canvas-draw
  (package
    (name "chicken-canvas-draw")
    (version "1.1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "canvas-draw" "1.1.2"))
        (sha256
          (base32 "0pyk20rd1170h5k88jnm23qimwp37zq3kx94fvc3cpwk9cg1h7vd"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-13" "chicken-miscmacros")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "canvas-draw"))
    (synopsis "Bindings to the CD graphics library")
    (home-page "https://wiki.call-cc.org/eggref/5/canvas-draw")
    (description "Bindings to the CD graphics library")
    (license license:bsd-2)))

(define-public
  chicken-chickadee
  (package
    (name "chicken-chickadee")
    (version "0.12.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "chickadee" "0.12.2"))
        (sha256
          (base32 "0blbxy2l7kii85glczrxrqc8n7794qxswq67v0vl6hxajwij197i"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable"
              "chicken-uri-common"
              "chicken-uri-generic"
              "chicken-intarweb"
              "chicken-simple-sha1"
              "chicken-spiffy"
              "chicken-spiffy-request-vars"
              "chicken-sxml-transforms"
              "chicken-chicken-doc"
              "chicken-chicken-doc-admin"
              "chicken-chicken-doc-html"
              "chicken-srfi-18")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "chickadee"))
    (synopsis "chicken-doc web server")
    (home-page "https://wiki.call-cc.org/eggref/5/chickadee")
    (description "chicken-doc web server")
    (license license:bsd-2)))

(define-public
  chicken-base64
  (package
    (name "chicken-base64")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "base64" "1.0"))
        (sha256
          (base32 "102431jlwkgqjmx3qnsdiz52f7f6r74fh7z0svlnsia6nphsj4cw"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "base64"))
    (synopsis "Encoding and decoding of base64 strings")
    (home-page "https://wiki.call-cc.org/eggref/5/base64")
    (description "Encoding and decoding of base64 strings")
    (license license:bsd-2)))

(define-public
  chicken-ncurses
  (package
    (name "chicken-ncurses")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ncurses" "2.0"))
        (sha256
          (base32 "1cdkicn3zmb8vcnqwd4rk19ywc7kfj3zsmi2wl6g41b4gdyd3xw8"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-bind")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ncurses"))
    (synopsis "An interface to the UNIX ncurses package")
    (home-page "https://wiki.call-cc.org/eggref/5/ncurses")
    (description "An interface to the UNIX ncurses package")
    (license license:bsd-2)))

(define-public
  chicken-char-set-literals
  (package
    (name "chicken-char-set-literals")
    (version "0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "char-set-literals" "0.4"))
        (sha256
          (base32 "1im25d5wvw7c913k5rq7axq457mg6z4yg64mk74g95x5r177x45i"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-14")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "char-set-literals"))
    (synopsis
      "A reader extension providing Gauche style literals for SRFI-14 char-sets")
    (home-page "https://wiki.call-cc.org/eggref/5/char-set-literals")
    (description
      "A reader extension providing Gauche style literals for SRFI-14 char-sets")
    (license license:bsd-2)))

(define-public
  chicken-sqlite3pth
  (package
    (name "chicken-sqlite3pth")
    (version "0.2.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sqlite3pth" "0.2.6"))
        (sha256
          (base32 "0panyvq2s1frp9cbqfj7a5b374nadlx8wg0wkpz9f15jjdpsx4in"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-pthreads"
              "chicken-srfi-34"
              "chicken-llrb-tree"
              "chicken-miscmacros"
              "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sqlite3pth"))
    (synopsis
      "Run SQLite queries asynchronously in pthreads.  Supports calling Scheme from SQLite's VFS to supply database block storage.")
    (home-page "https://wiki.call-cc.org/eggref/5/sqlite3pth")
    (description
      "Run SQLite queries asynchronously in pthreads.  Supports calling Scheme from SQLite's VFS to supply database block storage.")
    (license license:bsd-2)))

(define-public
  chicken-beaker
  (package
    (name "chicken-beaker")
    (version "0.0.22")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "beaker" "0.0.22"))
        (sha256
          (base32 "1nxzqjwh3bi2zyifdpn0wb86352rizjpfl3lfi34f3g6m95avmmg"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-begin-syntax"
              "chicken-debugger-protocol"
              "chicken-schematic"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14"
              "chicken-srfi-69"
              "chicken-vector-lib"
              "chicken-with-current-directory")))
    (native-inputs
      (specifications->packages
        (list "chicken-ansi-escape-sequences"
              "chicken-scsh-process"
              "chicken-srfi-1"
              "chicken-test"
              "chicken-module-declarations")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "beaker"))
    (synopsis "Lab supplies for CHICKEN development")
    (home-page "https://wiki.call-cc.org/eggref/5/beaker")
    (description "Lab supplies for CHICKEN development")
    (license license:bsd-2)))

(define-public
  chicken-hypergiant
  (package
    (name "chicken-hypergiant")
    (version "0.5.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "hypergiant" "0.5.3"))
        (sha256
          (base32 "0a4slm7rdjcqdvq36vb1q6b8fabqd9375hb53y2q1a3vi6xldwwr"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-glfw3"
              "chicken-glls"
              "chicken-epoxy"
              "chicken-gl-math"
              "chicken-gl-utils"
              "chicken-gl-type"
              "chicken-hyperscene"
              "chicken-noise"
              "chicken-soil"
              "chicken-miscmacros"
              "chicken-srfi-18"
              "chicken-srfi-42"
              "chicken-srfi-99"
              "chicken-bitstring")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "hypergiant"))
    (synopsis "Game library")
    (home-page "https://wiki.call-cc.org/eggref/5/hypergiant")
    (description "Game library")
    (license license:bsd-2)))

(define-public
  chicken-medea
  (package
    (name "chicken-medea")
    (version "4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "medea" "4"))
        (sha256
          (base32 "1ad7x1sziynjjgxiv70ghbabc1mwa15mdx38wazfzn3nl7ma1hm6"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-comparse"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14"
              "chicken-srfi-69")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "medea"))
    (synopsis "A JSON parser (and emitter) built with comparse")
    (home-page "https://wiki.call-cc.org/eggref/5/medea")
    (description "A JSON parser (and emitter) built with comparse")
    (license license:bsd-2)))

(define-public
  chicken-define-options
  (package
    (name "chicken-define-options")
    (version "1.23")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "define-options" "1.23"))
        (sha256
          (base32 "1j9lj5kj3j8jhclxnxrrc2wn6qn9j0bhr2y9fydg05an9q7jmrh0"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-brev-separate"
              "chicken-getopt-long"
              "chicken-matchable"
              "chicken-quasiwalk"
              "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "define-options"))
    (synopsis "Conveniently bind to getopt-long options")
    (home-page "https://wiki.call-cc.org/eggref/5/define-options")
    (description "Conveniently bind to getopt-long options")
    (license license:lgpl3+)))

(define-public
  chicken-messages
  (package
    (name "chicken-messages")
    (version "0.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "messages" "0.7"))
        (sha256
          (base32 "08mnsyh7w0dvcx7qy21b4a91hnb4k8pam7jcscgpv8psflaaz27j"))))
    (propagated-inputs (specifications->packages (list "chicken-bindings")))
    (native-inputs
      (specifications->packages
        (list "chicken-checks" "chicken-simple-cells" "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "messages"))
    (synopsis "Creating algebraic- and abstract-types based on vectors")
    (home-page "https://wiki.call-cc.org/eggref/5/messages")
    (description "Creating algebraic- and abstract-types based on vectors")
    (license license:bsd-2)))

(define-public
  chicken-prefixes
  (package
    (name "chicken-prefixes")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "prefixes" "1.0"))
        (sha256
          (base32 "09xy34vz2w9ngi9z2yahv3fw5xiiy4xpdmf33zfvj46k7w5dahpn"))))
    (propagated-inputs
      (specifications->packages (list "chicken-tree-walkers")))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "prefixes"))
    (synopsis "prefixing in er-macro-transformers made easy")
    (home-page "https://wiki.call-cc.org/eggref/5/prefixes")
    (description "prefixing in er-macro-transformers made easy")
    (license license:bsd-2)))

(define-public
  chicken-define-er-syntax
  (package
    (name "chicken-define-er-syntax")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "define-er-syntax" "1.2"))
        (sha256
          (base32 "1chkfqzkx1v82knwx72nxgnaham1765gphlvyq4bv14nfd1syqjv"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable" "chicken-quasiwalk")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "define-er-syntax"))
    (synopsis "explicitly implicit renaming")
    (home-page "https://wiki.call-cc.org/eggref/5/define-er-syntax")
    (description "explicitly implicit renaming")
    (license license:bsd-1)))

(define-public
  chicken-cluckcheck
  (package
    (name "chicken-cluckcheck")
    (version "0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "cluckcheck" "0.0"))
        (sha256
          (base32 "1k8310b9c03rjb3cmfk3744nsjshh1yqdpycmlbzhnrdjivzm898"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "cluckcheck"))
    (synopsis "A Chicken Scheme port of the QuickCheck unit test framework")
    (home-page "https://wiki.call-cc.org/eggref/5/cluckcheck")
    (description "A Chicken Scheme port of the QuickCheck unit test framework")
    (license license:bsd-2)))

(define-public
  chicken-chalk
  (package
    (name "chicken-chalk")
    (version "0.3.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "chalk" "0.3.5"))
        (sha256
          (base32 "0p1lzxpbqyk8vqpc4600mjiaf3bvm2hlw1w6789b9l3fm972mp5m"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-13" "chicken-getopt-long")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "chalk"))
    (synopsis "Simple hahn-style in-source documentation")
    (home-page "https://wiki.call-cc.org/eggref/5/chalk")
    (description "Simple hahn-style in-source documentation")
    (license license:bsd-2)))

(define-public
  chicken-srfi-180
  (package
    (name "chicken-srfi-180")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-180" "1.0.0"))
        (sha256
          (base32 "0agky55bn26967nqcaa3n2a3rsr79brybizcivh34qna15gahq39"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-r7rs" "chicken-srfi-60" "chicken-srfi-145")))
    (native-inputs (specifications->packages (list "chicken-srfi-121")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-180"))
    (synopsis
      "This library describes a JavaScript Object Notation (JSON) parser and printer. It supports JSON that may be bigger than memory.")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-180")
    (description
      "This library describes a JavaScript Object Notation (JSON) parser and printer. It supports JSON that may be bigger than memory.")
    (license license:expat)))

(define-public
  chicken-edward
  (package
    (name "chicken-edward")
    (version "1.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "edward" "1.0.1"))
        (sha256
          (base32 "0gfvjgg6c6hl2xmh63067xkh0sd2vmczwisirgglcm2inz4hjll3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-r7rs"
              "chicken-srfi-1"
              "chicken-srfi-14"
              "chicken-srfi-37"
              "chicken-matchable"
              "chicken-posix-regex")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "edward"))
    (synopsis
      "An extensible implementation of the ed text editor as defined in POSIX.1-2008")
    (home-page "https://wiki.call-cc.org/eggref/5/edward")
    (description
      "An extensible implementation of the ed text editor as defined in POSIX.1-2008")
    (license license:gpl3)))

(define-public
  chicken-srfi-51
  (package
    (name "chicken-srfi-51")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-51" "0.2"))
        (sha256
          (base32 "17iv2n9pcdgsdqj5j96akmbnlz1rxc3l57yg9yrjp7fkh4gi02i8"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-51"))
    (synopsis "SRFI-51: Handling rest list")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-51")
    (description "SRFI-51: Handling rest list")
    (license license:expat)))

(define-public
  chicken-chibi-generic
  (package
    (name "chicken-chibi-generic")
    (version "0.1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "chibi-generic" "0.1.3"))
        (sha256
          (base32 "04048cksqnhyn0zcq0sdn426cj3fqfrj7xq464961jl72x8xqc5w"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "chibi-generic"))
    (synopsis "Chibi Scheme's simple generic function interface")
    (home-page "https://wiki.call-cc.org/eggref/5/chibi-generic")
    (description "Chibi Scheme's simple generic function interface")
    (license license:bsd-2)))

(define-public
  chicken-taglib
  (package
    (name "chicken-taglib")
    (version "0.2.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "taglib" "0.2.5"))
        (sha256
          (base32 "0hasfwd414n7g29jp3d2m5djrl2f8mvzmhh9fhs23q2bspyxpdjb"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "taglib"))
    (synopsis "Bindings to taglib")
    (home-page "https://wiki.call-cc.org/eggref/5/taglib")
    (description "Bindings to taglib")
    (license license:lgpl3+)))

(define-public
  chicken-getopt-long
  (package
    (name "chicken-getopt-long")
    (version "1.21")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "getopt-long" "1.21"))
        (sha256
          (base32 "0qp4wdpxmjbk14i80qn8g4lpppwy7qmazk3113m7ill60jz3459m"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14"
              "chicken-matchable")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-matchable")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "getopt-long"))
    (synopsis "Command line option parsing.")
    (home-page "https://wiki.call-cc.org/eggref/5/getopt-long")
    (description "Command line option parsing.")
    (license license:lgpl3)))

(define-public
  chicken-uri-generic
  (package
    (name "chicken-uri-generic")
    (version "3.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "uri-generic" "3.3"))
        (sha256
          (base32 "11k6qczmia6m77jgk80lphz83h12hd5h5cfzj8mllf7kv50il69g"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable" "chicken-srfi-1" "chicken-srfi-14")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "uri-generic"))
    (synopsis "URI generic syntax (RFC 3986) parsing and manipulation.")
    (home-page "https://wiki.call-cc.org/eggref/5/uri-generic")
    (description "URI generic syntax (RFC 3986) parsing and manipulation.")
    (license license:bsd-2)))

(define-public
  chicken-ezxdisp
  (package
    (name "chicken-ezxdisp")
    (version "3.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ezxdisp" "3.0"))
        (sha256
          (base32 "0aqa7z8gir1kz6s8azj508hav80ymrp2adwpxa44hw6bbalgfdh8"))))
    (propagated-inputs (specifications->packages (list "chicken-bind")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ezxdisp"))
    (synopsis "A simple 2D and 3D graphics library for X11")
    (home-page "https://wiki.call-cc.org/eggref/5/ezxdisp")
    (description "A simple 2D and 3D graphics library for X11")
    (license license:lgpl2.0)))

(define-public
  chicken-zxcvbn
  (package
    (name "chicken-zxcvbn")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "zxcvbn" "1.0.0"))
        (sha256
          (base32 "0hqhzlwlmngwd9sgkrrhmvfaq8gc7dc2c719y6h2ys3ahym4iaxn"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "zxcvbn"))
    (synopsis "zxcvbn password entropy estimation")
    (home-page "https://wiki.call-cc.org/eggref/5/zxcvbn")
    (description "zxcvbn password entropy estimation")
    (license license:bsd-2)))

(define-public
  chicken-hash-trie
  (package
    (name "chicken-hash-trie")
    (version "1.1.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "hash-trie" "1.1.8"))
        (sha256
          (base32 "1860bp5h3kh0ra6b2qvb5pccylajq1x2hng0skqnv8ik068lnfr0"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "hash-trie"))
    (synopsis "hash-trie")
    (home-page "https://wiki.call-cc.org/eggref/5/hash-trie")
    (description "hash-trie")
    (license license:expat)))

(define-public
  chicken-allegro
  (package
    (name "chicken-allegro")
    (version "3.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "allegro" "3.0.0"))
        (sha256
          (base32 "14w7q0iwskrqbqfjspf5wxnxb8wn56q9xbpc0vz518azm9ndf63p"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-foreigners")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "allegro"))
    (synopsis "Allegro")
    (home-page "https://wiki.call-cc.org/eggref/5/allegro")
    (description "Allegro")
    (license license:bsd-2)))

(define-public
  chicken-graph-scc
  (package
    (name "chicken-graph-scc")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "graph-scc" "2.0"))
        (sha256
          (base32 "0i5fpryziv0i2vwa8bjqbdvxzakhflra4z3amafjwsgrpc1x908a"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-queues"
              "chicken-iset"
              "chicken-matchable"
              "chicken-yasos"
              "chicken-digraph")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "graph-scc"))
    (synopsis "Compute strongly-connected components (SCC) of a graph.")
    (home-page "https://wiki.call-cc.org/eggref/5/graph-scc")
    (description "Compute strongly-connected components (SCC) of a graph.")
    (license license:gpl3)))

(define-public
  chicken-scheme2c-compatibility
  (package
    (name "chicken-scheme2c-compatibility")
    (version "1.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "scheme2c-compatibility" "1.8"))
        (sha256
          (base32 "1xj5j63bq1p69cily4dciqa105nkaj6gcfxf4d0r5ci8n7pwysv2"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14"
              "chicken-traversal"
              "chicken-foreigners"
              "chicken-xlib")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "scheme2c-compatibility"))
    (synopsis "Scheme->c compatibility package")
    (home-page "https://wiki.call-cc.org/eggref/5/scheme2c-compatibility")
    (description "Scheme->c compatibility package")
    (license license:lgpl3+)))

(define-public
  chicken-inotify
  (package
    (name "chicken-inotify")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "inotify" "1.1"))
        (sha256
          (base32 "0sr17i3sq85y90y005v6wrfnmchhmrmwz8cj74b0zl997ayla0jd"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-miscmacros"
              "chicken-queues"
              "chicken-srfi-18"
              "chicken-srfi-69")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "inotify"))
    (synopsis "Bindings to inotify")
    (home-page "https://wiki.call-cc.org/eggref/5/inotify")
    (description "Bindings to inotify")
    (license license:expat)))

(define-public
  chicken-svnwiki2html
  (package
    (name "chicken-svnwiki2html")
    (version "0.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "svnwiki2html" "0.0.2"))
        (sha256
          (base32 "014401nlkpz19bk8yk906p9i0b7ycs79rn7yq0zks8z09rgr9ghk"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-qwiki"
              "chicken-svnwiki-sxml"
              "chicken-sxml-transforms"
              "chicken-srfi-1"
              "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "svnwiki2html"))
    (synopsis "A program to convert svnwiki syntax to HTML")
    (home-page "https://wiki.call-cc.org/eggref/5/svnwiki2html")
    (description "A program to convert svnwiki syntax to HTML")
    (license license:bsd-2)))

(define-public
  chicken-srfi-117
  (package
    (name "chicken-srfi-117")
    (version "1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-117" "1.4"))
        (sha256
          (base32 "0pshy2rh32xskvi4pbbbxwzyw73jwn0j2r6gv683kdll3piz6zag"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-117"))
    (synopsis "SRFI-117: Mutable Queues")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-117")
    (description "SRFI-117: Mutable Queues")
    (license license:bsd-2)))

(define-public
  chicken-pyffi
  (package
    (name "chicken-pyffi")
    (version "3.14")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pyffi" "3.14"))
        (sha256
          (base32 "1a62kd4qscl16hqmbj94yvnwhfgh5dkpqkrrlpw9pa0ngfb8854v"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-69"
              "chicken-bind"
              "chicken-utf8")))
    (native-inputs
      (specifications->packages
        (list "chicken-brev-separate"
              "chicken-test"
              "chicken-compile-file"
              "chicken-pkg-config"
              "chicken-srfi-13")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pyffi"))
    (synopsis "An interface to the Python programming language.")
    (home-page "https://wiki.call-cc.org/eggref/5/pyffi")
    (description "An interface to the Python programming language.")
    (license license:gpl3)))

(define-public
  chicken-srfi-38
  (package
    (name "chicken-srfi-38")
    (version "0.9")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-38" "0.9"))
        (sha256
          (base32 "0pbys0xrzjdsvlwzpvm4sgca9ynxzw6ncmp8gbdxhmwbm1qf71l2"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-38"))
    (synopsis "A Chicken version of the SRFI-38 reference implementation")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-38")
    (description "A Chicken version of the SRFI-38 reference implementation")
    (license license:public-domain)))

(define-public
  chicken-socket
  (package
    (name "chicken-socket")
    (version "0.3.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "socket" "0.3.3"))
        (sha256
          (base32 "0s4d1m3h22raihjyyy1lbz942bra7izy5b370pwbrrp0ybg4rs8x"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-13"
              "chicken-srfi-18"
              "chicken-foreigners"
              "chicken-feature-test")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "socket"))
    (synopsis "Interface to the BSD socket API")
    (home-page "https://wiki.call-cc.org/eggref/5/socket")
    (description "Interface to the BSD socket API")
    (license license:bsd-2)))

(define-public
  chicken-simple-cells
  (package
    (name "chicken-simple-cells")
    (version "1.2.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "simple-cells" "1.2.2"))
        (sha256
          (base32 "1x9gajg12f03zz50bxypw08w801r3i1yrkvap8mb948wx0f8y0cg"))))
    (propagated-inputs (specifications->packages (list "chicken-checks")))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "simple-cells"))
    (synopsis
      "Implementation of typed cells to replace general set! operators")
    (home-page "https://wiki.call-cc.org/eggref/5/simple-cells")
    (description
      "Implementation of typed cells to replace general set! operators")
    (license license:bsd-2)))

(define-public
  chicken-simple-sha1
  (package
    (name "chicken-simple-sha1")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "simple-sha1" "1.2"))
        (sha256
          (base32 "0bmjxa5hwx5xsicf1l5wgmk000pc275d8l6jcy5mi4g80rwvjddl"))))
    (propagated-inputs
      (specifications->packages (list "chicken-memory-mapped-files")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "simple-sha1"))
    (synopsis
      "A fast and simple SHA1 implementation with minimal dependencies")
    (home-page "https://wiki.call-cc.org/eggref/5/simple-sha1")
    (description
      "A fast and simple SHA1 implementation with minimal dependencies")
    (license license:public-domain)))

(define-public
  chicken-imlib2
  (package
    (name "chicken-imlib2")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "imlib2" "1.2"))
        (sha256
          (base32 "0vgn8dczhlmjgzhlpsmzk69l4h33yxhmjmqnjg7zi77h2canv5sk"))))
    (propagated-inputs (specifications->packages (list "chicken-foreigners")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "imlib2"))
    (synopsis "Chicken bindings for the Imlib2 image library")
    (home-page "https://wiki.call-cc.org/eggref/5/imlib2")
    (description "Chicken bindings for the Imlib2 image library")
    (license license:bsd-2)))

(define-public
  chicken-fcp
  (package
    (name "chicken-fcp")
    (version "v0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "fcp" "v0.4"))
        (sha256
          (base32 "0kbqghyf1qjmhs6vx6pkzq3m0y4yv2wan69sxpry8h0dj2lmw5jb"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-18"
              "chicken-srfi-69"
              "chicken-base64"
              "chicken-regex"
              "chicken-matchable")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "fcp"))
    (synopsis "Very basic interface to freenet FCP")
    (home-page "https://wiki.call-cc.org/eggref/5/fcp")
    (description "Very basic interface to freenet FCP")
    (license license:bsd-2)))

(define-public
  chicken-locals
  (package
    (name "chicken-locals")
    (version "1.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "locals" "1.0.1"))
        (sha256
          (base32 "15wpww2qjv87k0j8lqvf4za16y7ip4s2949ax1h9ibfb4g21c11b"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "locals"))
    (synopsis "local declarations inspired by ML")
    (home-page "https://wiki.call-cc.org/eggref/5/locals")
    (description "local declarations inspired by ML")
    (license license:bsd-2)))

(define-public
  chicken-callable-sequences
  (package
    (name "chicken-callable-sequences")
    (version "1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "callable-sequences" "1.3"))
        (sha256
          (base32 "13sw9f3187h0f2dsjql8j3jij16w5jjdfd7d5wmihhh09n6fma1l"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages
        (list "chicken-simple-tests" "chicken-arrays")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "callable-sequences"))
    (synopsis
      "Common functional interface to sequential- and random-access sequences")
    (home-page "https://wiki.call-cc.org/eggref/5/callable-sequences")
    (description
      "Common functional interface to sequential- and random-access sequences")
    (license license:bsd-2)))

(define-public
  chicken-define-record-and-printer
  (package
    (name "chicken-define-record-and-printer")
    (version "0.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "define-record-and-printer" "0.2.0"))
        (sha256
          (base32 "1iz0j13bnjxbz2dck3bnc1q43dvx5np8lllws4bg9rgmn2x584x1"))))
    (propagated-inputs
      (specifications->packages (list "chicken-hahn" "chicken-matchable")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "define-record-and-printer"))
    (synopsis "Trivial macro to define records and appropriate printers")
    (home-page "https://wiki.call-cc.org/eggref/5/define-record-and-printer")
    (description "Trivial macro to define records and appropriate printers")
    (license license:bsd-2)))

(define-public
  chicken-srfi-152
  (package
    (name "chicken-srfi-152")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-152" "1.0"))
        (sha256
          (base32 "1flkxwcznxb4r5n88iam8wf47dqdps8a368mqs93shzy2v0rfmrc"))))
    (propagated-inputs (specifications->packages (list "chicken-utf8")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-152"))
    (synopsis "String library (reduced)")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-152")
    (description "String library (reduced)")
    (license license:expat)))

(define-public
  chicken-md5
  (package
    (name "chicken-md5")
    (version "4.1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "md5" "4.1.3"))
        (sha256
          (base32 "1crpkb0vzg26rk1w9xmswmx53bsira02hkixjspmfrrssdkvh5gv"))))
    (propagated-inputs
      (specifications->packages (list "chicken-message-digest-primitive")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-test-utils"
              "chicken-message-digest-utils"
              "chicken-message-digest-primitive")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "md5"))
    (synopsis "Computes MD5 (RFC1321) checksums")
    (home-page "https://wiki.call-cc.org/eggref/5/md5")
    (description "Computes MD5 (RFC1321) checksums")
    (license license:public-domain)))

(define-public
  chicken-geo-utils
  (package
    (name "chicken-geo-utils")
    (version "1.2.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "geo-utils" "1.2.2"))
        (sha256
          (base32 "0n0fsfna4amxqkfcrqmr7b468xqhs2m7pmqyxs0zllmpf9wn0hd7"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-vector-lib"
              "chicken-mathh"
              "chicken-check-errors"
              "chicken-symbol-utils")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "geo-utils"))
    (synopsis "Geographic Utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/geo-utils")
    (description "Geographic Utilities")
    (license license:bsd-2)))

(define-public
  chicken-abnf
  (package
    (name "chicken-abnf")
    (version "8.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "abnf" "8.3"))
        (sha256
          (base32 "08lmhd9ifhyhy73w7z25l6d5w036xa59sykwhlbar5rqs46pf019"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-utf8" "chicken-lexgen")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "abnf"))
    (synopsis "Parser combinators for Augmented BNF grammars (RFC 4234).")
    (home-page "https://wiki.call-cc.org/eggref/5/abnf")
    (description "Parser combinators for Augmented BNF grammars (RFC 4234).")
    (license license:gpl3)))

(define-public
  chicken-json-rpc
  (package
    (name "chicken-json-rpc")
    (version "0.4.5a")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "json-rpc" "0.4.5a"))
        (sha256
          (base32 "10f2iw93fhc0vha6axqzd27akh0ys7a6q0vwhpl0jzw4s48h3ss3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-r7rs"
              "chicken-srfi-1"
              "chicken-srfi-18"
              "chicken-srfi-69"
              "chicken-srfi-180"
              "chicken-utf8")))
    (native-inputs
      (specifications->packages
        (list "chicken-r7rs" "chicken-srfi-18" "chicken-srfi-64")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "json-rpc"))
    (synopsis "A JSON RPC library for R7RS scheme.")
    (home-page "https://wiki.call-cc.org/eggref/5/json-rpc")
    (description "A JSON RPC library for R7RS scheme.")
    (license license:expat)))

(define-public
  chicken-protobuf
  (package
    (name "chicken-protobuf")
    (version "1.2.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "protobuf" "1.2.3"))
        (sha256
          (base32 "0qwc8akm3ig6dxv7f0xp1cp19pcz4064bcndg24jjcf7bwq32b71"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-13"
              "chicken-srfi-18"
              "chicken-srfi-42"
              "chicken-srfi-69"
              "chicken-srfi-99")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "protobuf"))
    (synopsis "Protocol buffer serialization")
    (home-page "https://wiki.call-cc.org/eggref/5/protobuf")
    (description "Protocol buffer serialization")
    (license license:bsd-2)))

(define-public
  chicken-rb-tree
  (package
    (name "chicken-rb-tree")
    (version "6.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "rb-tree" "6.2"))
        (sha256
          (base32 "0nnmm6yixfwz2qfzygxrgpi822cxaqrd7gzaz91klb7vwgx7zxqf"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-datatype"
              "chicken-matchable"
              "chicken-yasos"
              "chicken-srfi-1")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "rb-tree"))
    (synopsis "A sorted dictionary data structure based on red-black trees.")
    (home-page "https://wiki.call-cc.org/eggref/5/rb-tree")
    (description
      "A sorted dictionary data structure based on red-black trees.")
    (license license:gpl3)))

(define-public
  chicken-dust
  (package
    (name "chicken-dust")
    (version "0.0.16")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "dust" "0.0.16"))
        (sha256
          (base32 "1r4yfs78az2p7szgsnlcnlfrqkivj9am7vm1sh2b29rjffkqnhp3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-http-client"
              "chicken-memory-mapped-files"
              "chicken-openssl"
              "chicken-posix-groups")))
    (native-inputs
      (specifications->packages
        (list "chicken-begin-syntax"
              "chicken-matchable"
              "chicken-module-declarations")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "dust"))
    (synopsis "Fetch and install CHICKEN versions")
    (home-page "https://wiki.call-cc.org/eggref/5/dust")
    (description "Fetch and install CHICKEN versions")
    (license license:bsd-2)))

(define-public
  chicken-llrb-tree
  (package
    (name "chicken-llrb-tree")
    (version "0.3.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "llrb-tree" "0.3.8"))
        (sha256
          (base32 "13qsba89mra5bs2gsv313dy6gvm3mzccl31gjh41wyk81xzaq434"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-128" "chicken-miscmacros")))
    (native-inputs (specifications->packages (list "chicken-llrb-syntax")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "llrb-tree"))
    (synopsis "LLRB tree general and customized to key types.")
    (home-page "https://wiki.call-cc.org/eggref/5/llrb-tree")
    (description "LLRB tree general and customized to key types.")
    (license license:bsd-2)))

(define-public
  chicken-endian-port
  (package
    (name "chicken-endian-port")
    (version "4.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "endian-port" "4.0"))
        (sha256
          (base32 "15lxd1k6c3dxr7hx5gg8x2hd9ss49dc2h8ixm85jkl91bws757rc"))))
    (propagated-inputs
      (specifications->packages (list "chicken-iset" "chicken-endian-blob")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "endian-port"))
    (synopsis "An I/O port that supports different endian formats.")
    (home-page "https://wiki.call-cc.org/eggref/5/endian-port")
    (description "An I/O port that supports different endian formats.")
    (license license:gpl3)))

(define-public
  chicken-sexpc
  (package
    (name "chicken-sexpc")
    (version "1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sexpc" "1.4"))
        (sha256
          (base32 "1qr93xrdxz0fl46j20rqfcqyx20mk3bsm5qcgxa93fpx9mgr1z02"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-brev-separate" "chicken-fmt" "chicken-tree")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sexpc"))
    (synopsis "Unix filter that turns sexps into C syntax")
    (home-page "https://wiki.call-cc.org/eggref/5/sexpc")
    (description "Unix filter that turns sexps into C syntax")
    (license license:bsd-1)))

(define-public
  chicken-brev
  (package
    (name "chicken-brev")
    (version "1.41")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "brev" "1.41"))
        (sha256
          (base32 "1kbphbz21rlrsfcfqg77hm1vv7wh9z1gcwh5lb2hlrqp2yl7m7yc"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-anaphora"
              "chicken-brev-separate"
              "chicken-clojurian"
              "chicken-combinators"
              "chicken-define-options"
              "chicken-dwim-sort"
              "chicken-fix-me-now"
              "chicken-acetone"
              "chicken-html-parser"
              "chicken-match-generics"
              "chicken-http-client"
              "chicken-matchable"
              "chicken-miscmacros"
              "chicken-scsh-process"
              "chicken-sequences"
              "chicken-srfi-1"
              "chicken-srfi-42"
              "chicken-srfi-69"
              "chicken-strse"
              "chicken-sxml-serializer"
              "chicken-sxml-transforms"
              "chicken-sxpath"
              "chicken-tree"
              "chicken-uri-common")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "brev"))
    (synopsis "A huge pile of batteries and shortcuts")
    (home-page "https://wiki.call-cc.org/eggref/5/brev")
    (description "A huge pile of batteries and shortcuts")
    (license license:public-domain)))

(define-public
  chicken-srfi-99
  (package
    (name "chicken-srfi-99")
    (version "1.4.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-99" "1.4.5"))
        (sha256
          (base32 "033hid04aaph0xmsc68r417dnjyswfqyd20y5cl4q3v8izqi54ks"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-69" "chicken-miscmacros")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-99"))
    (synopsis "SRFI-99 record types")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-99")
    (description "SRFI-99 record types")
    (license license:bsd-2)))

(define-public
  chicken-number-limits
  (package
    (name "chicken-number-limits")
    (version "3.0.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "number-limits" "3.0.8"))
        (sha256
          (base32 "134958zarw74yrxn97sixmm987b047p7izppc0cxx9rlviq145hd"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "number-limits"))
    (synopsis "Limit constants for numbers")
    (home-page "https://wiki.call-cc.org/eggref/5/number-limits")
    (description "Limit constants for numbers")
    (license license:bsd-2)))

(define-public
  chicken-rope
  (package
    (name "chicken-rope")
    (version "0.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "rope" "0.1.0"))
        (sha256
          (base32 "0pif66a3hj29var419pd4rdcisyz36ny9w9jrkkjdwig57qiawww"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "rope"))
    (synopsis "Heavyweight alternative to strings")
    (home-page "https://wiki.call-cc.org/eggref/5/rope")
    (description "Heavyweight alternative to strings")
    (license license:bsd-2)))

(define-public
  chicken-fast-generic
  (package
    (name "chicken-fast-generic")
    (version "0.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "fast-generic" "0.7"))
        (sha256
          (base32 "0rm0x6ncsjvjcqkcqhpn9p3fwsbmfsf0p06biiy5ljf71w67q37v"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-matchable")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "fast-generic"))
    (synopsis "fast-generic functions")
    (home-page "https://wiki.call-cc.org/eggref/5/fast-generic")
    (description "fast-generic functions")
    (license license:bsd-2)))

(define-public
  chicken-rabbit
  (package
    (name "chicken-rabbit")
    (version "2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "rabbit" "2.1"))
        (sha256
          (base32 "16iics3fiv0i9c011lcx3mqbf692gmk8chclrnx645s08gm75660"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "rabbit"))
    (synopsis "Rabbit stream cipher.")
    (home-page "https://wiki.call-cc.org/eggref/5/rabbit")
    (description "Rabbit stream cipher.")
    (license license:public-domain)))

(define-public
  chicken-iconv
  (package
    (name "chicken-iconv")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "iconv" "2.0"))
        (sha256
          (base32 "0bwna3hnimad68hp11mpdi74sv971iqrzdayzidwb2qslzd1b3kr"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "iconv"))
    (synopsis "Character-set conversions")
    (home-page "https://wiki.call-cc.org/eggref/5/iconv")
    (description "Character-set conversions")
    (license license:public-domain)))

(define-public
  chicken-unitconv
  (package
    (name "chicken-unitconv")
    (version "4.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "unitconv" "4.0"))
        (sha256
          (base32 "0lkz79dzds0vjjgfbi4sy9gq34xrdrlc3l57gzgbcd42jhbp0xaz"))))
    (propagated-inputs (specifications->packages (list "chicken-matchable")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "unitconv"))
    (synopsis "Conversion of units of measurement")
    (home-page "https://wiki.call-cc.org/eggref/5/unitconv")
    (description "Conversion of units of measurement")
    (license license:lgpl3)))

(define-public
  chicken-git
  (package
    (name "chicken-git")
    (version "0.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "git" "0.2.0"))
        (sha256
          (base32 "0cgab5wbcqqcxx771xvbyd06c3dz3ib8v2mpv21d2z6b48c9qin8"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-69")))
    (native-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-test"
              "chicken-with-current-directory"
              "chicken-foreigners"
              "chicken-module-declarations"
              "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "git"))
    (synopsis "libgit2 bindings")
    (home-page "https://wiki.call-cc.org/eggref/5/git")
    (description "libgit2 bindings")
    (license license:bsd-2)))

(define-public
  chicken-mpd-client
  (package
    (name "chicken-mpd-client")
    (version "2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "mpd-client" "2.1"))
        (sha256
          (base32 "059dbm63cklnfvycas7zi7n8hbl3c82k07b6z4rni9jqg3cbs879"))))
    (propagated-inputs
      (specifications->packages (list "chicken-regex" "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "mpd-client"))
    (synopsis "Interface to Music Player Daemon")
    (home-page "https://wiki.call-cc.org/eggref/5/mpd-client")
    (description "Interface to Music Player Daemon")
    (license license:bsd-2)))

(define-public
  chicken-transducers
  (package
    (name "chicken-transducers")
    (version "0.5.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "transducers" "0.5.4"))
        (sha256
          (base32 "1bz05dy7kjypk85yck3a8h6iji6kkmnb48kpqdqvj9nm0kvg2nwd"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-r7rs"
              "chicken-srfi-1"
              "chicken-srfi-128"
              "chicken-srfi-133"
              "chicken-srfi-146"
              "chicken-srfi-160"
              "chicken-check-errors")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "transducers"))
    (synopsis "Transducers for working with foldable data types.")
    (home-page "https://wiki.call-cc.org/eggref/5/transducers")
    (description "Transducers for working with foldable data types.")
    (license license:expat)))

(define-public
  chicken-srfi-63
  (package
    (name "chicken-srfi-63")
    (version "0.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-63" "0.5"))
        (sha256
          (base32 "1iszd74yfv215zmpr8i00cbhx4yni47zic14f7qvd0jp1pplhrlk"))))
    (propagated-inputs (specifications->packages (list "chicken-records")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-63"))
    (synopsis "Homogeneous and heterogeneous arrays")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-63")
    (description "Homogeneous and heterogeneous arrays")
    (license license:clarified-artistic)))

(define-public
  chicken-sql-de-lite
  (package
    (name "chicken-sql-de-lite")
    (version "0.10.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sql-de-lite" "0.10.1"))
        (sha256
          (base32 "1vx7j1y6b1wkhf3wn3bgf62a3zn3wk9clcygn80k4cjpma2p8ig5"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-foreigners"
              "chicken-object-evict"
              "chicken-srfi-1"
              "chicken-srfi-18"
              "chicken-srfi-69")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-compile-file")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sql-de-lite"))
    (synopsis "SQLite 3 interface")
    (home-page "https://wiki.call-cc.org/eggref/5/sql-de-lite")
    (description "SQLite 3 interface")
    (license license:bsd-2)))

(define-public
  chicken-npdiff
  (package
    (name "chicken-npdiff")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "npdiff" "2.0"))
        (sha256
          (base32 "08s172bggsa7hnfqyfbkvx9qz6q26qbaanhm86s3mcg6pf0bx10k"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-datatype" "chicken-yasos")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "npdiff"))
    (synopsis "Compute the longest common subsequence of two sequences")
    (home-page "https://wiki.call-cc.org/eggref/5/npdiff")
    (description "Compute the longest common subsequence of two sequences")
    (license license:gpl3)))

(define-public
  chicken-lsp-server
  (package
    (name "chicken-lsp-server")
    (version "0.4.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "lsp-server" "0.4.4"))
        (sha256
          (base32 "09fak8d29qmxynh4361prhfg971j74mha6pw311a6kmz88h9zp0h"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-apropos"
              "chicken-chicken-doc"
              "chicken-json-rpc"
              "chicken-nrepl"
              "chicken-r7rs"
              "chicken-srfi-1"
              "chicken-srfi-18"
              "chicken-srfi-69"
              "chicken-srfi-130"
              "chicken-srfi-133"
              "chicken-srfi-180"
              "chicken-uri-generic"
              "chicken-utf8")))
    (native-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-69" "chicken-srfi-64")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "lsp-server"
                 #:phases (modify-phases %standard-phases
                                         (delete 'check))))
    (synopsis "LSP Server for CHICKEN.")
    (home-page "https://wiki.call-cc.org/eggref/5/lsp-server")
    (description "LSP Server for CHICKEN.")
    (license license:expat)))

(define-public
  chicken-awful-sql-de-lite
  (package
    (name "chicken-awful-sql-de-lite")
    (version "0.7.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "awful-sql-de-lite" "0.7.1"))
        (sha256
          (base32 "15jhsp0bgrav2xy82fl7csgzvnchhm04ayr3wjr2dv1ki3fl430v"))))
    (propagated-inputs
      (specifications->packages (list "chicken-awful" "chicken-sql-de-lite")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "awful-sql-de-lite"))
    (synopsis "sql-de-lite support for awful")
    (home-page "https://wiki.call-cc.org/eggref/5/awful-sql-de-lite")
    (description "sql-de-lite support for awful")
    (license license:bsd-2)))

(define-public
  chicken-silex
  (package
    (name "chicken-silex")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "silex" "1.0"))
        (sha256
          (base32 "0ck8mgs2alvsial3ay9638ia2kl4zs63x6rc480p24sxhil6klg8"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "silex"))
    (synopsis "An efficient and powerful lexer generator")
    (home-page "https://wiki.call-cc.org/eggref/5/silex")
    (description "An efficient and powerful lexer generator")
    (license license:bsd-2)))

(define-public
  chicken-srfi-34
  (package
    (name "chicken-srfi-34")
    (version "0.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-34" "0.7"))
        (sha256
          (base32 "1f4jkj0s0ackppbjz2ysnzpms9y7jhz2sc0w6qwxq8cmb8ga1vbc"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-34"))
    (synopsis "SRFI-34: Exception Handling for Programs")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-34")
    (description "SRFI-34: Exception Handling for Programs")
    (license license:bsd-1)))

(define-public
  chicken-binary-search
  (package
    (name "chicken-binary-search")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "binary-search" "0.2"))
        (sha256
          (base32 "0hycs33782xvcc4p0jl2a716fi388v8vbvf9isgrnl9ahqnk9kia"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "binary-search"))
    (synopsis "Binary search algorithm")
    (home-page "https://wiki.call-cc.org/eggref/5/binary-search")
    (description "Binary search algorithm")
    (license license:bsd-2)))

(define-public
  chicken-bitwise-utils
  (package
    (name "chicken-bitwise-utils")
    (version "1.3.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "bitwise-utils" "1.3.1"))
        (sha256
          (base32 "1p433kx2q1zam5a2isgnxiywgkcb77bmbqlajpr7rvm5i739h8g7"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "bitwise-utils"))
    (synopsis "Bitwise utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/bitwise-utils")
    (description "Bitwise utilities")
    (license license:public-domain)))

(define-public
  chicken-coin-change
  (package
    (name "chicken-coin-change")
    (version "1.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "coin-change" "1.0.2"))
        (sha256
          (base32 "09p83afsh2dx4y2cpyi55bf2br03ysdpq9xrqik7fmks3913kxmk"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "coin-change"))
    (synopsis "Greedy solver for the coin change problem")
    (home-page "https://wiki.call-cc.org/eggref/5/coin-change")
    (description "Greedy solver for the coin change problem")
    (license license:unlicense)))

(define-public
  chicken-bloom-filter
  (package
    (name "chicken-bloom-filter")
    (version "2.3.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "bloom-filter" "2.3.4"))
        (sha256
          (base32 "1ljak0xscrywyl1sbv8yx9qkw1r2m94gyw3ag73p3z8m618valy3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-iset"
              "chicken-message-digest-primitive"
              "chicken-message-digest-type"
              "chicken-message-digest-utils"
              "chicken-check-errors")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-test-utils"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-sha1"
              "chicken-sha2"
              "chicken-md5"
              "chicken-tiger-hash"
              "chicken-ripemd")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "bloom-filter"))
    (synopsis "Bloom Filter")
    (home-page "https://wiki.call-cc.org/eggref/5/bloom-filter")
    (description "Bloom Filter")
    (license license:bsd-2)))

(define-public
  chicken-irc
  (package
    (name "chicken-irc")
    (version "1.9.9")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "irc" "1.9.9"))
        (sha256
          (base32 "0dxlfp0mn96pgimb6wf3mzqlm4jqz3f79sn9akqp03v9pqpszgyh"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable" "chicken-regex" "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "irc"))
    (synopsis "A simple IRC client")
    (home-page "https://wiki.call-cc.org/eggref/5/irc")
    (description "A simple IRC client")
    (license license:bsd-2)))

(define-public
  chicken-yasos
  (package
    (name "chicken-yasos")
    (version "1.14")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "yasos" "1.14"))
        (sha256
          (base32 "0q8cl3bvslk76l89k0vf836cb3xmd4kwvhgak38afsnrvirwiamn"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-69" "chicken-srfi-127")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "yasos"))
    (synopsis "A very simple OOP system")
    (home-page "https://wiki.call-cc.org/eggref/5/yasos")
    (description "A very simple OOP system")
    (license license:bsd-2)))

(define-public
  chicken-srfi-158
  (package
    (name "chicken-srfi-158")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-158" "0.1"))
        (sha256
          (base32 "02ayjw2rd8p0iiw97z2fvbxaq3v0x48afwsdcc9gahdl5bwvg2qd"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-158"))
    (synopsis "SRFI 158: Generators and Accumulators")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-158")
    (description "SRFI 158: Generators and Accumulators")
    (license license:expat)))

(define-public
  chicken-parley
  (package
    (name "chicken-parley")
    (version "1.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "parley" "1.0.1"))
        (sha256
          (base32 "10hb7a40lcy0mamwh2hcncdjracf5llq1pppafmgg9fcj8iav2pw"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-miscmacros"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-18"
              "chicken-srfi-71"
              "chicken-stty")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "parley"))
    (synopsis "A readline replacement written in scheme based on linenoise.")
    (home-page "https://wiki.call-cc.org/eggref/5/parley")
    (description
      "A readline replacement written in scheme based on linenoise.")
    (license license:bsd-2)))

(define-public
  chicken-srfi-123
  (package
    (name "chicken-srfi-123")
    (version "0.2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-123" "0.2.1"))
        (sha256
          (base32 "1kr576bs2yj72ay4445jd7872sd872k9b31b4rli33lprkgxj1pg"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-99" "chicken-box" "chicken-r7rs")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-123"))
    (synopsis "SRFI-123 - Generic accessor and modifier operations")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-123")
    (description "SRFI-123 - Generic accessor and modifier operations")
    (license license:expat)))

(define-public
  chicken-mini-kanren
  (package
    (name "chicken-mini-kanren")
    (version "1.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "mini-kanren" "1.2.0"))
        (sha256
          (base32 "036i34dzdnpb62951n7qh253q7gzg0rwhjj7nw1c43zn1hb5zw5j"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "mini-kanren"))
    (synopsis
      "Packages the canonical miniKanren implementation for CHICKEN Scheme.")
    (home-page "https://wiki.call-cc.org/eggref/5/mini-kanren")
    (description
      "Packages the canonical miniKanren implementation for CHICKEN Scheme.")
    (license license:expat)))

(define-public
  chicken-generics
  (package
    (name "chicken-generics")
    (version "2.0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "generics" "2.0.3"))
        (sha256
          (base32 "1fklbb5yjg8j56cvqbijirb2d0h5jqscp7219f67aln3lpq06dz6"))))
    (propagated-inputs
      (specifications->packages (list "chicken-simple-cells")))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "generics"))
    (synopsis "an implementation of generic functions and a lot of helpers")
    (home-page "https://wiki.call-cc.org/eggref/5/generics")
    (description "an implementation of generic functions and a lot of helpers")
    (license license:bsd-2)))

(define-public
  chicken-spiffy-cgi-handlers
  (package
    (name "chicken-spiffy-cgi-handlers")
    (version "0.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "spiffy-cgi-handlers" "0.7"))
        (sha256
          (base32 "0hy22mk56g039ykmqgdl5n5x9d7g9ihbf6qkzxazdff66ib19kz1"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-spiffy"
              "chicken-intarweb"
              "chicken-uri-common"
              "chicken-socket"
              "chicken-records"
              "chicken-srfi-1"
              "chicken-srfi-18"
              "chicken-srfi-13"
              "chicken-miscmacros")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "spiffy-cgi-handlers"))
    (synopsis "CGI and FastCGI handlers for a small but powerful web server.")
    (home-page "https://wiki.call-cc.org/eggref/5/spiffy-cgi-handlers")
    (description
      "CGI and FastCGI handlers for a small but powerful web server.")
    (license license:bsd-2)))

(define-public
  chicken-message-digest-primitive
  (package
    (name "chicken-message-digest-primitive")
    (version "4.3.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "message-digest-primitive" "4.3.8"))
        (sha256
          (base32 "1yc7b5zkwrqz4pc6y9fz4qgj8cgvmnfb30ad6slb5rl1vb6g5gjg"))))
    (propagated-inputs
      (specifications->packages (list "chicken-check-errors")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "message-digest-primitive"))
    (synopsis "Message Digest Primitive")
    (home-page "https://wiki.call-cc.org/eggref/5/message-digest-primitive")
    (description "Message Digest Primitive")
    (license license:bsd-2)))

(define-public
  chicken-patch
  (package
    (name "chicken-patch")
    (version "1.15")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "patch" "1.15"))
        (sha256
          (base32 "1qgbk91zbq4rxc2kvmczlflkjsym1x09i4g1bmcyfa2cds5rkmgx"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-regex")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "patch"))
    (synopsis "Simple source patch utility")
    (home-page "https://wiki.call-cc.org/eggref/5/patch")
    (description "Simple source patch utility")
    (license license:expat)))

(define-public
  chicken-termbox
  (package
    (name "chicken-termbox")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "termbox" "0.3"))
        (sha256
          (base32 "0d6zz6fr1nqznm1b10fyz0q71533qh7056ggx17flrnjlvxayb5f"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "termbox"))
    (synopsis "Minimal text based user interfaces. Bindings for nsf/termbox")
    (home-page "https://wiki.call-cc.org/eggref/5/termbox")
    (description
      "Minimal text based user interfaces. Bindings for nsf/termbox")
    (license license:expat)))

(define-public
  chicken-address-info
  (package
    (name "chicken-address-info")
    (version "1.0.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "address-info" "1.0.5"))
        (sha256
          (base32 "0vzrbzalqx3bv5nzq9rykfyhnrgnf2hlh55hi67pgync9z06v3jy"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "address-info"))
    (synopsis "Network address information access")
    (home-page "https://wiki.call-cc.org/eggref/5/address-info")
    (description "Network address information access")
    (license license:bsd-2)))

(define-public
  chicken-disjoint-set
  (package
    (name "chicken-disjoint-set")
    (version "0.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "disjoint-set" "0.1.0"))
        (sha256
          (base32 "0d1nfp2rd6nah5l07ijdhbzajnyvnrpfxd0kkph6kz6gc8v50qh7"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "disjoint-set"))
    (synopsis
      "Disjoint set implementation based on Scheme vectors and their indexes")
    (home-page "https://wiki.call-cc.org/eggref/5/disjoint-set")
    (description
      "Disjoint set implementation based on Scheme vectors and their indexes")
    (license license:unlicense)))

(define-public
  chicken-crc
  (package
    (name "chicken-crc")
    (version "1.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "crc" "1.0.2"))
        (sha256
          (base32 "085ggy01wvb6sf33r65m7d8kmh65h3zax4nsijsd9v1ax7m2lsm4"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "crc"))
    (synopsis "Computes CRC checksum")
    (home-page "https://wiki.call-cc.org/eggref/5/crc")
    (description "Computes CRC checksum")
    (license license:bsd-2)))

(define-public
  chicken-biglists
  (package
    (name "chicken-biglists")
    (version "0.4.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "biglists" "0.4.1"))
        (sha256
          (base32 "08qc2vsbc42c8108z50v2izkiwn5gd5hk7mjf8gbwy28p92gqh2x"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "biglists"))
    (synopsis "a uniform interface to lists and lazy-lists")
    (home-page "https://wiki.call-cc.org/eggref/5/biglists")
    (description "a uniform interface to lists and lazy-lists")
    (license license:bsd-2)))

(define-public
  chicken-cjson
  (package
    (name "chicken-cjson")
    (version "5.0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "cjson" "5.0.3"))
        (sha256
          (base32 "0hw8c9wm6d3l02bxsyhv3v6br47yq6azqpd3r55dwni6mma33b5y"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "cjson"))
    (synopsis "JSON parsing done in C. Sometimes a good idea.")
    (home-page "https://wiki.call-cc.org/eggref/5/cjson")
    (description "JSON parsing done in C. Sometimes a good idea.")
    (license license:bsd-2)))

(define-public
  chicken-loop
  (package
    (name "chicken-loop")
    (version "1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "loop" "1.5"))
        (sha256
          (base32 "1i4k4sy7hjc2djk1h0j46hzv3vn4qp280dzv7w3j9lx2pcpjs4gs"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "loop"))
    (synopsis "The Common Lisp LOOP macro")
    (home-page "https://wiki.call-cc.org/eggref/5/loop")
    (description "The Common Lisp LOOP macro")
    (license license:gpl2)))

(define-public
  chicken-schematic
  (package
    (name "chicken-schematic")
    (version "0.3.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "schematic" "0.3.2"))
        (sha256
          (base32 "03nn90fi18gn29vxvslyi5zxhl5hx2m7f7ikfy9a3ypnkw1bh8qk"))))
    (propagated-inputs
      (specifications->packages (list "chicken-optimism" "chicken-r7rs")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "schematic"))
    (synopsis "Tools for Scheme development")
    (home-page "https://wiki.call-cc.org/eggref/5/schematic")
    (description "Tools for Scheme development")
    (license license:bsd-2)))

(define-public
  chicken-zshbrev
  (package
    (name "chicken-zshbrev")
    (version "1.21")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "zshbrev" "1.21"))
        (sha256
          (base32 "1zmb84z22p8gv1bk05x7daqpl5h1z71hpivkyc1wbjfxyymmyaxj"))))
    (propagated-inputs (specifications->packages (list "chicken-brev")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "zshbrev"))
    (synopsis
      "Access Chicken functions from any shell and access zsh functions from Chicken")
    (home-page "https://wiki.call-cc.org/eggref/5/zshbrev")
    (description
      "Access Chicken functions from any shell and access zsh functions from Chicken")
    (license license:lgpl3)))

(define-public
  chicken-blob-utils
  (package
    (name "chicken-blob-utils")
    (version "2.0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "blob-utils" "2.0.4"))
        (sha256
          (base32 "0qp696595b46gygwf1cf0096sv5rxysgcn9yqwmbp8lxnl59p42n"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-string-utils" "chicken-check-errors")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "blob-utils"))
    (synopsis "Blob Utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/blob-utils")
    (description "Blob Utilities")
    (license license:bsd-2)))

(define-public
  chicken-dataframe
  (package
    (name "chicken-dataframe")
    (version "0.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "dataframe" "0.5"))
        (sha256
          (base32 "0wkm3hpv2wjqwwsnwnm2fsr3pcxxv4qxlb52wih5yk9rvrnafnb5"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-25"
              "chicken-srfi-69"
              "chicken-srfi-127"
              "chicken-utf8"
              "chicken-vector-lib"
              "chicken-yasos"
              "chicken-rb-tree"
              "chicken-fmt"
              "chicken-statistics")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "dataframe"))
    (synopsis "Tabular data structure for data analysis")
    (home-page "https://wiki.call-cc.org/eggref/5/dataframe")
    (description "Tabular data structure for data analysis")
    (license license:gpl3)))

(define-public
  chicken-pandoc
  (package
    (name "chicken-pandoc")
    (version "0.2.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pandoc" "0.2.3"))
        (sha256
          (base32 "034gmrir5bfffz7mybmd0b4k3yjvrc19gc5a086pxzcg6ijzbcyr"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-cjson"
              "chicken-http-client"
              "chicken-medea"
              "chicken-r7rs"
              "chicken-scsh-process")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pandoc"))
    (synopsis "Call upon Pandoc to parse documents into SXML")
    (home-page "https://wiki.call-cc.org/eggref/5/pandoc")
    (description "Call upon Pandoc to parse documents into SXML")
    (license license:expat)))

(define-public
  chicken-cmark
  (package
    (name "chicken-cmark")
    (version "0.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "cmark" "0.1.0"))
        (sha256
          (base32 "1rxyr6di07zqfjzbb0kgdx43m2b1zpjrkaph8x078jgqawyblc6v"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-lowdown")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "cmark"))
    (synopsis "A chicken wrapper for cmark with markdown to sxml capabilities")
    (home-page "https://wiki.call-cc.org/eggref/5/cmark")
    (description
      "A chicken wrapper for cmark with markdown to sxml capabilities")
    (license license:expat)))

(define-public
  chicken-uri-match
  (package
    (name "chicken-uri-match")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "uri-match" "1.0"))
        (sha256
          (base32 "0bkl82wjhiihk4ll1m5zddzcmhwswgp9n26gig7c606wyi76yw7s"))))
    (propagated-inputs (specifications->packages (list "chicken-uri-common")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "uri-match"))
    (synopsis "A flexible URI matcher")
    (home-page "https://wiki.call-cc.org/eggref/5/uri-match")
    (description "A flexible URI matcher")
    (license license:bsd-2)))

(define-public
  chicken-lazy-ffi
  (package
    (name "chicken-lazy-ffi")
    (version "1.8.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "lazy-ffi" "1.8.6"))
        (sha256
          (base32 "07fqnpa8jlalgasi0w859qry84qfdg0pb4892cjazsfl72ii5yhw"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-bind" "chicken-srfi-1" "chicken-srfi-69")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "lazy-ffi"))
    (synopsis "A foreign function interface for lazy programmers")
    (home-page "https://wiki.call-cc.org/eggref/5/lazy-ffi")
    (description "A foreign function interface for lazy programmers")
    (license license:bsd-2)))

(define-public
  chicken-call-table-generics
  (package
    (name "chicken-call-table-generics")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "call-table-generics" "1.2"))
        (sha256
          (base32 "1pkhgzwpl2k0lsshxmhy11v126nbpk28hjwv2d5fcnfam2lzf6kq"))))
    (propagated-inputs
      (specifications->packages (list "chicken-brev-separate")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "call-table-generics"))
    (synopsis "cond generics")
    (home-page "https://wiki.call-cc.org/eggref/5/call-table-generics")
    (description "cond generics")
    (license license:bsd-1)))

(define-public
  chicken-html-parser
  (package
    (name "chicken-html-parser")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "html-parser" "0.3"))
        (sha256
          (base32 "0qa09xnszyp3hfalacawr4hwlaxrr0g1iq617wxna036mjifg1rs"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "html-parser"))
    (synopsis "A permissive, scalable HTML parser.")
    (home-page "https://wiki.call-cc.org/eggref/5/html-parser")
    (description "A permissive, scalable HTML parser.")
    (license license:bsd-2)))

(define-public
  chicken-moremacros
  (package
    (name "chicken-moremacros")
    (version "2.5.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "moremacros" "2.5.3"))
        (sha256
          (base32 "0xwrsak9r77gyq85jhqj1hwjpmv897d8mgzqhw1q7br2clry44sk"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-69" "chicken-miscmacros" "chicken-check-errors")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "moremacros"))
    (synopsis "More miscellaneous macros")
    (home-page "https://wiki.call-cc.org/eggref/5/moremacros")
    (description "More miscellaneous macros")
    (license license:bsd-2)))

(define-public
  chicken-foof-loop
  (package
    (name "chicken-foof-loop")
    (version "9.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "foof-loop" "9.0"))
        (sha256
          (base32 "1d6h1l2f5ihw1qb788cyn2lgdyyir4w79vbdbdz6imchs8mnr6xn"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "foof-loop"))
    (synopsis "Extensible looping macros (originally based on Alex Shinn's)")
    (home-page "https://wiki.call-cc.org/eggref/5/foof-loop")
    (description
      "Extensible looping macros (originally based on Alex Shinn's)")
    (license license:public-domain)))

(define-public
  chicken-sequences-utils
  (package
    (name "chicken-sequences-utils")
    (version "0.5.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sequences-utils" "0.5.1"))
        (sha256
          (base32 "1r3wbvi502wm82zn78a2kw2dv1ya0msphhx42gb9wllxdhzz0d6l"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-69" "chicken-sequences")))
    (native-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sequences-utils"))
    (synopsis "(More) Generic sequence operators")
    (home-page "https://wiki.call-cc.org/eggref/5/sequences-utils")
    (description "(More) Generic sequence operators")
    (license license:bsd-2)))

(define-public
  chicken-gnuplot-pipe
  (package
    (name "chicken-gnuplot-pipe")
    (version "0.4.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "gnuplot-pipe" "0.4.2"))
        (sha256
          (base32 "10mnxnm91wji6glpc4bg2hhchgpj7ilgvskj5d5b3j9i5hd5xkzn"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "gnuplot-pipe"))
    (synopsis "A simple interface to Gnuplot")
    (home-page "https://wiki.call-cc.org/eggref/5/gnuplot-pipe")
    (description "A simple interface to Gnuplot")
    (license license:gpl3)))

(define-public
  chicken-states
  (package
    (name "chicken-states")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "states" "1.0"))
        (sha256
          (base32 "1l4h4l318rzrkfbq2s1cbinjwqxazclfpy1zznb03s3r0x3h9zrc"))))
    (propagated-inputs (specifications->packages (list "chicken-advice")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "states"))
    (synopsis "Simple Finite State Machine library")
    (home-page "https://wiki.call-cc.org/eggref/5/states")
    (description "Simple Finite State Machine library")
    (license license:public-domain)))

(define-public
  chicken-s11n
  (package
    (name "chicken-s11n")
    (version "0.9.12")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "s11n" "0.9.12"))
        (sha256
          (base32 "1vngrvh2b7rv5n5zvksfg27zikpc7d8xb8n1kd0pyfr7hna00wf9"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-miscmacros" "chicken-matchable" "chicken-srfi-69")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "s11n"))
    (synopsis "Serialization of arbitrary data.")
    (home-page "https://wiki.call-cc.org/eggref/5/s11n")
    (description "Serialization of arbitrary data.")
    (license license:bsd-2)))

(define-public
  chicken-holes
  (package
    (name "chicken-holes")
    (version "1.2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "holes" "1.2.1"))
        (sha256
          (base32 "01zgr5w3msk7s45y7s3js3nwfa6j3wfxf9ijn6ymlrkac96jmiv3"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "holes"))
    (synopsis "partial expressions as procedures with named parameters")
    (home-page "https://wiki.call-cc.org/eggref/5/holes")
    (description "partial expressions as procedures with named parameters")
    (license license:bsd-2)))

(define-public
  chicken-scss
  (package
    (name "chicken-scss")
    (version "4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "scss" "4"))
        (sha256
          (base32 "0asc4lp83ylx2qz5y0svfdws2adm88vbhb69z0lflakbdj9mrqax"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-matchable")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "scss"))
    (synopsis "unknown")
    (home-page "https://wiki.call-cc.org/eggref/5/scss")
    (description "unknown")
    (license license:bsd-2)))

(define-public
  chicken-json-utils
  (package
    (name "chicken-json-utils")
    (version "1.1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "json-utils" "1.1.1"))
        (sha256
          (base32 "1m67ri4b2awnmsmva1613cnsp94v0w73qxw4myyhglrnkam4xlcc"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-utf8"
              "chicken-srfi-1"
              "chicken-srfi-69"
              "chicken-vector-lib"
              "chicken-miscmacros"
              "chicken-moremacros")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "json-utils"))
    (synopsis "JSON Utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/json-utils")
    (description "JSON Utilities")
    (license license:bsd-2)))

(define-public
  chicken-heap-o-rama
  (package
    (name "chicken-heap-o-rama")
    (version "0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "heap-o-rama" "0.4"))
        (sha256
          (base32 "10jys007s16cr3sz9ca5ip93gz7m29mjxsifpaafsyfbpg4n9p88"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-18")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "heap-o-rama"))
    (synopsis "...")
    (home-page "https://wiki.call-cc.org/eggref/5/heap-o-rama")
    (description "...")
    (license license:bsd-2)))

(define-public
  chicken-iset
  (package
    (name "chicken-iset")
    (version "2.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "iset" "2.2"))
        (sha256
          (base32 "1z59w289416wpf7i62gry6fyglgn6cip4zvffxd64yw9wgyzcjzc"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "iset"))
    (synopsis "Integer sets")
    (home-page "https://wiki.call-cc.org/eggref/5/iset")
    (description "Integer sets")
    (license license:bsd-2)))

(define-public
  chicken-awful
  (package
    (name "chicken-awful")
    (version "1.0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "awful" "1.0.3"))
        (sha256
          (base32 "1i20ib8kx2hjggi18xn72lwxaa2q38bmmffsm06s1cxrfh58s5gz"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-json"
              "chicken-http-session"
              "chicken-spiffy"
              "chicken-spiffy-cookies"
              "chicken-spiffy-request-vars"
              "chicken-sxml-transforms"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-69")))
    (native-inputs
      (specifications->packages
        (list "chicken-http-client" "chicken-server-test" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "awful"))
    (synopsis
      "awful provides an application and an extension to ease the development of web-based applications.")
    (home-page "https://wiki.call-cc.org/eggref/5/awful")
    (description
      "awful provides an application and an extension to ease the development of web-based applications.")
    (license license:bsd-2)))

(define-public
  chicken-tree
  (package
    (name "chicken-tree")
    (version "1.50")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "tree" "1.50"))
        (sha256
          (base32 "1bmipwxg1r5fyxfskgrpr5ivprc3s70vdcc5vm8i6mp2cfn8dmxz"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-42"
              "chicken-srfi-69"
              "chicken-srfi-71")))
    (native-inputs (specifications->packages (list "chicken-miscmacros")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "tree"))
    (synopsis "A tree utility library")
    (home-page "https://wiki.call-cc.org/eggref/5/tree")
    (description "A tree utility library")
    (license license:expat)))

(define-public
  chicken-fx-utils
  (package
    (name "chicken-fx-utils")
    (version "4.0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "fx-utils" "4.0.3"))
        (sha256
          (base32 "0kbk7cm5ss00582nvgfq25zcgf07z417c5jf0flva4csm37rb6hf"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "fx-utils"))
    (synopsis "fx utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/fx-utils")
    (description "fx utilities")
    (license license:bsd-2)))

(define-public
  chicken-math-utils
  (package
    (name "chicken-math-utils")
    (version "1.0.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "math-utils" "1.0.6"))
        (sha256
          (base32 "1jcr67q4pq7i34lkhbqml18rkv6w61wsqclp9k1xgvg6p2b0aaxj"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-test-utils" "chicken-vector-lib")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "math-utils"))
    (synopsis "Miscellaneous math utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/math-utils")
    (description "Miscellaneous math utilities")
    (license license:public-domain)))

(define-public
  chicken-list-utils
  (package
    (name "chicken-list-utils")
    (version "2.6.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "list-utils" "2.6.0"))
        (sha256
          (base32 "1llnf0qrssw4vpwvp17ir7558q0d1xyyb14zydcrnb9nhbzly5jr"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-utf8" "chicken-srfi-1" "chicken-check-errors")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "list-utils"))
    (synopsis "list-utils")
    (home-page "https://wiki.call-cc.org/eggref/5/list-utils")
    (description "list-utils")
    (license license:bsd-2)))

(define-public
  chicken-srfi-69
  (package
    (name "chicken-srfi-69")
    (version "0.4.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-69" "0.4.3"))
        (sha256
          (base32 "12qgj5wqj9xxkh0ff48a540v4gd8a91w4rvay6ri5sv8piq8nnzx"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-69"))
    (synopsis "SRFI-69 hash-table library")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-69")
    (description "SRFI-69 hash-table library")
    (license license:bsd-2)))

(define-public
  chicken-commands
  (package
    (name "chicken-commands")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "commands" "1.0.0"))
        (sha256
          (base32 "13y49vrkd9rs98s9fk10g8w056xb9nnqxwn1372sayw64789i3ib"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "commands"))
    (synopsis "Helpers for programs that dispatch commands")
    (home-page "https://wiki.call-cc.org/eggref/5/commands")
    (description "Helpers for programs that dispatch commands")
    (license license:bsd-2)))

(define-public
  chicken-srfi-143
  (package
    (name "chicken-srfi-143")
    (version "0.4.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-143" "0.4.1"))
        (sha256
          (base32 "0a30ysddklf2mndh5chhkdx5zqlkgyxggwxypgn7znmny23zlrja"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-143"))
    (synopsis "SRFI 143: Fixnums")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-143")
    (description "SRFI 143: Fixnums")
    (license license:expat)))

(define-public
  chicken-awful-salmonella-tar
  (package
    (name "chicken-awful-salmonella-tar")
    (version "0.0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "awful-salmonella-tar" "0.0.4"))
        (sha256
          (base32 "1zqzhafsbc64y344pax7z68vxfigwd8rcmgafqp6knn948lamrb3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-awful" "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "awful-salmonella-tar"))
    (synopsis "Serve salmonella report files out of tar archives")
    (home-page "https://wiki.call-cc.org/eggref/5/awful-salmonella-tar")
    (description "Serve salmonella report files out of tar archives")
    (license license:bsd-2)))

(define-public
  chicken-srfi-216
  (package
    (name "chicken-srfi-216")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-216" "0.1"))
        (sha256
          (base32 "0mq8frv16bx8jvvj0j0yvbnpwwh5kixvzhdnp427vvxhsfvrjk70"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-18")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-216"))
    (synopsis "SRFI 216: SICP Prerequisites")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-216")
    (description "SRFI 216: SICP Prerequisites")
    (license license:expat)))

(define-public
  chicken-kiwi
  (package
    (name "chicken-kiwi")
    (version "1.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "kiwi" "1.0.2"))
        (sha256
          (base32 "00r9020pz5x6w9zca4qx9n6n2sj9yny0zn41fnr47gsx91mxv2qb"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-69"
              "chicken-clojurian"
              "chicken-matchable")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "kiwi"))
    (synopsis "Bindings to the KiWi library")
    (home-page "https://wiki.call-cc.org/eggref/5/kiwi")
    (description "Bindings to the KiWi library")
    (license license:zlib)))

(define-public
  chicken-spiffy-directory-listing
  (package
    (name "chicken-spiffy-directory-listing")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "spiffy-directory-listing" "0.3"))
        (sha256
          (base32 "1jpvskqc2vx7f01vc4wj3kl2kqb53b6x33xm6qi6v947k8has49y"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages
        (list "chicken-spiffy" "chicken-sxml-transforms")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "spiffy-directory-listing"))
    (synopsis "Flexible directory listing for Spiffy")
    (home-page "https://wiki.call-cc.org/eggref/5/spiffy-directory-listing")
    (description "Flexible directory listing for Spiffy")
    (license license:bsd-2)))

(define-public
  chicken-gl-type
  (package
    (name "chicken-gl-type")
    (version "0.4.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "gl-type" "0.4.0"))
        (sha256
          (base32 "1x5krxmvkpv52qnyp241x1vs6ws67lgb79zs0v5p0hbdh8mr8h4r"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-freetype"
              "chicken-miscmacros"
              "chicken-epoxy"
              "chicken-gl-utils"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "gl-type"))
    (synopsis "Freetype font rendering in OpenGL")
    (home-page "https://wiki.call-cc.org/eggref/5/gl-type")
    (description "Freetype font rendering in OpenGL")
    (license license:bsd-2)))

(define-public
  chicken-srfi-145
  (package
    (name "chicken-srfi-145")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-145" "0.1"))
        (sha256
          (base32 "1jxabczdgw3dd49rvg5gdhghhcw0iclvdpm1j9psl80r2brjwnxr"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-145"))
    (synopsis "SRFI 145: Assumptions")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-145")
    (description "SRFI 145: Assumptions")
    (license license:expat)))

(define-public
  chicken-geminih
  (package
    (name "chicken-geminih")
    (version "1.13")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "geminih" "1.13"))
        (sha256
          (base32 "1i2nmzk61szkpg0a2r4i6gx00hnj78b3dqkk34y349h29dm2jv56"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-clojurian"
              "chicken-acetone"
              "chicken-anaphora"
              "chicken-html-parser"
              "chicken-strse"
              "chicken-match-generics"
              "chicken-brev-separate"
              "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "geminih"))
    (synopsis "Gemtext to SXML")
    (home-page "https://wiki.call-cc.org/eggref/5/geminih")
    (description "Gemtext to SXML")
    (license license:bsd-1)))

(define-public
  chicken-remote-mailbox
  (package
    (name "chicken-remote-mailbox")
    (version "1.0.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "remote-mailbox" "1.0.7"))
        (sha256
          (base32 "1jm9ybxji5i06vdrh39biiwyhk8cyxxhh4gnbxa66xv7h5n5dmhn"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-tcp-server"
              "chicken-s11n"
              "chicken-mailbox"
              "chicken-srfi-18"
              "chicken-synch"
              "chicken-miscmacros"
              "chicken-moremacros"
              "chicken-llrb-tree"
              "chicken-condition-utils"
              "chicken-check-errors")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "remote-mailbox"))
    (synopsis "Remote Mailbox")
    (home-page "https://wiki.call-cc.org/eggref/5/remote-mailbox")
    (description "Remote Mailbox")
    (license license:bsd-2)))

(define-public
  chicken-oauth
  (package
    (name "chicken-oauth")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "oauth" "0.3"))
        (sha256
          (base32 "1afqv4acx1682ph81ggkpa6rrv0wyzg9094ab4xx12ygkiib8g2f"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-uri-common"
              "chicken-intarweb"
              "chicken-http-client"
              "chicken-hmac"
              "chicken-sha1"
              "chicken-base64")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "oauth"))
    (synopsis "OAuth 1.0, 1.0a, RFC 5849")
    (home-page "https://wiki.call-cc.org/eggref/5/oauth")
    (description "OAuth 1.0, 1.0a, RFC 5849")
    (license license:bsd-2)))

(define-public
  chicken-vector-lib
  (package
    (name "chicken-vector-lib")
    (version "2.1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "vector-lib" "2.1.1"))
        (sha256
          (base32 "071nx5m5q7j55mv4ikikffd1b2m7xfkbm21rjffg8gz6qwqa851z"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "vector-lib"))
    (synopsis "Port of the SRFI-43 reference implementation")
    (home-page "https://wiki.call-cc.org/eggref/5/vector-lib")
    (description "Port of the SRFI-43 reference implementation")
    (license license:bsd-2)))

(define-public
  chicken-srfi-1
  (package
    (name "chicken-srfi-1")
    (version "0.5.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-1" "0.5.1"))
        (sha256
          (base32 "03cjp5dvclwkqxr7kp486smagfh44jzzs5k61wkk1k8p7qhcm4k5"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-1"))
    (synopsis "SRFI-1 list library")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-1")
    (description "SRFI-1 list library")
    (license license:bsd-2)))

(define-public
  chicken-hyde
  (package
    (name "chicken-hyde")
    (version "4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "hyde" "4"))
        (sha256
          (base32 "1wb0qla9bbr55iw3z502b6chfb7vzjf3h0b5hy2anl7vic4dn8ar"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-sxml-transforms"
              "chicken-doctype"
              "chicken-matchable"
              "chicken-scss"
              "chicken-spiffy"
              "chicken-colorize"
              "chicken-intarweb"
              "chicken-uri-common"
              "chicken-svnwiki-sxml"
              "chicken-defstruct"
              "chicken-sxpath"
              "chicken-html-parser"
              "chicken-atom"
              "chicken-rfc3339"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-18"
              "chicken-srfi-69")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "hyde"))
    (synopsis "A static website compiler")
    (home-page "https://wiki.call-cc.org/eggref/5/hyde")
    (description "A static website compiler")
    (license license:bsd-2)))

(define-public
  chicken-transmission
  (package
    (name "chicken-transmission")
    (version "0.3.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "transmission" "0.3.0"))
        (sha256
          (base32 "1483d5kz13zvrqpacvb7lfvc178x3j9236vmdv37ndsvjfy7m6fc"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-http-client"
              "chicken-intarweb"
              "chicken-medea"
              "chicken-r7rs"
              "chicken-srfi-1"
              "chicken-srfi-189"
              "chicken-uri-common")))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "transmission"))
    (synopsis "Transmission RPC")
    (home-page "https://wiki.call-cc.org/eggref/5/transmission")
    (description "Transmission RPC")
    (license license:unlicense)))

(define-public
  chicken-zlib
  (package
    (name "chicken-zlib")
    (version "0.7.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "zlib" "0.7.0"))
        (sha256
          (base32 "0m3kkspj2l4ssl82gx058h747xmbhm66cxc1z0908b0pjkw5byx7"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-foreigners" "chicken-miscmacros")))
    (native-inputs
      (specifications->packages
        (list "chicken-simple-sha1"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "zlib"))
    (synopsis "Bindings for zlib")
    (home-page "https://wiki.call-cc.org/eggref/5/zlib")
    (description "Bindings for zlib")
    (license license:gpl3)))

(define-public
  chicken-scsh-process
  (package
    (name "chicken-scsh-process")
    (version "1.6.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "scsh-process" "1.6.0"))
        (sha256
          (base32 "1fn99ncj7d4qgj92pmm77mvmar2ki5q8k8qgsi8nfs56xr7gr5lm"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-18" "chicken-llrb-tree")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "scsh-process"))
    (synopsis "A reimplementation for CHICKEN of SCSH's process notation.")
    (home-page "https://wiki.call-cc.org/eggref/5/scsh-process")
    (description "A reimplementation for CHICKEN of SCSH's process notation.")
    (license license:bsd-2)))

(define-public
  chicken-test-new-egg
  (package
    (name "chicken-test-new-egg")
    (version "1.0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "test-new-egg" "1.0.4"))
        (sha256
          (base32 "01m7bi646f0ypv5j1zpsw16fk4rzw3lmycxlhkzzb11ghlgl2vqq"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-henrietta-cache"
              "chicken-salmonella"
              "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "test-new-egg"))
    (synopsis
      "A tool to test new eggs before they are added to the official CHICKEN repository")
    (home-page "https://wiki.call-cc.org/eggref/5/test-new-egg")
    (description
      "A tool to test new eggs before they are added to the official CHICKEN repository")
    (license license:bsd-2)))

(define-public
  chicken-srfi-13
  (package
    (name "chicken-srfi-13")
    (version "0.3.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-13" "0.3.4"))
        (sha256
          (base32 "11d8qlvsykp2mz2vwxmk19x1zl5b5fymhvgznsrfjl429z5xai94"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-14")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-13"))
    (synopsis "SRFI-13 string library")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-13")
    (description "SRFI-13 string library")
    (license license:bsd-2)))

(define-public
  chicken-srfi-189
  (package
    (name "chicken-srfi-189")
    (version "1.0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-189" "1.0.3"))
        (sha256
          (base32 "0vdp1sia7anpnvj2rryb1j933n62flwq34iladxymfwgx178fmaa"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-typed-records")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-189"))
    (synopsis "SRFI 189: Maybe and Either")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-189")
    (description "SRFI 189: Maybe and Either")
    (license license:expat)))

(define-public
  chicken-preserve
  (package
    (name "chicken-preserve")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "preserve" "1.1"))
        (sha256
          (base32 "0nabvcf0aqz66x8vjbf6j7q1mpl65xbk8i55crydxnwnaq4jnf8r"))))
    (propagated-inputs
      (specifications->packages (list "chicken-brev-separate")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "preserve"))
    (synopsis "Cache a procedure for a set time")
    (home-page "https://wiki.call-cc.org/eggref/5/preserve")
    (description "Cache a procedure for a set time")
    (license license:public-domain)))

(define-public
  chicken-srfi-203
  (package
    (name "chicken-srfi-203")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-203" "0.1"))
        (sha256
          (base32 "0f31r0722h5nhw5xc3695ccps54jv5jl160s78c4gpjps3rlqfga"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-203"))
    (synopsis "SRFI 203: A Simple Picture Language in the Style of SICP")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-203")
    (description "SRFI 203: A Simple Picture Language in the Style of SICP")
    (license license:bsd-2)))

(define-public
  chicken-udp
  (package
    (name "chicken-udp")
    (version "1.18")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "udp" "1.18"))
        (sha256
          (base32 "1f4m1jj0r5wm5akd6q7cfnc0fwgw0kwkqr4l5n40vbgcwp8gvm7k"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-srfi-18")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "udp"))
    (synopsis "An interface to User Datagram Protocol sockets")
    (home-page "https://wiki.call-cc.org/eggref/5/udp")
    (description "An interface to User Datagram Protocol sockets")
    (license license:bsd-2)))

(define-public
  chicken-test-generative
  (package
    (name "chicken-test-generative")
    (version "0.0.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "test-generative" "0.0.6"))
        (sha256
          (base32 "1r7sx789ha7ajnpb3zgjryhjfmhy6i1dpblkjfxdbmk2sz4py9lf"))))
    (propagated-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "test-generative"))
    (synopsis "Allows quickcheck like testing for pure code with the test egg")
    (home-page "https://wiki.call-cc.org/eggref/5/test-generative")
    (description
      "Allows quickcheck like testing for pure code with the test egg")
    (license license:gpl3)))

(define-public
  chicken-matrico
  (package
    (name "chicken-matrico")
    (version "0.5rel")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "matrico" "0.5rel"))
        (sha256
          (base32 "0ng09xbk8229nhq4s8f8rxgrgigf81qr685mggvk2lm5p7kckpjq"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "matrico"))
    (synopsis "A flonum matrix module for CHICKEN Scheme.")
    (home-page "https://wiki.call-cc.org/eggref/5/matrico")
    (description "A flonum matrix module for CHICKEN Scheme.")
    (license license:zlib)))

(define-public
  chicken-gemrefinder
  (package
    (name "chicken-gemrefinder")
    (version "1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "gemrefinder" "1.5"))
        (sha256
          (base32 "0zb0yxmiz513c2fxy2kgv454kgynavwlxryfgrzgiamz04sca2r3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-scsh-process"
              "chicken-srfi-1"
              "chicken-srfi-42"
              "chicken-define-options"
              "chicken-combinators"
              "chicken-brev-separate"
              "chicken-match-generics"
              "chicken-strse")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "gemrefinder"))
    (synopsis "Checks Gemini space for replies to your posts")
    (home-page "https://wiki.call-cc.org/eggref/5/gemrefinder")
    (description "Checks Gemini space for replies to your posts")
    (license license:agpl3+)))

(define-public
  chicken-memcached
  (package
    (name "chicken-memcached")
    (version "1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "memcached" "1.5"))
        (sha256
          (base32 "1n6y2bgwc7bxcd8mv6zrq4d09659bx664m8v6zvj4c67dqrcrrd8"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-base64" "chicken-srfi-13" "chicken-srfi-14")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "memcached"))
    (synopsis "Client interface to the Memcached protocol.")
    (home-page "https://wiki.call-cc.org/eggref/5/memcached")
    (description "Client interface to the Memcached protocol.")
    (license license:bsd-2)))

(define-public
  chicken-vectr
  (package
    (name "chicken-vectr")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "vectr" "0.1"))
        (sha256
          (base32 "0a97mg94l03npnlds7c8f63d9nhvr2rfjnk0p1mgqpmvq396kf0g"))))
    (propagated-inputs (specifications->packages (list "chicken-coops")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "vectr"))
    (synopsis "A linear vectr library.")
    (home-page "https://wiki.call-cc.org/eggref/5/vectr")
    (description "A linear vectr library.")
    (license license:gpl3)))

(define-public
  chicken-srfi-130
  (package
    (name "chicken-srfi-130")
    (version "2.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-130" "2.0.1"))
        (sha256
          (base32 "1ks5l3f41d6fn49cjk7dz1wbv10x5aa7cmyg2cm49scyr7gixi9a"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-typed-records"
              "chicken-utf8")))
    (native-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-test" "chicken-test-generative")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-130"))
    (synopsis "SRFI-130: Cursor-based string library")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-130")
    (description "SRFI-130: Cursor-based string library")
    (license license:expat)))

(define-public
  chicken-simple-logger
  (package
    (name "chicken-simple-logger")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "simple-logger" "1.0.0"))
        (sha256
          (base32 "05d9fjn6m9m8c4n2blig844vhv9cp1rmyrcxnkzxfxxiw9y4wfhf"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "simple-logger"))
    (synopsis "A very simple logger")
    (home-page "https://wiki.call-cc.org/eggref/5/simple-logger")
    (description "A very simple logger")
    (license license:bsd-2)))

(define-public
  chicken-hmac
  (package
    (name "chicken-hmac")
    (version "7.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "hmac" "7.2.0"))
        (sha256
          (base32 "005xj5cndfxzwr7l7xiaybzgghzwp4b4812i3vw090igg7sl8mlg"))))
    (propagated-inputs
      (specifications->packages (list "chicken-message-digest")))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-sha1" "chicken-string-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "hmac"))
    (synopsis "HMAC provides a HMAC using the message-digest interface.")
    (home-page "https://wiki.call-cc.org/eggref/5/hmac")
    (description "HMAC provides a HMAC using the message-digest interface.")
    (license license:bsd-2)))

(define-public
  chicken-acetone
  (package
    (name "chicken-acetone")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "acetone" "1.2"))
        (sha256
          (base32 "0qyvv15zd3pfcyg8p6pgb3nn4sx0h0lsyiljwvb4lpb5p6xwygz8"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-match-generics"
              "chicken-srfi-1"
              "chicken-brev-separate")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "acetone"))
    (synopsis "A simple parser")
    (home-page "https://wiki.call-cc.org/eggref/5/acetone")
    (description "A simple parser")
    (license license:bsd-1)))

(define-public
  chicken-chicken-belt
  (package
    (name "chicken-chicken-belt")
    (version "0.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "chicken-belt" "0.1.0"))
        (sha256
          (base32 "0xxq4383gircmnaqyjwx1ckr07x5m51h1rx6dbxvsb79pn53cpv9"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable" "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "chicken-belt"))
    (synopsis "A utility belt for managing your CHICKEN coop")
    (home-page "https://wiki.call-cc.org/eggref/5/chicken-belt")
    (description "A utility belt for managing your CHICKEN coop")
    (license license:bsd-2)))

(define-public
  chicken-image-dimensions
  (package
    (name "chicken-image-dimensions")
    (version "1.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "image-dimensions" "1.0.1"))
        (sha256
          (base32 "0f451j8y8hyhbda12b8jj68gxjqmg24piwwk7vk8p66y0n7mslhk"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "image-dimensions"))
    (synopsis "Detect image dimensions for common formats")
    (home-page "https://wiki.call-cc.org/eggref/5/image-dimensions")
    (description "Detect image dimensions for common formats")
    (license license:expat)))

(define-public
  chicken-scm2wiki
  (package
    (name "chicken-scm2wiki")
    (version "0.3.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "scm2wiki" "0.3.2"))
        (sha256
          (base32 "0f8zwxkskzlillnbyngzgaqqgxviimn52rscj6vxx9hgl2yw3mkk"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14"
              "chicken-args"
              "chicken-comparse")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-coops")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "scm2wiki"))
    (synopsis "An auto-documentation tool for CHICKEN Scheme.")
    (home-page "https://wiki.call-cc.org/eggref/5/scm2wiki")
    (description "An auto-documentation tool for CHICKEN Scheme.")
    (license license:expat)))

(define-public
  chicken-stb-image-write
  (package
    (name "chicken-stb-image-write")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "stb-image-write" "0.3"))
        (sha256
          (base32 "0477v02icjgvbsna0wh3hqapiz1hpggwrm3wi11104kin8jh0kl1"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "stb-image-write"))
    (synopsis "write png/jpg/tga/bmp images")
    (home-page "https://wiki.call-cc.org/eggref/5/stb-image-write")
    (description "write png/jpg/tga/bmp images")
    (license license:public-domain)))

(define-public
  chicken-http-client
  (package
    (name "chicken-http-client")
    (version "1.2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "http-client" "1.2.1"))
        (sha256
          (base32 "0d24dpi8c45rvwfm31hd033rpyghx9xps1qdki8czcl6500bcy7y"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-intarweb"
              "chicken-uri-common"
              "chicken-simple-md5"
              "chicken-sendfile"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-18"
              "chicken-srfi-69")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "http-client"))
    (synopsis "High-level HTTP client library")
    (home-page "https://wiki.call-cc.org/eggref/5/http-client")
    (description "High-level HTTP client library")
    (license license:bsd-2)))

(define-public
  chicken-qwiki
  (package
    (name "chicken-qwiki")
    (version "2.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "qwiki" "2.2"))
        (sha256
          (base32 "14m75v6a2bfqag646zx95hqhn6g16dm921klkmj1xvf8f19nf2mb"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-intarweb"
              "chicken-uri-common"
              "chicken-spiffy"
              "chicken-sxml-transforms"
              "chicken-svn-client"
              "chicken-estraier-client"
              "chicken-sxpath"
              "chicken-simple-sha1"
              "chicken-svnwiki-sxml"
              "chicken-html-parser"
              "chicken-colorize"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "qwiki"))
    (synopsis "qwiki - the quick wiki")
    (home-page "https://wiki.call-cc.org/eggref/5/qwiki")
    (description "qwiki - the quick wiki")
    (license license:bsd-2)))

(define-public
  chicken-posix-utils
  (package
    (name "chicken-posix-utils")
    (version "2.1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "posix-utils" "2.1.1"))
        (sha256
          (base32 "0l9yd1cqlj3wpddnky38lqiisq2m88gjyc053xmazsdbakg6622h"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-utf8" "chicken-check-errors")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "posix-utils"))
    (synopsis "posix-utils")
    (home-page "https://wiki.call-cc.org/eggref/5/posix-utils")
    (description "posix-utils")
    (license license:bsd-2)))

(define-public
  chicken-posix-shm
  (package
    (name "chicken-posix-shm")
    (version "1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "posix-shm" "1.4"))
        (sha256
          (base32 "12rljfwpq1jax439jhcvmyjz6ijra1wis8nysi0sbnmdzlm3w3gd"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-compile-file")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "posix-shm"))
    (synopsis "POSIX shared memory API")
    (home-page "https://wiki.call-cc.org/eggref/5/posix-shm")
    (description "POSIX shared memory API")
    (license license:bsd-2)))

(define-public
  chicken-miscmacros
  (package
    (name "chicken-miscmacros")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "miscmacros" "1.0"))
        (sha256
          (base32 "0xs8ksnbpxm0a1s2bcqybliaqpr5agin4ksn3hyjwniqhzx4qzg8"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "miscmacros"))
    (synopsis "Various helper macros")
    (home-page "https://wiki.call-cc.org/eggref/5/miscmacros")
    (description "Various helper macros")
    (license license:bsd-2)))

(define-public
  chicken-matchable
  (package
    (name "chicken-matchable")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "matchable" "1.2"))
        (sha256
          (base32 "1c7c61wivhn8qrj5rfivr2f0ffjgl4ccd6chk9p705rynjiv7pw0"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "matchable"))
    (synopsis "Hygienic MATCH replacement")
    (home-page "https://wiki.call-cc.org/eggref/5/matchable")
    (description "Hygienic MATCH replacement")
    (license license:public-domain)))

(define-public
  chicken-srfi-45
  (package
    (name "chicken-srfi-45")
    (version "4.0.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-45" "4.0.7"))
        (sha256
          (base32 "0sygx2pd8d2j8q9n9xz4hdlbnn7amm7za4ibpk0wssyf02r6y5a3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-record-variants" "chicken-check-errors")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-45"))
    (synopsis "SRFI-45: Primitives for Expressing Iterative Lazy Algorithms")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-45")
    (description
      "SRFI-45: Primitives for Expressing Iterative Lazy Algorithms")
    (license license:bsd-2)))

(define-public
  chicken-awful-sqlite3
  (package
    (name "chicken-awful-sqlite3")
    (version "0.7.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "awful-sqlite3" "0.7.0"))
        (sha256
          (base32 "1gvn7x8q822sq48zllbnpqw88898rjmkvy8qin9mzzf86y08ky8g"))))
    (propagated-inputs
      (specifications->packages (list "chicken-awful" "chicken-sqlite3")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "awful-sqlite3"))
    (synopsis "Sqlite3 support for awful")
    (home-page "https://wiki.call-cc.org/eggref/5/awful-sqlite3")
    (description "Sqlite3 support for awful")
    (license license:bsd-2)))

(define-public
  chicken-egg-tarballs
  (package
    (name "chicken-egg-tarballs")
    (version "0.10.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "egg-tarballs" "0.10.0"))
        (sha256
          (base32 "0sribz131y1q9x86zfgwjqpjhmz62f2jn41cv8d5s1q4bfpv4xkw"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-simple-sha1" "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "egg-tarballs"))
    (synopsis "Creates tarballs for eggs in henrietta cache")
    (home-page "https://wiki.call-cc.org/eggref/5/egg-tarballs")
    (description "Creates tarballs for eggs in henrietta cache")
    (license license:bsd-2)))

(define-public
  chicken-srfi-14
  (package
    (name "chicken-srfi-14")
    (version "0.2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-14" "0.2.1"))
        (sha256
          (base32 "1sjcnkn08knbcy7hvqsqiin693a73hw0r159xi7l5l6hgvlml4qp"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-14"))
    (synopsis "SRFI-14 character-sets library")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-14")
    (description "SRFI-14 character-sets library")
    (license license:bsd-2)))

(define-public
  chicken-stfl
  (package
    (name "chicken-stfl")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "stfl" "1.1"))
        (sha256
          (base32 "1j63kcj1sq8mr6hb37xskd8c6807nzgs2wf97i8yaxw456s1v57k"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "stfl"))
    (synopsis "Bindings to the STFL curses widget library")
    (home-page "https://wiki.call-cc.org/eggref/5/stfl")
    (description "Bindings to the STFL curses widget library")
    (license license:gpl3)))

(define-public
  chicken-cis
  (package
    (name "chicken-cis")
    (version "1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "cis" "1.4"))
        (sha256
          (base32 "0cipkar25s3gzgzg6sy5547b6da665ln610c71zscz37f4q6wjm8"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "cis"))
    (synopsis "Compact integer sets.")
    (home-page "https://wiki.call-cc.org/eggref/5/cis")
    (description "Compact integer sets.")
    (license license:lgpl3)))

(define-public
  chicken-srfi-47
  (package
    (name "chicken-srfi-47")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-47" "2.0"))
        (sha256
          (base32 "1kjvqza95qwkwr6basar56vph9lpmm6y4ayp49wd3n1jnfdxkj1d"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-47"))
    (synopsis "SRFI-47: Arrays")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-47")
    (description "SRFI-47: Arrays")
    (license license:bsd-2)))

(define-public
  chicken-interfaces
  (package
    (name "chicken-interfaces")
    (version "0.4.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "interfaces" "0.4.1"))
        (sha256
          (base32 "08yjwfy2cmk23j60p611gnjz4kgph1rl583xkp80vy2fsg01dnqv"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "interfaces"))
    (synopsis "Simple interface/implementation abstraction")
    (home-page "https://wiki.call-cc.org/eggref/5/interfaces")
    (description "Simple interface/implementation abstraction")
    (license license:public-domain)))

(define-public
  chicken-semantic-version
  (package
    (name "chicken-semantic-version")
    (version "0.0.16")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "semantic-version" "0.0.16"))
        (sha256
          (base32 "10wczj83664q09zxgcnf1zr96xds6dmfvn0gvw8cq4i269ppcv0j"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-utf8"
              "chicken-srfi-1"
              "chicken-vector-lib"
              "chicken-srfi-69"
              "chicken-srfi-128"
              "chicken-record-variants")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "semantic-version"))
    (synopsis "Semantic Version Utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/semantic-version")
    (description "Semantic Version Utilities")
    (license license:bsd-2)))

(define-public
  chicken-optimism
  (package
    (name "chicken-optimism")
    (version "0.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "optimism" "0.1.0"))
        (sha256
          (base32 "0sw7sxx530bpgl8spxq0k9ry044k8nsn85y4xip0vhwcprjkqhmk"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "optimism"))
    (synopsis "Command line option handling")
    (home-page "https://wiki.call-cc.org/eggref/5/optimism")
    (description "Command line option handling")
    (license license:public-domain)))

(define-public
  chicken-gl-math
  (package
    (name "chicken-gl-math")
    (version "0.9.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "gl-math" "0.9.1"))
        (sha256
          (base32 "043587v0mm9lisy7vacg0z18fnabviwj5cmk1gd2y05d3zqbf4dz"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-matchable")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "gl-math"))
    (synopsis "A small gamedev-oriented math library")
    (home-page "https://wiki.call-cc.org/eggref/5/gl-math")
    (description "A small gamedev-oriented math library")
    (license license:bsd-2)))

(define-public
  chicken-stemmer
  (package
    (name "chicken-stemmer")
    (version "0.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "stemmer" "0.0.2"))
        (sha256
          (base32 "17b9f9dswsd2zwhxwxigcaqpjyj7ppzxzk20ip5nh0884s976j6m"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "stemmer"))
    (synopsis "Bindings for the Snowball project's libstemmer")
    (home-page "https://wiki.call-cc.org/eggref/5/stemmer")
    (description "Bindings for the Snowball project's libstemmer")
    (license license:bsd-2)))

(define-public
  chicken-envsubst
  (package
    (name "chicken-envsubst")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "envsubst" "1.0.0"))
        (sha256
          (base32 "1wvfdkafhqi2m1qdap8da5yf6148yy2mrcmjl8lb811rvffbqld7"))))
    (propagated-inputs (specifications->packages (list "chicken-matchable")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "envsubst"))
    (synopsis "Simple templating with parameter expansion")
    (home-page "https://wiki.call-cc.org/eggref/5/envsubst")
    (description "Simple templating with parameter expansion")
    (license license:bsd-2)))

(define-public
  chicken-srfi-41
  (package
    (name "chicken-srfi-41")
    (version "2.1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-41" "2.1.5"))
        (sha256
          (base32 "017qpy23mq2h7pd70j5wgq570z29qpnl8fw0j272kr6g5ndhmbbp"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-record-variants"
              "chicken-check-errors")))
    (native-inputs
      (specifications->packages
        (list "chicken-test-utils" "chicken-check-errors")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-41"))
    (synopsis "SRFI 41 (Streams)")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-41")
    (description "SRFI 41 (Streams)")
    (license license:bsd-2)))

(define-public
  chicken-getopt-utils
  (package
    (name "chicken-getopt-utils")
    (version "1.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "getopt-utils" "1.2.0"))
        (sha256
          (base32 "1992zcps7gghhc9l7sfkglmf2rqgwvw6jz39k7q9mbs690chq1l1"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-utf8" "chicken-srfi-1" "chicken-getopt-long")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "getopt-utils"))
    (synopsis "Utilities for getopt-long")
    (home-page "https://wiki.call-cc.org/eggref/5/getopt-utils")
    (description "Utilities for getopt-long")
    (license license:bsd-2)))

(define-public
  chicken-hyperscene
  (package
    (name "chicken-hyperscene")
    (version "0.4.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "hyperscene" "0.4.0"))
        (sha256
          (base32 "1v2l36f5ymvc3bslh462lcmnjdkv26xmlqr3fr2rifc0yrwry6bp"))))
    (propagated-inputs (specifications->packages (list "chicken-miscmacros")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "hyperscene"))
    (synopsis "Scene graph and spatial partitioning")
    (home-page "https://wiki.call-cc.org/eggref/5/hyperscene")
    (description "Scene graph and spatial partitioning")
    (license license:bsd-2)))

(define-public
  chicken-salmonella
  (package
    (name "chicken-salmonella")
    (version "3.1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "salmonella" "3.1.1"))
        (sha256
          (base32 "1r60dlr1qcjlirbwqpn23aphczlkhrhskgqmw51973w46ww839nf"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "salmonella"))
    (synopsis "A tool for testing eggs")
    (home-page "https://wiki.call-cc.org/eggref/5/salmonella")
    (description "A tool for testing eggs")
    (license license:bsd-2)))

(define-public
  chicken-F-operator
  (package
    (name "chicken-F-operator")
    (version "4.1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "F-operator" "4.1.4"))
        (sha256
          (base32 "0i7yfc8pxszvsgls871s2bwy11yxyxr4sqbl8gc21g29xm7vjivq"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-miscmacros" "chicken-datatype" "chicken-box")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-test-utils"
              "chicken-utf8"
              "chicken-srfi-1"
              "chicken-srfi-18")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "F-operator"))
    (synopsis "Shift/Reset Control Operators")
    (home-page "https://wiki.call-cc.org/eggref/5/F-operator")
    (description "Shift/Reset Control Operators")
    (license license:bsd-2)))

(define-public
  chicken-r6rs-bytevectors
  (package
    (name "chicken-r6rs-bytevectors")
    (version "0.1.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "r6rs-bytevectors" "0.1.7"))
        (sha256
          (base32 "1qah1bym1q3ww0fkyqvz048q9brv7ffsz2x3cqpx0cp7yk41by9m"))))
    (propagated-inputs (specifications->packages (list "chicken-utf8")))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-srfi-1" "chicken-utf8")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "r6rs-bytevectors"))
    (synopsis "An implementation of r6rs bytevectors")
    (home-page "https://wiki.call-cc.org/eggref/5/r6rs-bytevectors")
    (description "An implementation of r6rs bytevectors")
    (license license:expat)))

(define-public
  chicken-isaac
  (package
    (name "chicken-isaac")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "isaac" "1.0.0"))
        (sha256
          (base32 "0hmqm5ag457q0zryaj8b2zx25hgg9pq4l1gxd5vf4xb4s79i1wxb"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-module-declarations")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "isaac"))
    (synopsis "Bindings to the ISAAC CSPRNG")
    (home-page "https://wiki.call-cc.org/eggref/5/isaac")
    (description "Bindings to the ISAAC CSPRNG")
    (license license:bsd-2)))

(define-public
  chicken-cairo
  (package
    (name "chicken-cairo")
    (version "0.1.18")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "cairo" "0.1.18"))
        (sha256
          (base32 "1x69i4aysn8mf93ic36947p6gvgglk8c0vg2m6vdhimf6y65szi1"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "cairo"))
    (synopsis "Chicken bindings for Cairo, a vector graphics library")
    (home-page "https://wiki.call-cc.org/eggref/5/cairo")
    (description "Chicken bindings for Cairo, a vector graphics library")
    (license license:lgpl2.1)))

(define-public
  chicken-cst
  (package
    (name "chicken-cst")
    (version "1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "cst" "1.5"))
        (sha256
          (base32 "1r7vc6rwc75di72v5h9s4cdakm5a2hywpayl1xpw4vbq8fdn7zc0"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-brev-separate"
              "chicken-srfi-1"
              "chicken-define-options"
              "chicken-match-generics")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "cst"))
    (synopsis "Visualize sexps as trees via Graphviz")
    (home-page "https://wiki.call-cc.org/eggref/5/cst")
    (description "Visualize sexps as trees via Graphviz")
    (license license:bsd-1)))

(define-public
  chicken-sqlite3
  (package
    (name "chicken-sqlite3")
    (version "3.7.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sqlite3" "3.7.2"))
        (sha256
          (base32 "1i9387ph1l7ky30in2v9y8zqc4rqzl0xmzb4hqjpipsxv6haa98s"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-18"
              "chicken-srfi-69"
              "chicken-object-evict"
              "chicken-check-errors"
              "chicken-synch"
              "chicken-miscmacros"
              "chicken-matchable"
              "chicken-sql-null")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sqlite3"))
    (synopsis "Bindings to version 3.x of the SQLite API")
    (home-page "https://wiki.call-cc.org/eggref/5/sqlite3")
    (description "Bindings to version 3.x of the SQLite API")
    (license license:bsd-2)))

(define-public
  chicken-unveil
  (package
    (name "chicken-unveil")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "unveil" "0.2"))
        (sha256
          (base32 "0v9s6qaf5lcvdn881bpibazy77fajm8fj7h6v54425lx35164rbf"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "unveil"))
    (synopsis "unveil(2) support for CHICKEN")
    (home-page "https://wiki.call-cc.org/eggref/5/unveil")
    (description "unveil(2) support for CHICKEN")
    (license license:isc)))

(define-public
  chicken-hahn
  (package
    (name "chicken-hahn")
    (version "0.10.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "hahn" "0.10.1"))
        (sha256
          (base32 "1p7i8vmh4pg9q0k1ml2n8wbrl7hq8b7x9xgxz5jsb8ywwax74fk4"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "hahn"))
    (synopsis "In-source documentation")
    (home-page "https://wiki.call-cc.org/eggref/5/hahn")
    (description "In-source documentation")
    (license license:bsd-2)))

(define-public
  chicken-s9fes-char-graphics
  (package
    (name "chicken-s9fes-char-graphics")
    (version "1.4.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "s9fes-char-graphics" "1.4.2"))
        (sha256
          (base32 "1ysz8vrx7zwfv4drx955ca28avmdfilafd9a20sl67y5vwb47i8m"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-utf8" "chicken-format")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "s9fes-char-graphics"))
    (synopsis "Scheme 9 from Empty Space Char Graphics")
    (home-page "https://wiki.call-cc.org/eggref/5/s9fes-char-graphics")
    (description "Scheme 9 from Empty Space Char Graphics")
    (license license:public-domain)))

(define-public
  chicken-posix-groups
  (package
    (name "chicken-posix-groups")
    (version "0.2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "posix-groups" "0.2.1"))
        (sha256
          (base32 "0s2gdq2kkpik7l3cms3mp15x7j15dp22pcrfrkap77hfl6xpyh8z"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "posix-groups"))
    (synopsis "Access POSIX group information")
    (home-page "https://wiki.call-cc.org/eggref/5/posix-groups")
    (description "Access POSIX group information")
    (license license:bsd-2)))

(define-public
  chicken-svgpath
  (package
    (name "chicken-svgpath")
    (version "1.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "svgpath" "1.7"))
        (sha256
          (base32 "0017w5vc9qpz5gcghhlsw6fzla2vxkvykm9rvriiqm9zywq48wlh"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-brev-separate"
              "chicken-clojurian"
              "chicken-match-generics"
              "chicken-miscmacros"
              "chicken-srfi-1"
              "chicken-srfi-69"
              "chicken-strse"
              "chicken-sxpath"
              "chicken-tree")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "svgpath"))
    (synopsis "Parse, normalize, and write SVG path data")
    (home-page "https://wiki.call-cc.org/eggref/5/svgpath")
    (description "Parse, normalize, and write SVG path data")
    (license license:lgpl3+)))

(define-public
  chicken-spiffy
  (package
    (name "chicken-spiffy")
    (version "6.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "spiffy" "6.3"))
        (sha256
          (base32 "1nfxygrscvldmayr5sm8vqqvzv2wk63yh7pksp7v5gkffd0yhnzs"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-intarweb"
              "chicken-uri-common"
              "chicken-uri-generic"
              "chicken-sendfile"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14"
              "chicken-srfi-18")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "spiffy"))
    (synopsis "A small but powerful web server")
    (home-page "https://wiki.call-cc.org/eggref/5/spiffy")
    (description "A small but powerful web server")
    (license license:bsd-2)))

(define-public
  chicken-sourcehut
  (package
    (name "chicken-sourcehut")
    (version "0.3.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sourcehut" "0.3.3"))
        (sha256
          (base32 "1l7cc6kynh54qanqr8z8v38b7c3whb79hsdrdia5cvxcig2vzvfk"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-http-client"
              "chicken-intarweb"
              "chicken-medea"
              "chicken-openssl"
              "chicken-optimism"
              "chicken-simple-exceptions"
              "chicken-srfi-1"
              "chicken-srfi-133")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-begin-syntax"
              "chicken-module-declarations")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sourcehut"))
    (synopsis "Bindings and CLI for the sr.ht REST API")
    (home-page "https://wiki.call-cc.org/eggref/5/sourcehut")
    (description "Bindings and CLI for the sr.ht REST API")
    (license license:bsd-2)))

(define-public
  chicken-daemon
  (package
    (name "chicken-daemon")
    (version "0.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "daemon" "0.0.1"))
        (sha256
          (base32 "1kqryy1jq9qz0y3c58qlwr8mvgdn2jyr7a6anqb32dipp9ylqkim"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "daemon"))
    (synopsis "Create daemon processes")
    (home-page "https://wiki.call-cc.org/eggref/5/daemon")
    (description "Create daemon processes")
    (license license:unlicense)))

(define-public
  chicken-srfi-71
  (package
    (name "chicken-srfi-71")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-71" "0.2"))
        (sha256
          (base32 "0v10ylzd5r61l2f6b2v3j4mpxf50pwmrlaqrhx66bw2fps3n32qp"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-71"))
    (synopsis "SRFI-71: Extended LET-syntax for multiple values")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-71")
    (description "SRFI-71: Extended LET-syntax for multiple values")
    (license license:bsd-1)))

(define-public
  chicken-ersatz
  (package
    (name "chicken-ersatz")
    (version "1.28")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ersatz" "1.28"))
        (sha256
          (base32 "0lrrqvgz4zpv1qkc45g0dnjmvkhyxh338wn009cmhj1ingv57yg0"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-datatype"
              "chicken-silex"
              "chicken-lalr"
              "chicken-utf8"
              "chicken-uri-generic"
              "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ersatz"))
    (synopsis "A template engine inspired by Jinja2 and Jingoo.")
    (home-page "https://wiki.call-cc.org/eggref/5/ersatz")
    (description "A template engine inspired by Jinja2 and Jingoo.")
    (license license:lgpl3)))

(define-public
  chicken-string-utils
  (package
    (name "chicken-string-utils")
    (version "2.7.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "string-utils" "2.7.4"))
        (sha256
          (base32 "1ilzdvbmmm7jnq4m3nrbxhj9x2b4d772748m9fjxzl9bqqik1a54"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-utf8"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-69"
              "chicken-miscmacros"
              "chicken-check-errors")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "string-utils"))
    (synopsis "String Utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/string-utils")
    (description "String Utilities")
    (license license:bsd-2)))

(define-public
  chicken-srfi-133
  (package
    (name "chicken-srfi-133")
    (version "1.6.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-133" "1.6.1"))
        (sha256
          (base32 "02ixzvl2a858zd1x0xiz7ygg5vj47fj720mn57jgpa1b8qskqf2c"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-133"))
    (synopsis "SRFI-133: Vector Library (R7RS-compatible)")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-133")
    (description "SRFI-133: Vector Library (R7RS-compatible)")
    (license license:bsd-2)))

(define-public
  chicken-srfi-179
  (package
    (name "chicken-srfi-179")
    (version "0.2.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-179" "0.2.3"))
        (sha256
          (base32 "0y5y6sr0flmhnkfbazihi72hyc3cs067i00c0zcd6jcpr28ki103"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-133" "chicken-srfi-160")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-srfi-1"
              "chicken-srfi-133"
              "chicken-srfi-160")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-179"))
    (synopsis "SRFI-179: Nonempty Intervals and Generalized Arrays (Updated)")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-179")
    (description
      "SRFI-179: Nonempty Intervals and Generalized Arrays (Updated)")
    (license license:expat)))

(define-public
  chicken-pkg-config
  (package
    (name "chicken-pkg-config")
    (version "0.1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pkg-config" "0.1.2"))
        (sha256
          (base32 "0q2zjfcywgqjv13cl1mjbl7n1csyq9rzkk20kky8ra0j3mkdql03"))))
    (propagated-inputs (specifications->packages (list "chicken-posix-utils")))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pkg-config"))
    (synopsis "Wrapper around pkg-config")
    (home-page "https://wiki.call-cc.org/eggref/5/pkg-config")
    (description "Wrapper around pkg-config")
    (license license:bsd-2)))

(define-public
  chicken-anaphora
  (package
    (name "chicken-anaphora")
    (version "1.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "anaphora" "1.0.1"))
        (sha256
          (base32 "1yzm92qjpgga8722jdy3xx8gzq0ijass06aqyncccawjzshq7zy1"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "anaphora"))
    (synopsis "Some anaphoric and named macros")
    (home-page "https://wiki.call-cc.org/eggref/5/anaphora")
    (description "Some anaphoric and named macros")
    (license license:bsd-2)))

(define-public
  chicken-dynamic-import
  (package
    (name "chicken-dynamic-import")
    (version "1.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "dynamic-import" "1.0.2"))
        (sha256
          (base32 "17n0z551p7kr83afpjhg3q93q10nlwf7rjc3qmff1g026yhxnvwc"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-test-utils" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "dynamic-import"))
    (synopsis "Dynamic Import")
    (home-page "https://wiki.call-cc.org/eggref/5/dynamic-import")
    (description "Dynamic Import")
    (license license:public-domain)))

(define-public
  chicken-traversal
  (package
    (name "chicken-traversal")
    (version "1.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "traversal" "1.7"))
        (sha256
          (base32 "172inmqlz2pqbks5gyfnbll5qnnk4545jrb3xbsp9qxcmmayamiw"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-vector-lib")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "traversal"))
    (synopsis "Various list operations")
    (home-page "https://wiki.call-cc.org/eggref/5/traversal")
    (description "Various list operations")
    (license license:lgpl3+)))

(define-public
  chicken-iterators
  (package
    (name "chicken-iterators")
    (version "0.1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "iterators" "0.1.1"))
        (sha256
          (base32 "0aji2ycbqykqqy2911gwfsyp1g8sry2k7w7ap80gq41xravknawf"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "iterators"))
    (synopsis "Iterators and coroutines")
    (home-page "https://wiki.call-cc.org/eggref/5/iterators")
    (description "Iterators and coroutines")
    (license license:bsd-2)))

(define-public
  chicken-micro-benchmark
  (package
    (name "chicken-micro-benchmark")
    (version "0.0.20")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "micro-benchmark" "0.0.20"))
        (sha256
          (base32 "022fkwr1wm1im40rgk3g5dz8n4rvlw1zdmskqsh9idv31gbfi456"))))
    (propagated-inputs
      (specifications->packages (list "chicken-micro-stats" "chicken-srfi-1")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "micro-benchmark"))
    (synopsis "Easily create micro-benchmarks")
    (home-page "https://wiki.call-cc.org/eggref/5/micro-benchmark")
    (description "Easily create micro-benchmarks")
    (license license:gpl3)))

(define-public
  chicken-estraier-client
  (package
    (name "chicken-estraier-client")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "estraier-client" "1.0"))
        (sha256
          (base32 "12ng7wqdf0l2vdg96i19xpj5wsh9ppjrh0r7ip7kv8afpl8kqj6p"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-http-client" "chicken-uri-common" "chicken-intarweb")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "estraier-client"))
    (synopsis "A pure Scheme Hyper Estraier client library")
    (home-page "https://wiki.call-cc.org/eggref/5/estraier-client")
    (description "A pure Scheme Hyper Estraier client library")
    (license license:bsd-2)))

(define-public
  chicken-dotted-lambdas
  (package
    (name "chicken-dotted-lambdas")
    (version "1.3.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "dotted-lambdas" "1.3.1"))
        (sha256
          (base32 "0wxg56c1ywi77xvk1xjpmdnz93mk21dqzhjc3pdm5mnvc49j5nnk"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "dotted-lambdas"))
    (synopsis "lambda equivalents with dots as trailing symbols")
    (home-page "https://wiki.call-cc.org/eggref/5/dotted-lambdas")
    (description "lambda equivalents with dots as trailing symbols")
    (license license:bsd-2)))

(define-public
  chicken-protobj
  (package
    (name "chicken-protobj")
    (version "0.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "protobj" "0.5"))
        (sha256
          (base32 "181cdk8w2346i1x7yj77kzs7zlv2617m6drbacjf7zlv7jjb59sv"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "protobj"))
    (synopsis "A prototype-delegation object model")
    (home-page "https://wiki.call-cc.org/eggref/5/protobj")
    (description "A prototype-delegation object model")
    (license license:lgpl2.1)))

(define-public
  chicken-srfi-227
  (package
    (name "chicken-srfi-227")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-227" "1.1"))
        (sha256
          (base32 "0vrpgqdmwdaphy0szskxyl2x6xhwycgvi6flwi5v6m2zi5cd3j1c"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-227"))
    (synopsis "SRFI 227: Optional Arguments")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-227")
    (description "SRFI 227: Optional Arguments")
    (license license:expat)))

(define-public
  chicken-dyn-vector
  (package
    (name "chicken-dyn-vector")
    (version "2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "dyn-vector" "2.1"))
        (sha256
          (base32 "0bjzldp0jxks200ciyp1pslmg3rbh7s1cx835qgmfd47qpyds8mb"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-vector-lib")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "dyn-vector"))
    (synopsis "Dynamic (dense) vectors based on SRFI-43.")
    (home-page "https://wiki.call-cc.org/eggref/5/dyn-vector")
    (description "Dynamic (dense) vectors based on SRFI-43.")
    (license license:lgpl3)))

(define-public
  chicken-srfi-151
  (package
    (name "chicken-srfi-151")
    (version "1.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-151" "1.0.2"))
        (sha256
          (base32 "0hscg2342wl2bzbnwl5d0ij1vr7nxn0ly9aqp3n5yh6j9x3hd29i"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-151"))
    (synopsis "SRFI 151: Bitwise Operations")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-151")
    (description "SRFI 151: Bitwise Operations")
    (license license:expat)))

(define-public
  chicken-srfi-74
  (package
    (name "chicken-srfi-74")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-74" "0.1"))
        (sha256
          (base32 "1ymcad82vf89660i8km8568xnkpiz35inil348arqkp44804q1rz"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-60" "chicken-srfi-66")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-74"))
    (synopsis "SRFI-74: Octet-Addressed Binary Blocks")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-74")
    (description "SRFI-74: Octet-Addressed Binary Blocks")
    (license license:expat)))

(define-public
  chicken-scmfmt
  (package
    (name "chicken-scmfmt")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "scmfmt" "0.1"))
        (sha256
          (base32 "0vpixxbil8ckmhsvfc9szv5gsvc2a1m88n2vv5cab5paarl26rhg"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "scmfmt"))
    (synopsis "Chicken Scheme code formattor to use from stdin/stdout")
    (home-page "https://wiki.call-cc.org/eggref/5/scmfmt")
    (description "Chicken Scheme code formattor to use from stdin/stdout")
    (license license:bsd-2)))

(define-public
  chicken-srfi-134
  (package
    (name "chicken-srfi-134")
    (version "1.1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-134" "1.1.1"))
        (sha256
          (base32 "0nzingih2pjsi3ysk3qhp9wc52lsk1wpdgypsf67prnz3cllz90p"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-41" "chicken-typed-records")))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-srfi-1" "chicken-test-generative")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-134"))
    (synopsis "SRFI 134: Immutable deques")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-134")
    (description "SRFI 134: Immutable deques")
    (license license:expat)))

(define-public
  chicken-slib-wt-tree
  (package
    (name "chicken-slib-wt-tree")
    (version "0.1.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "slib-wt-tree" "0.1.6"))
        (sha256
          (base32 "0np2nc8z5ddvf3248zq91f6qmv71x8vink8rswlvjb5vidvcf3kp"))))
    (propagated-inputs
      (specifications->packages (list "chicken-typed-records")))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-test-generative" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "slib-wt-tree"))
    (synopsis "Weight-balanced trees")
    (home-page "https://wiki.call-cc.org/eggref/5/slib-wt-tree")
    (description "Weight-balanced trees")
    (license license:gpl2)))

(define-public
  chicken-dot-locking
  (package
    (name "chicken-dot-locking")
    (version "0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "dot-locking" "0.4"))
        (sha256
          (base32 "13fndcyk4xavn694k1a8kcv3c02a2scxn0z3s56mya2nw4wns88z"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-13" "chicken-srfi-18")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "dot-locking"))
    (synopsis "advisory locking mechanism based on standard file operations")
    (home-page "https://wiki.call-cc.org/eggref/5/dot-locking")
    (description
      "advisory locking mechanism based on standard file operations")
    (license license:bsd-2)))

(define-public
  chicken-coops-utils
  (package
    (name "chicken-coops-utils")
    (version "2.2.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "coops-utils" "2.2.3"))
        (sha256
          (base32 "1ywxc7r1l5a930rfp0fv99dcfg2gbvg93rp4jih4rnlpwys6gpv4"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-check-errors"
              "chicken-coops")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "coops-utils"))
    (synopsis "coops utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/coops-utils")
    (description "coops utilities")
    (license license:bsd-2)))

(define-public
  chicken-markdown-svnwiki
  (package
    (name "chicken-markdown-svnwiki")
    (version "0.3.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "markdown-svnwiki" "0.3.1"))
        (sha256
          (base32 "1iw63ki41f1gr2b89k0ligwyljxfx8ysaacfnf70wgz4j70mh282"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-lowdown"
              "chicken-sxml-transforms"
              "chicken-miscmacros"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-37")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "markdown-svnwiki"))
    (synopsis "Convert Markdown to svnwiki")
    (home-page "https://wiki.call-cc.org/eggref/5/markdown-svnwiki")
    (description "Convert Markdown to svnwiki")
    (license license:bsd-2)))

(define-public
  chicken-lazy-seq
  (package
    (name "chicken-lazy-seq")
    (version "2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "lazy-seq" "2"))
        (sha256
          (base32 "12gz8999g73fa20v067gs4v6zs65w8qajwjfsngbcdaqadv2733g"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "lazy-seq"))
    (synopsis "Clojure-like lazy sequences")
    (home-page "https://wiki.call-cc.org/eggref/5/lazy-seq")
    (description "Clojure-like lazy sequences")
    (license license:bsd-2)))

(define-public
  chicken-srfi-25
  (package
    (name "chicken-srfi-25")
    (version "1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-25" "1.3"))
        (sha256
          (base32 "0vf6f0f6jm4frpz995kxjzydg3p7vjn58shmv6s2p34hmfsjcm04"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-25"))
    (synopsis "Multidimensional arrays")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-25")
    (description "Multidimensional arrays")
    (license license:bsd-1)))

(define-public
  chicken-srfi-144
  (package
    (name "chicken-srfi-144")
    (version "0.1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-144" "0.1.3"))
        (sha256
          (base32 "08fjhasdxmmb48c5nx632wjr6ikyhwgsyzxx49jz9hzns4ld526g"))))
    (propagated-inputs (specifications->packages (list "chicken-r7rs")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-144"))
    (synopsis "SRFI 144: Flonums")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-144")
    (description "SRFI 144: Flonums")
    (license license:expat)))

(define-public
  chicken-srfi-4-comprehensions
  (package
    (name "chicken-srfi-4-comprehensions")
    (version "1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-4-comprehensions" "1.5"))
        (sha256
          (base32 "1j2xabk6fjsh2wnwgzanmqv3pwb72imzfyiiwm8a9y45xyx6513l"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-42")))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-4-comprehensions"))
    (synopsis "SRFI-42 Comprehensions for SRFI-4 Vectors")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-4-comprehensions")
    (description "SRFI-42 Comprehensions for SRFI-4 Vectors")
    (license license:bsd-1)))

(define-public
  chicken-color
  (package
    (name "chicken-color")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "color" "1.1"))
        (sha256
          (base32 "1pxc66arxkzyfqfyv7myzfvqwqakh643cjb3n8pqxgmvmrmfwgfr"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-fmt" "chicken-records" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "color"))
    (synopsis "The SLIB color library")
    (home-page "https://wiki.call-cc.org/eggref/5/color")
    (description "The SLIB color library")
    (license license:bsd-2)))

(define-public
  chicken-expat
  (package
    (name "chicken-expat")
    (version "2.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "expat" "2.2"))
        (sha256
          (base32 "162z5mblii6lk2n67ya3zgsgpi1dbfyzcq8r4gxld36j05w39bpb"))))
    (propagated-inputs
      (specifications->packages (list "chicken-bind" "chicken-silex")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-queues")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "expat"))
    (synopsis "An interface to James Clark's Expat XML parser")
    (home-page "https://wiki.call-cc.org/eggref/5/expat")
    (description "An interface to James Clark's Expat XML parser")
    (license license:bsd-2)))

(define-public
  chicken-awful-main
  (package
    (name "chicken-awful-main")
    (version "0.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "awful-main" "0.1.0"))
        (sha256
          (base32 "1zpnk3xjkn2pdfw953ximq6i0d3v3mak8ydl6a3nb2zz1daq7044"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-awful" "chicken-spiffy" "chicken-define-options")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "awful-main"))
    (synopsis "Turn awful web applications into static executables")
    (home-page "https://wiki.call-cc.org/eggref/5/awful-main")
    (description "Turn awful web applications into static executables")
    (license license:bsd-2)))

(define-public
  chicken-sendfile
  (package
    (name "chicken-sendfile")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sendfile" "2.0"))
        (sha256
          (base32 "1vi5i8df146j2gh4x7s8fry0bdzfm57f7v62zd5sd0x45h72lffw"))))
    (propagated-inputs
      (specifications->packages (list "chicken-memory-mapped-files")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-simple-sha1"
              "chicken-srfi-13"
              "chicken-srfi-69")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sendfile"))
    (synopsis "Sending a file over the network")
    (home-page "https://wiki.call-cc.org/eggref/5/sendfile")
    (description "Sending a file over the network")
    (license license:bsd-2)))

(define-public
  chicken-srfi-48
  (package
    (name "chicken-srfi-48")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-48" "1.0.0"))
        (sha256
          (base32 "153ipqaz7740vr50sq639vk5vs8wxd8lmfpa0vk17qzw5skmnhp6"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-38")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-48"))
    (synopsis "SRFI-48: Intermediate Format Strings")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-48")
    (description "SRFI-48: Intermediate Format Strings")
    (license license:expat)))

(define-public
  chicken-latch
  (package
    (name "chicken-latch")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "latch" "0.3"))
        (sha256
          (base32 "0sl8i18g03cl8qpaqbrfkcx7xd28jyxcb183873s9yq7max4zryr"))))
    (propagated-inputs (specifications->packages (list "chicken-matchable")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "latch"))
    (synopsis "Evaluate expressions once")
    (home-page "https://wiki.call-cc.org/eggref/5/latch")
    (description "Evaluate expressions once")
    (license license:public-domain)))

(define-public
  chicken-agrep
  (package
    (name "chicken-agrep")
    (version "1.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "agrep" "1.7"))
        (sha256
          (base32 "1anh4dkcdh3w5akd45n11v62kl3jpj7n78zfwaia99yd9dd5i9ww"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-datatype" "chicken-srfi-1" "chicken-srfi-14")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "agrep"))
    (synopsis "Approximate grep..")
    (home-page "https://wiki.call-cc.org/eggref/5/agrep")
    (description "Approximate grep..")
    (license license:gpl3)))

(define-public
  chicken-aes
  (package
    (name "chicken-aes")
    (version "1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "aes" "1.5"))
        (sha256
          (base32 "01bwykr6ryv036pyjc95qhqmrj0p7wisb0dhnf7f7nw858phr4av"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-crypto-tools")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "aes"))
    (synopsis
      "A self-contained implementation of the AES / Rijndael encryption algorithm")
    (home-page "https://wiki.call-cc.org/eggref/5/aes")
    (description
      "A self-contained implementation of the AES / Rijndael encryption algorithm")
    (license license:bsd-2)))

(define-public
  chicken-box
  (package
    (name "chicken-box")
    (version "3.6.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "box" "3.6.0"))
        (sha256
          (base32 "131k73q72v658mkxhj34988kwh8yxjq00gf4sn3f1y837n6kp9yd"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "box"))
    (synopsis "Boxing")
    (home-page "https://wiki.call-cc.org/eggref/5/box")
    (description "Boxing")
    (license license:bsd-2)))

(define-public
  chicken-scan-input-lines
  (package
    (name "chicken-scan-input-lines")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "scan-input-lines" "0.2"))
        (sha256
          (base32 "16pkx339r5s877np1k0dhs29zdcmrz0smcwmcpw23c540sq9jb2z"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "scan-input-lines"))
    (synopsis "Scan lines until a regex or predicate matches")
    (home-page "https://wiki.call-cc.org/eggref/5/scan-input-lines")
    (description "Scan lines until a regex or predicate matches")
    (license license:bsd-2)))

(define-public
  chicken-simple-binds
  (package
    (name "chicken-simple-binds")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "simple-binds" "1.1"))
        (sha256
          (base32 "0b5frz0zq5b87l4l5hhca318m0mjllw9zjacbyw0l2w39l48f77z"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "simple-binds"))
    (synopsis "Some simple destructuring bind macros")
    (home-page "https://wiki.call-cc.org/eggref/5/simple-binds")
    (description "Some simple destructuring bind macros")
    (license license:bsd-2)))

(define-public
  chicken-blosc
  (package
    (name "chicken-blosc")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "blosc" "1.1"))
        (sha256
          (base32 "0m78rb2q0znixpiflcrndlk708g4mbw7yh1ynkvk3zzvln0d3wgi"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-srfi-13" "chicken-compile-file")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "blosc"))
    (synopsis "Bindings to the Blosc multi-threaded meta-compressor library")
    (home-page "https://wiki.call-cc.org/eggref/5/blosc")
    (description
      "Bindings to the Blosc multi-threaded meta-compressor library")
    (license license:bsd-2)))

(define-public
  chicken-srfi-207
  (package
    (name "chicken-srfi-207")
    (version "2.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-207" "2.0.0"))
        (sha256
          (base32 "124gl45p6i3mnjlq8hys9m0smc9qnizv0r9lch1sf3qi8pj3v648"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-151"
              "chicken-r7rs")))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-207"))
    (synopsis "SRFI-207: String-notated bytevectors")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-207")
    (description "SRFI-207: String-notated bytevectors")
    (license license:expat)))

(define-public
  chicken-server-test
  (package
    (name "chicken-server-test")
    (version "0.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "server-test" "0.6"))
        (sha256
          (base32 "1k3k9mkildbi9i8vgj26rj5nidrm0zif8pqf9zm5ahwn4kcp9drx"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "server-test"))
    (synopsis "Utilities to help testing servers")
    (home-page "https://wiki.call-cc.org/eggref/5/server-test")
    (description "Utilities to help testing servers")
    (license license:bsd-2)))

(define-public
  chicken-crypto-tools
  (package
    (name "chicken-crypto-tools")
    (version "1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "crypto-tools" "1.4"))
        (sha256
          (base32 "0ajf0qfnhp99f4x1dll2fhlxrsxamgrrwyksc7rrym77xmv8f1pd"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "crypto-tools"))
    (synopsis "Useful cryptographic primitives")
    (home-page "https://wiki.call-cc.org/eggref/5/crypto-tools")
    (description "Useful cryptographic primitives")
    (license license:bsd-2)))

(define-public
  chicken-udp6
  (package
    (name "chicken-udp6")
    (version "0.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "udp6" "0.2.0"))
        (sha256
          (base32 "1fm8khkfw22iwsnlyj5jpipfkp70y35pk2y3i4bzmp6iq84gxjrm"))))
    (propagated-inputs (specifications->packages (list "chicken-socket")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "udp6"))
    (synopsis "Interface to UDP over IPv4 and IPv6")
    (home-page "https://wiki.call-cc.org/eggref/5/udp6")
    (description "Interface to UDP over IPv4 and IPv6")
    (license license:bsd-2)))

(define-public
  chicken-opencl
  (package
    (name "chicken-opencl")
    (version "1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "opencl" "1.3"))
        (sha256
          (base32 "18xbnw47abkxyqm8irlk38qak8m2zmnw3z53ixzck97260hyy03y"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-18")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "opencl"))
    (synopsis "Bindings to OpenCL")
    (home-page "https://wiki.call-cc.org/eggref/5/opencl")
    (description "Bindings to OpenCL")
    (license license:bsd-2)))

(define-public
  chicken-pipes
  (package
    (name "chicken-pipes")
    (version "1.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pipes" "1.0.1"))
        (sha256
          (base32 "1bljwlb3s47hcllm05am8bj5clpywchffnkk2ajx572vl5b0qs92"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pipes"))
    (synopsis "sequencing partial combinations")
    (home-page "https://wiki.call-cc.org/eggref/5/pipes")
    (description "sequencing partial combinations")
    (license license:bsd-2)))

(define-public
  chicken-simple-contracts
  (package
    (name "chicken-simple-contracts")
    (version "1.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "simple-contracts" "1.0.2"))
        (sha256
          (base32 "0x0fzvnkzbzf1qr40xg8zi8qj5b889d3hs6b6cvdh46456zvzxka"))))
    (propagated-inputs (specifications->packages (list "chicken-checks")))
    (native-inputs
      (specifications->packages
        (list "chicken-checks" "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "simple-contracts"))
    (synopsis "Design by contract for procedures")
    (home-page "https://wiki.call-cc.org/eggref/5/simple-contracts")
    (description "Design by contract for procedures")
    (license license:bsd-2)))

(define-public
  chicken-macaw
  (package
    (name "chicken-macaw")
    (version "0.1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "macaw" "0.1.1"))
        (sha256
          (base32 "1zc9prn3n4rac6ibgbfg0fcdl0czf31qhx8v2276m49i7hizvan4"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "macaw"))
    (synopsis "Efficient color types and math")
    (home-page "https://wiki.call-cc.org/eggref/5/macaw")
    (description "Efficient color types and math")
    (license license:bsd-2)))

(define-public
  chicken-manual-labor
  (package
    (name "chicken-manual-labor")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "manual-labor" "0.3"))
        (sha256
          (base32 "1v8af7p0np2fphp5mi8kk1872lcqpka211j51dw6010db2262pbm"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-regex"
              "chicken-matchable"
              "chicken-svnwiki-sxml"
              "chicken-srfi-1"
              "chicken-uri-generic"
              "chicken-chicken-doc-html")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "manual-labor"))
    (synopsis "Generate static HTML manual from wiki docs")
    (home-page "https://wiki.call-cc.org/eggref/5/manual-labor")
    (description "Generate static HTML manual from wiki docs")
    (license license:bsd-2)))

(define-public
  chicken-memory-mapped-files
  (package
    (name "chicken-memory-mapped-files")
    (version "0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "memory-mapped-files" "0.4"))
        (sha256
          (base32 "08vk7j2bfykcfwxl7g06qpbnr287i7d2l5nkpbaiyhi2ws1nhjl9"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "memory-mapped-files"))
    (synopsis "Memory-mapped file access for UNIX and Windows")
    (home-page "https://wiki.call-cc.org/eggref/5/memory-mapped-files")
    (description "Memory-mapped file access for UNIX and Windows")
    (license license:bsd-2)))

(define-public
  chicken-sq
  (package
    (name "chicken-sq")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sq" "0.2"))
        (sha256
          (base32 "0pcxy8l8qlb085pbxp9plxzzrs4wb2pfpx840rydwhpsjmrfx1zp"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-optimism"
              "chicken-r7rs"
              "chicken-simple-exceptions"
              "chicken-srfi-18"
              "chicken-srfi-60"
              "chicken-srfi-145")))
    (native-inputs
      (specifications->packages
        (list "chicken-begin-syntax"
              "chicken-matchable"
              "chicken-miscmacros"
              "chicken-module-declarations")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sq"))
    (synopsis "Scheme jq wrapper for processing S-expressions")
    (home-page "https://wiki.call-cc.org/eggref/5/sq")
    (description "Scheme jq wrapper for processing S-expressions")
    (license license:bsd-2)))

(define-public
  chicken-srfi-29
  (package
    (name "chicken-srfi-29")
    (version "3.0.11")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-29" "3.0.11"))
        (sha256
          (base32 "1jyjwkz6jz9da3n32cgja2dvwrsl9lckknxjb1ial0359ibqnc3h"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-69"
              "chicken-utf8"
              "chicken-locale"
              "chicken-posix-utils"
              "chicken-condition-utils"
              "chicken-check-errors")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-29"))
    (synopsis "Localization")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-29")
    (description "Localization")
    (license license:bsd-2)))

(define-public
  chicken-srfi-35
  (package
    (name "chicken-srfi-35")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-35" "0.1"))
        (sha256
          (base32 "13xgssgyrhcakg94lk04pkk38fr5ggfyf4r3sf0abansr6wxrahh"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-35"))
    (synopsis "SRFI-35 Conditions")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-35")
    (description "SRFI-35 Conditions")
    (license license:expat)))

(define-public
  chicken-slice
  (package
    (name "chicken-slice")
    (version "1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "slice" "1.3"))
        (sha256
          (base32 "1cdgs1fhir777909qp43990xbn2a1xhp5rbakjyvcaf8y0m082w0"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-utf8")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-utf8")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "slice"))
    (synopsis "A slicer procedure for lists, strings and vectors")
    (home-page "https://wiki.call-cc.org/eggref/5/slice")
    (description "A slicer procedure for lists, strings and vectors")
    (license license:bsd-2)))

(define-public
  chicken-pstk
  (package
    (name "chicken-pstk")
    (version "1.4.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pstk" "1.4.1"))
        (sha256
          (base32 "075w2kaljy08cx8z78pi3741is1fi63bfsfdy229gkfrbkzl8vpz"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pstk"))
    (synopsis "PS/Tk: Portable Scheme interface to Tk")
    (home-page "https://wiki.call-cc.org/eggref/5/pstk")
    (description "PS/Tk: Portable Scheme interface to Tk")
    (license license:bsd-2)))

(define-public
  chicken-svn-client
  (package
    (name "chicken-svn-client")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "svn-client" "1.2"))
        (sha256
          (base32 "0xxnk0pnvv6n8zf7wz720nzj03yx15xdiczpkwvhr87rafy02smy"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "svn-client"))
    (synopsis "A wrapper around Subversion's libsvn_client C library.")
    (home-page "https://wiki.call-cc.org/eggref/5/svn-client")
    (description "A wrapper around Subversion's libsvn_client C library.")
    (license license:public-domain)))

(define-public
  chicken-bind
  (package
    (name "chicken-bind")
    (version "1.2.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "bind" "1.2.6"))
        (sha256
          (base32 "02j8i4w3dzfnfcyckk6y228shwfxk5pgap3zsha86am53gw05aj0"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-silex"
              "chicken-matchable"
              "chicken-coops"
              "chicken-srfi-1"
              "chicken-regex")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "bind"))
    (synopsis "Automatically generate bindings from C/C++ declarations")
    (home-page "https://wiki.call-cc.org/eggref/5/bind")
    (description "Automatically generate bindings from C/C++ declarations")
    (license license:public-domain)))

(define-public
  chicken-bencode
  (package
    (name "chicken-bencode")
    (version "1.3.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "bencode" "1.3.1"))
        (sha256
          (base32 "1sxjf16vfp8wxjyr9jxldmb495vdy334b2jgxj6ji7mdfizrldiq"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-miscmacros" "chicken-vector-lib")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "bencode"))
    (synopsis "Bencoding parser and serializer")
    (home-page "https://wiki.call-cc.org/eggref/5/bencode")
    (description "Bencoding parser and serializer")
    (license license:bsd-2)))

(define-public
  chicken-srfi-217
  (package
    (name "chicken-srfi-217")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-217" "0.2"))
        (sha256
          (base32 "0ynasgp03kqd6nhqmcnp4cjf87p3pkjaqi2x860hma79xsslyp8n"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-143" "chicken-typed-records")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-217"))
    (synopsis "SRFI 217: Integer Sets")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-217")
    (description "SRFI 217: Integer Sets")
    (license license:expat)))

(define-public
  chicken-tabular
  (package
    (name "chicken-tabular")
    (version "1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "tabular" "1.4"))
        (sha256
          (base32 "155h58aphs1m29fq152fp08q1jkf7sibyi2ynqza6y5z846gf9gj"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-127"
              "chicken-utf8"
              "chicken-matchable")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "tabular"))
    (synopsis
      "Parsing and formatting of tabular text data such as comma- and delimiter-separated values (CSV and DSV).")
    (home-page "https://wiki.call-cc.org/eggref/5/tabular")
    (description
      "Parsing and formatting of tabular text data such as comma- and delimiter-separated values (CSV and DSV).")
    (license license:gpl3)))

(define-public
  chicken-input-parse
  (package
    (name "chicken-input-parse")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "input-parse" "1.2"))
        (sha256
          (base32 "195ghf8qk3w7wxvdra3gi653p57y3hdadngjz599ym14rcfxq61q"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "input-parse"))
    (synopsis "input-stream tokenizing and parsing routines.")
    (home-page "https://wiki.call-cc.org/eggref/5/input-parse")
    (description "input-stream tokenizing and parsing routines.")
    (license license:public-domain)))

(define-public
  chicken-tweetnacl
  (package
    (name "chicken-tweetnacl")
    (version "1.4.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "tweetnacl" "1.4.2"))
        (sha256
          (base32 "0ba8xz39qgc8ixq7s21pdf5sw5hwxriakdhq7pxc47na2q2pr1dy"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "tweetnacl"))
    (synopsis "TweetNaCl cryptographic library")
    (home-page "https://wiki.call-cc.org/eggref/5/tweetnacl")
    (description "TweetNaCl cryptographic library")
    (license license:bsd-2)))

(define-public
  chicken-make
  (package
    (name "chicken-make")
    (version "1.9")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "make" "1.9"))
        (sha256
          (base32 "0dhw7jf6f67y6wpcs2vq9b7jwhkkb2z9gwf1z036yvhfyir6l2z8"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "make"))
    (synopsis "The PLT 'make' macro")
    (home-page "https://wiki.call-cc.org/eggref/5/make")
    (description "The PLT 'make' macro")
    (license license:lgpl2.0+)))

(define-public
  chicken-begin-syntax
  (package
    (name "chicken-begin-syntax")
    (version "0.2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "begin-syntax" "0.2.1"))
        (sha256
          (base32 "10xdikbpilxibjvmdnshjdwhp56lh0w6414cwgiwva2vqr7930zj"))))
    (propagated-inputs (specifications->packages (list "chicken-matchable")))
    (native-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-module-declarations")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "begin-syntax"))
    (synopsis "Convenience macro for inline syntax expansion")
    (home-page "https://wiki.call-cc.org/eggref/5/begin-syntax")
    (description "Convenience macro for inline syntax expansion")
    (license license:bsd-2)))

(define-public
  chicken-ezd
  (package
    (name "chicken-ezd")
    (version "2020.01.26")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ezd" "2020.01.26"))
        (sha256
          (base32 "1a7212xv4pr44hmz6z9gn3hv7j7v51p69jj30c6x05p4lip8myh3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-18"
              "chicken-scheme2c-compatibility"
              "chicken-xlib")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ezd"))
    (synopsis "easy drawing for programs on X displays")
    (home-page "https://wiki.call-cc.org/eggref/5/ezd")
    (description "easy drawing for programs on X displays")
    (license license:bsd-2)))

(define-public
  chicken-salmonella-diff
  (package
    (name "chicken-salmonella-diff")
    (version "1.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "salmonella-diff" "1.1.0"))
        (sha256
          (base32 "1w5qzsmx2i9cpjd2d9kkfhw6627xg19x5w6jck9gba6vgcf2s6ca"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-salmonella"
              "chicken-salmonella-html-report"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-sxml-transforms")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "salmonella-diff"))
    (synopsis "A tool to diff salmonella log files")
    (home-page "https://wiki.call-cc.org/eggref/5/salmonella-diff")
    (description "A tool to diff salmonella log files")
    (license license:bsd-2)))

(define-public
  chicken-test-utils
  (package
    (name "chicken-test-utils")
    (version "1.0.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "test-utils" "1.0.5"))
        (sha256
          (base32 "0c4zj3i4g1iq38ifdgzhrl5lz0v97qzphsyg1d2a6ps6zr7jwgbf"))))
    (propagated-inputs (specifications->packages (list "chicken-test")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "test-utils"))
    (synopsis "Test Utilities (for test egg)")
    (home-page "https://wiki.call-cc.org/eggref/5/test-utils")
    (description "Test Utilities (for test egg)")
    (license license:bsd-2)))

(define-public
  chicken-srfi-42
  (package
    (name "chicken-srfi-42")
    (version "1.76")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-42" "1.76"))
        (sha256
          (base32 "1s43an2yqzx123zlf8k1xny6wr3s5kx61hrik8bkn4wcr6w4rqla"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-42"))
    (synopsis "SRFI-42 (Eager comprehensions)")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-42")
    (description "SRFI-42 (Eager comprehensions)")
    (license license:bsd-1)))

(define-public
  chicken-utf8
  (package
    (name "chicken-utf8")
    (version "3.6.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "utf8" "3.6.3"))
        (sha256
          (base32 "0vpf2vw4k7b1f7afgminnvkgiq9m973rxi1w2y63jgg8vr7i027p"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-69" "chicken-iset" "chicken-regex")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "utf8"))
    (synopsis "Unicode support")
    (home-page "https://wiki.call-cc.org/eggref/5/utf8")
    (description "Unicode support")
    (license license:bsd-2)))

(define-public
  chicken-openssl
  (package
    (name "chicken-openssl")
    (version "2.2.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "openssl" "2.2.5"))
        (sha256
          (base32 "018x80cxs7glvqn7nhjcfbvw36bn3pf4y24a6cn7mz25z6597vg0"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-18"
              "chicken-address-info")))
    (native-inputs
      (specifications->packages
        (list "chicken-http-client"
              "chicken-server-test"
              "chicken-spiffy"
              "chicken-test"
              "chicken-uri-common")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "openssl"))
    (synopsis "Bindings to the OpenSSL SSL/TLS library")
    (home-page "https://wiki.call-cc.org/eggref/5/openssl")
    (description "Bindings to the OpenSSL SSL/TLS library")
    (license license:bsd-2)))

(define-public
  chicken-edn
  (package
    (name "chicken-edn")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "edn" "1.0"))
        (sha256
          (base32 "166qm2vx5gj7bc57s1bnnbp55zhv19hnimmivhhdhsnq32wi3511"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-r7rs"
              "chicken-srfi-69"
              "chicken-srfi-1"
              "chicken-chalk")))
    (native-inputs
      (specifications->packages
        (list "chicken-r7rs" "chicken-srfi-64" "chicken-chalk")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "edn"))
    (synopsis "EDN data reader/writer.")
    (home-page "https://wiki.call-cc.org/eggref/5/edn")
    (description "EDN data reader/writer.")
    (license license:bsd-2)))

(define-public
  chicken-mailbox
  (package
    (name "chicken-mailbox")
    (version "3.3.10")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "mailbox" "3.3.10"))
        (sha256
          (base32 "1g1fxkydd8wkqpvfv4md2ilk5vf4276ks5153da7mph2i6hbzr4a"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-srfi-18")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "mailbox"))
    (synopsis "Thread-safe queues with timeout")
    (home-page "https://wiki.call-cc.org/eggref/5/mailbox")
    (description "Thread-safe queues with timeout")
    (license license:bsd-2)))

(define-public
  chicken-exif
  (package
    (name "chicken-exif")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "exif" "1.2"))
        (sha256
          (base32 "1gqlkxabpzb951fkrq2lgdq55sds8713iawdqvf3sqj25qbkz3j4"))))
    (propagated-inputs
      (specifications->packages (list "chicken-foreigners" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "exif"))
    (synopsis
      "Binding to libexif, reading EXIF meta data from digital camera images.")
    (home-page "https://wiki.call-cc.org/eggref/5/exif")
    (description
      "Binding to libexif, reading EXIF meta data from digital camera images.")
    (license license:bsd-2)))

(define-public
  chicken-pdf
  (package
    (name "chicken-pdf")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pdf" "1.1"))
        (sha256
          (base32 "1klqq78pcdg2r8simcyjkdjb9664h5cz2indksjdlpj3ma3zb3ax"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-regex" "chicken-format")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pdf"))
    (synopsis "A library for PDF generation.")
    (home-page "https://wiki.call-cc.org/eggref/5/pdf")
    (description "A library for PDF generation.")
    (license license:bsd-2)))

(define-public
  chicken-srfi-116
  (package
    (name "chicken-srfi-116")
    (version "1.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-116" "1.7"))
        (sha256
          (base32 "0jwpav26shl9isi4i3xi01am7s472kk9jxlzj8fb1afjj3kmwgar"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-128")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-116"))
    (synopsis "SRFI-116: Immutable Lists.")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-116")
    (description "SRFI-116: Immutable Lists.")
    (license license:bsd-2)))

(define-public
  chicken-srfi-178
  (package
    (name "chicken-srfi-178")
    (version "1.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-178" "1.0.2"))
        (sha256
          (base32 "1njgn227ihvci6nbabmrbhdldpbar4yrs6cph7fbsw9h13cgbl50"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-151" "chicken-srfi-160" "chicken-srfi-141")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-178"))
    (synopsis "SRFI 178: Bitvector library")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-178")
    (description "SRFI 178: Bitvector library")
    (license license:expat)))

(define-public
  chicken-atom
  (package
    (name "chicken-atom")
    (version "0.1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "atom" "0.1.5"))
        (sha256
          (base32 "0apb3g551n0qi594m1sl2vamcb0p3w36dyxk6lpj9q1fshgg4mym"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable"
              "chicken-ssax"
              "chicken-sxml-serializer"
              "chicken-regex")))
    (native-inputs
      (specifications->packages (list "chicken-rfc3339" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "atom"))
    (synopsis "Atom 1.0 feed reader and writer")
    (home-page "https://wiki.call-cc.org/eggref/5/atom")
    (description "Atom 1.0 feed reader and writer")
    (license license:bsd-2)))

(define-public
  chicken-ipfs
  (package
    (name "chicken-ipfs")
    (version "0.0.14")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ipfs" "0.0.14"))
        (sha256
          (base32 "108fmxv5cwwvv70bjh6cwc6l4djxb1mnb7wn2jp3ad5s58hhw1pb"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-http-client"
              "chicken-intarweb"
              "chicken-medea"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-189"
              "chicken-srfi-197"
              "chicken-uri-common")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ipfs"))
    (synopsis "IPFS HTTP API for Scheme")
    (home-page "https://wiki.call-cc.org/eggref/5/ipfs")
    (description "IPFS HTTP API for Scheme")
    (license license:unlicense)))

(define-public
  chicken-lexgen
  (package
    (name "chicken-lexgen")
    (version "8.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "lexgen" "8.2"))
        (sha256
          (base32 "1dbvs2g5772w8nvh62rvnsqsmivr76ypkbncbs8l0rx9qi8ir9fn"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-utf8" "chicken-srfi-127")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-14")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "lexgen"))
    (synopsis "Lexer combinators")
    (home-page "https://wiki.call-cc.org/eggref/5/lexgen")
    (description "Lexer combinators")
    (license license:gpl3)))

(define-public
  chicken-doctype
  (package
    (name "chicken-doctype")
    (version "2.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "doctype" "2.2"))
        (sha256
          (base32 "1k3wabdnlyavdmpgdfyz8msr9s2y0kllvp3kw9hmjdlwlyfzw1ag"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "doctype"))
    (synopsis
      "Exports strings corresponding to standard XML (XHTML, HTML) doctypes")
    (home-page "https://wiki.call-cc.org/eggref/5/doctype")
    (description
      "Exports strings corresponding to standard XML (XHTML, HTML) doctypes")
    (license license:public-domain)))

(define-public
  chicken-digraph
  (package
    (name "chicken-digraph")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "digraph" "2.0"))
        (sha256
          (base32 "0dkagz0rs27zh6cfmfqld18wb63pq3acylwidky3v01maw36c41r"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-dyn-vector"
              "chicken-matchable"
              "chicken-yasos"
              "chicken-srfi-1")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "digraph"))
    (synopsis "Directed graph in adjacency list format.")
    (home-page "https://wiki.call-cc.org/eggref/5/digraph")
    (description "Directed graph in adjacency list format.")
    (license license:gpl3)))

(define-public
  chicken-alist-lib
  (package
    (name "chicken-alist-lib")
    (version "0.3.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "alist-lib" "0.3.0"))
        (sha256
          (base32 "0v8aab5wknj736rxb83gjlwlaxlg7lz5cxpsngniz7ilrs2b3fdl"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-hahn" "chicken-matchable" "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "alist-lib"))
    (synopsis "SRFI-69-like library for alists")
    (home-page "https://wiki.call-cc.org/eggref/5/alist-lib")
    (description "SRFI-69-like library for alists")
    (license license:bsd-2)))

(define-public
  chicken-srfi-196
  (package
    (name "chicken-srfi-196")
    (version "1.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-196" "1.0.1"))
        (sha256
          (base32 "0nhkd3n4rx5ibqbxbz36braih5szw4x4221jx0yg3v04vnv81cab"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-133"
              "chicken-typed-records"
              "chicken-utf8")))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-test-generative" "chicken-utf8")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-196"))
    (synopsis "SRFI-196: Range Objects")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-196")
    (description "SRFI-196: Range Objects")
    (license license:expat)))

(define-public
  chicken-chicken-update
  (package
    (name "chicken-chicken-update")
    (version "0.1.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "chicken-update" "0.1.6"))
        (sha256
          (base32 "1kbxk93k7p9x2594q4zsya93m7rzpnhixksvdvmiwq42dj72hyid"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-fmt"
              "chicken-sxpath"
              "chicken-http-client"
              "chicken-uri-common"
              "chicken-optimism"
              "chicken-ssax")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "chicken-update"))
    (synopsis "Update installed eggs")
    (home-page "https://wiki.call-cc.org/eggref/5/chicken-update")
    (description "Update installed eggs")
    (license license:public-domain)))

(define-public
  chicken-opengl
  (package
    (name "chicken-opengl")
    (version "1.21")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "opengl" "1.21"))
        (sha256
          (base32 "0sd75k8bm68w2c1n1jlb6yn67xsij49wfgvdakpm4aldqpi79cks"))))
    (propagated-inputs
      (specifications->packages (list "chicken-bind" "chicken-silex")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "opengl"))
    (synopsis "OpenGL bindings")
    (home-page "https://wiki.call-cc.org/eggref/5/opengl")
    (description "OpenGL bindings")
    (license license:bsd-2)))

(define-public
  chicken-sdl2-ttf
  (package
    (name "chicken-sdl2-ttf")
    (version "0.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sdl2-ttf" "0.2.0"))
        (sha256
          (base32 "0sbj9dib5dx9gc8wayg3a74ag028spysqnl70r2x9hrvdh7pyclj"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-sdl2" "chicken-miscmacros" "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sdl2-ttf"))
    (synopsis "Bindings to SDL_ttf 2")
    (home-page "https://wiki.call-cc.org/eggref/5/sdl2-ttf")
    (description "Bindings to SDL_ttf 2")
    (license license:bsd-2)))

(define-public
  chicken-list-comprehensions
  (package
    (name "chicken-list-comprehensions")
    (version "1.2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "list-comprehensions" "1.2.1"))
        (sha256
          (base32 "09v0k4wx4i456hdpsnani9i6ky7cy4sja4p57y4aqc5y5n1zaf0w"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "list-comprehensions"))
    (synopsis "Some list creating routines")
    (home-page "https://wiki.call-cc.org/eggref/5/list-comprehensions")
    (description "Some list creating routines")
    (license license:bsd-2)))

(define-public
  chicken-srfi-113
  (package
    (name "chicken-srfi-113")
    (version "1.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-113" "1.2.0"))
        (sha256
          (base32 "0ripxgwfwizj9mzb04lsbvavvy7qima81cyqm830j59sixj6ldc2"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-r7rs" "chicken-srfi-69" "chicken-srfi-128")))
    (native-inputs
      (specifications->packages (list "chicken-srfi-13" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-113"))
    (synopsis "SRFI-113: Sets and Bags")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-113")
    (description "SRFI-113: Sets and Bags")
    (license license:bsd-2)))

(define-public
  chicken-math
  (package
    (name "chicken-math")
    (version "0.3.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "math" "0.3.4"))
        (sha256
          (base32 "0q4996hf2wi043vni1006gm4xkj0rk76f505k158ggdv0ihqg5l7"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-r6rs-bytevectors"
              "chicken-miscmacros"
              "chicken-srfi-133"
              "chicken-srfi-42")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "math"))
    (synopsis "Chicken port of Racket's math library")
    (home-page "https://wiki.call-cc.org/eggref/5/math")
    (description "Chicken port of Racket's math library")
    (license license:gpl3)))

(define-public
  chicken-ripemd
  (package
    (name "chicken-ripemd")
    (version "2.1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ripemd" "2.1.2"))
        (sha256
          (base32 "18d0f37a13nsknay6vw27xvr1k0s4p4ss2dc29fhx89hsv5ycjsq"))))
    (propagated-inputs
      (specifications->packages (list "chicken-message-digest-primitive")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-test-utils"
              "chicken-srfi-13"
              "chicken-message-digest-utils"
              "chicken-message-digest-primitive")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ripemd"))
    (synopsis "RIPE Message Digest")
    (home-page "https://wiki.call-cc.org/eggref/5/ripemd")
    (description "RIPE Message Digest")
    (license license:bsd-2)))

(define-public
  chicken-awful-sse
  (package
    (name "chicken-awful-sse")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "awful-sse" "0.3"))
        (sha256
          (base32 "0jmrccwhq14j0ga8ac7vn2rkm3yyskaw3chhzvr8y3j4vsb0kala"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-awful" "chicken-spiffy" "chicken-intarweb")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-server-test"
              "chicken-uri-common"
              "chicken-http-client")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "awful-sse"))
    (synopsis "Server-Sent Events module for Awful")
    (home-page "https://wiki.call-cc.org/eggref/5/awful-sse")
    (description "Server-Sent Events module for Awful")
    (license license:bsd-2)))

(define-public
  chicken-breadline
  (package
    (name "chicken-breadline")
    (version "0.11")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "breadline" "0.11"))
        (sha256
          (base32 "1rvppf2aci4dxn6a74nzzj1iw7is65ad38fbvrr9harazfx6j4jy"))))
    (propagated-inputs
      (specifications->packages (list "chicken-apropos" "chicken-srfi-18")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "breadline"))
    (synopsis "Bindings to readline")
    (home-page "https://wiki.call-cc.org/eggref/5/breadline")
    (description "Bindings to readline")
    (license license:gpl3)))

(define-public
  chicken-graph-dfs
  (package
    (name "chicken-graph-dfs")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "graph-dfs" "2.0"))
        (sha256
          (base32 "13v9bg4isf707ldid13bz2vrnklwr8vnjlma08p51la6y71cy196"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-iset"
              "chicken-matchable"
              "chicken-yasos"
              "chicken-digraph")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "graph-dfs"))
    (synopsis "Depth-first search in a graph.")
    (home-page "https://wiki.call-cc.org/eggref/5/graph-dfs")
    (description "Depth-first search in a graph.")
    (license license:gpl3)))

(define-public
  chicken-spiffy-uri-match
  (package
    (name "chicken-spiffy-uri-match")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "spiffy-uri-match" "1.0"))
        (sha256
          (base32 "0hqr1m4zd0i5ajnyhr4892sdrd2nfm81hjsjvl3ydrygwma8znbn"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-uri-match"
              "chicken-spiffy"
              "chicken-uri-common"
              "chicken-intarweb")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "spiffy-uri-match"))
    (synopsis "uri-match integration for spiffy")
    (home-page "https://wiki.call-cc.org/eggref/5/spiffy-uri-match")
    (description "uri-match integration for spiffy")
    (license license:bsd-2)))

(define-public
  chicken-rocksdb
  (package
    (name "chicken-rocksdb")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "rocksdb" "1.0"))
        (sha256
          (base32 "1yrsclyzapyb96s46095xfd8yshp0rvxf3j5h9jbdqm93sqg2aic"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "rocksdb"))
    (synopsis "Bindings to Facebooks's RocksDB Key-Value Store")
    (home-page "https://wiki.call-cc.org/eggref/5/rocksdb")
    (description "Bindings to Facebooks's RocksDB Key-Value Store")
    (license license:bsd-2)))

(define-public
  chicken-smtp
  (package
    (name "chicken-smtp")
    (version "5.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "smtp" "5.2"))
        (sha256
          (base32 "122f454xw3f99x71m11i3p593h17mac5xnglmr1fzalfdd1b4909"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable"
              "chicken-datatype"
              "chicken-utf8"
              "chicken-abnf")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-13")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "smtp"))
    (synopsis
      "Parser combinators and state machine for Simple Mail Transfer Protocol (RFC 5321).")
    (home-page "https://wiki.call-cc.org/eggref/5/smtp")
    (description
      "Parser combinators and state machine for Simple Mail Transfer Protocol (RFC 5321).")
    (license license:gpl3)))

(define-public
  chicken-srfi-19
  (package
    (name "chicken-srfi-19")
    (version "4.9.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-19" "4.9.6"))
        (sha256
          (base32 "0vqwg2sknm7fm677npbjdvhcfa2s6l41sgvhkk11m10b8jgnr1b3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-utf8"
              "chicken-srfi-18"
              "chicken-srfi-29"
              "chicken-miscmacros"
              "chicken-locale"
              "chicken-record-variants"
              "chicken-check-errors")))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-test-utils" "chicken-format")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-19"))
    (synopsis "Time Data Types and Procedures")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-19")
    (description "Time Data Types and Procedures")
    (license license:bsd-2)))

(define-public
  chicken-srfi-146
  (package
    (name "chicken-srfi-146")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-146" "0.1"))
        (sha256
          (base32 "0pdlcfhmy50nigi9q3rdy9hhrhw4jmrm5rcdl30d402yaj8fq5q6"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-hash-trie"
              "chicken-srfi-1"
              "chicken-srfi-128"
              "chicken-srfi-145"
              "chicken-srfi-158")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-146"))
    (synopsis "SRFI 146: Mappings")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-146")
    (description "SRFI 146: Mappings")
    (license license:expat)))

(define-public
  chicken-sxpath
  (package
    (name "chicken-sxpath")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sxpath" "1.0"))
        (sha256
          (base32 "177wjyz5pj4m783pfhwk070qll2b9iw9m0lh3nyyf6mp2w803ylf"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sxpath"))
    (synopsis
      "The sxpath bits of sxml-tools from the SSAX project at Sourceforge")
    (home-page "https://wiki.call-cc.org/eggref/5/sxpath")
    (description
      "The sxpath bits of sxml-tools from the SSAX project at Sourceforge")
    (license license:public-domain)))

(define-public
  chicken-rfc3339
  (package
    (name "chicken-rfc3339")
    (version "0.1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "rfc3339" "0.1.3"))
        (sha256
          (base32 "0gfwz46jjs2jffax8xl3cd0bmja36mhcxikn45prbgafsam30y1l"))))
    (propagated-inputs
      (specifications->packages (list "chicken-matchable" "chicken-regex")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "rfc3339"))
    (synopsis "RFC3339 datetime parser")
    (home-page "https://wiki.call-cc.org/eggref/5/rfc3339")
    (description "RFC3339 datetime parser")
    (license license:bsd-2)))

(define-public
  chicken-csv-abnf
  (package
    (name "chicken-csv-abnf")
    (version "6.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "csv-abnf" "6.1"))
        (sha256
          (base32 "1pqkk40c4i1lxhdwp6ghigmjxdn735j9m4b5ysswj39ypmx6d4i4"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-regex" "chicken-utf8" "chicken-abnf" "chicken-yasos")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "csv-abnf"))
    (synopsis "Parsing and formatting of comma-separated values (CSV).")
    (home-page "https://wiki.call-cc.org/eggref/5/csv-abnf")
    (description "Parsing and formatting of comma-separated values (CSV).")
    (license license:gpl3)))

(define-public
  chicken-message-digest-utils
  (package
    (name "chicken-message-digest-utils")
    (version "4.3.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "message-digest-utils" "4.3.5"))
        (sha256
          (base32 "004da7czv5mqxz8cif2nc0shx1xxj266alqm2370h13wbdl369c3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-blob-utils"
              "chicken-string-utils"
              "chicken-memory-mapped-files"
              "chicken-message-digest-primitive"
              "chicken-message-digest-type"
              "chicken-check-errors")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "message-digest-utils"))
    (synopsis "Message Digest Support")
    (home-page "https://wiki.call-cc.org/eggref/5/message-digest-utils")
    (description "Message Digest Support")
    (license license:bsd-2)))

(define-public
  chicken-sdl2
  (package
    (name "chicken-sdl2")
    (version "0.4.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sdl2" "0.4.1"))
        (sha256
          (base32 "0is0x43273413jk7d8y80q27vc0yi8rpa7r72nb9rlzxwcazl5zn"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sdl2"))
    (synopsis "Bindings to Simple DirectMedia Layer 2 (SDL2)")
    (home-page "https://wiki.call-cc.org/eggref/5/sdl2")
    (description "Bindings to Simple DirectMedia Layer 2 (SDL2)")
    (license license:bsd-2)))

(define-public
  chicken-r7rs
  (package
    (name "chicken-r7rs")
    (version "1.0.9")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "r7rs" "1.0.9"))
        (sha256
          (base32 "1rwx52mjsylvbkmpg0z7jbawaf87dsxdgwgq8z5nh8k5nb03b6v5"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable" "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "r7rs"))
    (synopsis "R7RS compatibility")
    (home-page "https://wiki.call-cc.org/eggref/5/r7rs")
    (description "R7RS compatibility")
    (license license:bsd-2)))

(define-public
  chicken-generalized-arrays
  (package
    (name "chicken-generalized-arrays")
    (version "2.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "generalized-arrays" "2.0.0"))
        (sha256
          (base32 "1ypga6lanhqsm8lpgk6s1nj4q024xb9kl9ar58cwj53h1irn7942"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-r7rs"
              "chicken-srfi-48"
              "chicken-srfi-128"
              "chicken-srfi-133"
              "chicken-srfi-160"
              "chicken-check-errors"
              "chicken-transducers")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "generalized-arrays"))
    (synopsis
      "Provides generalized arrays, intervals, and storage classes for CHICKEN Scheme.")
    (home-page "https://wiki.call-cc.org/eggref/5/generalized-arrays")
    (description
      "Provides generalized arrays, intervals, and storage classes for CHICKEN Scheme.")
    (license license:bsd-3)))

(define-public
  chicken-system
  (package
    (name "chicken-system")
    (version "0.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "system" "0.8"))
        (sha256
          (base32 "18sp0r0qsq8aw3ff9f4cv5a3n6p7yh5jlwf0s22x8bswi4377a76"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-coops"
              "chicken-shell"
              "chicken-compile-file"
              "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "system"))
    (synopsis "load and compile groups of files")
    (home-page "https://wiki.call-cc.org/eggref/5/system")
    (description "load and compile groups of files")
    (license license:bsd-2)))

(define-public
  chicken-symbol-utils
  (package
    (name "chicken-symbol-utils")
    (version "2.5.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "symbol-utils" "2.5.0"))
        (sha256
          (base32 "0mxcdlf1i0xn70h9l5grgx1yvkbgq9rcvil02gdp9by5qqcqmklh"))))
    (propagated-inputs (specifications->packages (list "chicken-utf8")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "symbol-utils"))
    (synopsis "Symbol Utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/symbol-utils")
    (description "Symbol Utilities")
    (license license:bsd-2)))

(define-public
  chicken-nrepl
  (package
    (name "chicken-nrepl")
    (version "5.0.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "nrepl" "5.0.8"))
        (sha256
          (base32 "0d4pl1j1wayqsdryc5v8la5v5p9nifwva86z48vlss3s388na208"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-18")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "nrepl"))
    (synopsis "Simple networked REPL over TCP")
    (home-page "https://wiki.call-cc.org/eggref/5/nrepl")
    (description "Simple networked REPL over TCP")
    (license license:bsd-2)))

(define-public
  chicken-fix-me-now
  (package
    (name "chicken-fix-me-now")
    (version "1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "fix-me-now" "1.5"))
        (sha256
          (base32 "1acp5bdqd9k0gdjvnv41q77v0f1dkjxqmyvqq9xsgrm9xpv0mzw8"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-strse" "chicken-srfi-1" "chicken-sxml-transforms")))
    (native-inputs (specifications->packages (list "chicken-brev-separate")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "fix-me-now"))
    (synopsis "Make tweaks and changes to sexp trees")
    (home-page "https://wiki.call-cc.org/eggref/5/fix-me-now")
    (description "Make tweaks and changes to sexp trees")
    (license license:bsd-1)))

(define-public
  chicken-lowdown
  (package
    (name "chicken-lowdown")
    (version "3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "lowdown" "3"))
        (sha256
          (base32 "0ihnsnjr2mfac2z053ra5167791c3jzz11wvj1fz2jz688pdr6rg"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-char-set-literals"
              "chicken-clojurian"
              "chicken-comparse"
              "chicken-fancypants"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14"
              "chicken-srfi-69"
              "chicken-sxml-transforms")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "lowdown"))
    (synopsis "A pure Chicken Markdown parser")
    (home-page "https://wiki.call-cc.org/eggref/5/lowdown")
    (description "A pure Chicken Markdown parser")
    (license license:bsd-2)))

(define-public
  chicken-pseudo-meta-egg-info
  (package
    (name "chicken-pseudo-meta-egg-info")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pseudo-meta-egg-info" "1.1"))
        (sha256
          (base32 "0dmhxm851vbzfcf14sqqxqpmigxvi0195ih9zb25nbxnsdcmy684"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-spiffy" "chicken-uri-common" "chicken-svn-client")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pseudo-meta-egg-info"))
    (synopsis
      "Provide automatically generated release-info and a pseudo-\"meta\"-file for eggs in svn")
    (home-page "https://wiki.call-cc.org/eggref/5/pseudo-meta-egg-info")
    (description
      "Provide automatically generated release-info and a pseudo-\"meta\"-file for eggs in svn")
    (license license:public-domain)))

(define-public
  chicken-synch
  (package
    (name "chicken-synch")
    (version "3.3.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "synch" "3.3.8"))
        (sha256
          (base32 "0hqwk1xfrslcyigjj9z28lki8xdb1x1ccvss225mnmahpdn42pp8"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-18" "chicken-check-errors")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-test-utils"
              "chicken-srfi-18"
              "chicken-srfi-69")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "synch"))
    (synopsis "Synchronization Forms")
    (home-page "https://wiki.call-cc.org/eggref/5/synch")
    (description "Synchronization Forms")
    (license license:bsd-2)))

(define-public
  chicken-sql-null
  (package
    (name "chicken-sql-null")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sql-null" "2.0"))
        (sha256
          (base32 "0700qryzi38rah26fzrh04njd4r88ksi366mf2259zilwzmlf2nh"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sql-null"))
    (synopsis "A convenience extension for representing SQL NULL values")
    (home-page "https://wiki.call-cc.org/eggref/5/sql-null")
    (description "A convenience extension for representing SQL NULL values")
    (license license:public-domain)))

(define-public
  chicken-introspect
  (package
    (name "chicken-introspect")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "introspect" "0.2"))
        (sha256
          (base32 "0r8fcqrzq2cj3vcr484v0k7f706pnylv7mq9lq3ra5pv079fblz3"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "introspect"))
    (synopsis "Module introspection")
    (home-page "https://wiki.call-cc.org/eggref/5/introspect")
    (description "Module introspection")
    (license license:bsd-2)))

(define-public
  chicken-simple-exceptions
  (package
    (name "chicken-simple-exceptions")
    (version "1.3.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "simple-exceptions" "1.3.1"))
        (sha256
          (base32 "0phsfz2263yiy9z33sf7qjf4i8kh51n5yf1g2wmb0pb63vcdqy8n"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "simple-exceptions"))
    (synopsis "Some user-friendly exception routines")
    (home-page "https://wiki.call-cc.org/eggref/5/simple-exceptions")
    (description "Some user-friendly exception routines")
    (license license:bsd-2)))

(define-public
  chicken-tokyocabinet
  (package
    (name "chicken-tokyocabinet")
    (version "0.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "tokyocabinet" "0.1.0"))
        (sha256
          (base32 "0x285jydmkgx46gqwnjxczmbbpmbv17jpqf7k6k4jiix6x54q5vg"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "tokyocabinet"))
    (synopsis "Tokyo Cabinet hash database interface")
    (home-page "https://wiki.call-cc.org/eggref/5/tokyocabinet")
    (description "Tokyo Cabinet hash database interface")
    (license license:bsd-2)))

(define-public
  chicken-snowtar
  (package
    (name "chicken-snowtar")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "snowtar" "1.1"))
        (sha256
          (base32 "00m1s8i4d46ibbav5dqiwflm6xa2d5kydss1jsxx0sv8948c8iyc"))))
    (propagated-inputs (specifications->packages (list "chicken-miscmacros")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "snowtar"))
    (synopsis "TAR file format packing and unpacking.")
    (home-page "https://wiki.call-cc.org/eggref/5/snowtar")
    (description "TAR file format packing and unpacking.")
    (license license:lgpl2.1+)))

(define-public
  chicken-mpi
  (package
    (name "chicken-mpi")
    (version "2.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "mpi" "2.5"))
        (sha256
          (base32 "0ca91ny4cqgd69f62l0slg8f9dvnchy6c289nmik7wnnr8ns1g13"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-13" "chicken-srfi-14")))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-srfi-1" "chicken-compile-file")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "mpi"))
    (synopsis "Message-passing Interface (MPI)")
    (home-page "https://wiki.call-cc.org/eggref/5/mpi")
    (description "Message-passing Interface (MPI)")
    (license license:gpl3)))

(define-public
  chicken-graph-bfs
  (package
    (name "chicken-graph-bfs")
    (version "2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "graph-bfs" "2.1"))
        (sha256
          (base32 "0kw1xszqnph2b2p8mzf8gskd6g3v3a5shvm7bndwwkly2l8p178a"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-iset"
              "chicken-matchable"
              "chicken-yasos"
              "chicken-digraph")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "graph-bfs"))
    (synopsis "Breadth-first search in a graph.")
    (home-page "https://wiki.call-cc.org/eggref/5/graph-bfs")
    (description "Breadth-first search in a graph.")
    (license license:gpl3)))

(define-public
  chicken-web-colors
  (package
    (name "chicken-web-colors")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "web-colors" "1.0.0"))
        (sha256
          (base32 "05q5rrw4dmnswrb2sfzyvn970s9xclwhcvzybs0qdb15qq89g4jn"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-13")))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "web-colors"))
    (synopsis "Parse and write HTML/CSS color strings")
    (home-page "https://wiki.call-cc.org/eggref/5/web-colors")
    (description "Parse and write HTML/CSS color strings")
    (license license:bsd-2)))

(define-public
  chicken-fmt
  (package
    (name "chicken-fmt")
    (version "0.8.11")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "fmt" "0.8.11.2"))
        (sha256
          (base32 "0w04zfkhh8cnns6n0m1s9zh8jn7nvm3h4nzvfzxiih84i6y13yx1"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-69"
              "chicken-utf8")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "fmt"))
    (synopsis "Combinator Formatting")
    (home-page "https://wiki.call-cc.org/eggref/5/fmt")
    (description "Combinator Formatting")
    (license license:bsd-2)))

(define-public
  chicken-srfi-60
  (package
    (name "chicken-srfi-60")
    (version "0.7.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-60" "0.7.1"))
        (sha256
          (base32 "18cfqkq5pfgfh21c1m1n6m10imqnpfljmwzzzy15wrzgbqw04z8n"))))
    (propagated-inputs
      (specifications->packages (list "chicken-bitwise-utils")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-60"))
    (synopsis "SRFI 60: Integers as bits")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-60")
    (description "SRFI 60: Integers as bits")
    (license license:expat)))

(define-public
  chicken-mathh
  (package
    (name "chicken-mathh")
    (version "4.7.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "mathh" "4.7.0"))
        (sha256
          (base32 "1mf9aqjwp068a93fmkm29f5mawc15nizm8wwvfra1af7y4f434al"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "mathh"))
    (synopsis "ISO C math functions and constants")
    (home-page "https://wiki.call-cc.org/eggref/5/mathh")
    (description "ISO C math functions and constants")
    (license license:public-domain)))

(define-public
  chicken-jsmin
  (package
    (name "chicken-jsmin")
    (version "2.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "jsmin" "2.2"))
        (sha256
          (base32 "0spkddwisamn8mwjl4ayqy8g233vcmsrgar8aqk83dv3p5ax8kmi"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "jsmin"))
    (synopsis
      "Implementation of Douglas Crockford's JavaScript minifier in CHICKEN Scheme")
    (home-page "https://wiki.call-cc.org/eggref/5/jsmin")
    (description
      "Implementation of Douglas Crockford's JavaScript minifier in CHICKEN Scheme")
    (license license:bsd-2)))

(define-public
  chicken-chicken-doc
  (package
    (name "chicken-chicken-doc")
    (version "0.7.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "chicken-doc" "0.7.0"))
        (sha256
          (base32 "1p7i5dsi9x8kfchh3xdw9ww9pz2p861v8vynqzwmbclpqjrspllh"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable"
              "chicken-fmt"
              "chicken-sxml-transforms"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-69")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "chicken-doc"))
    (synopsis "Explore Chicken documentation locally")
    (home-page "https://wiki.call-cc.org/eggref/5/chicken-doc")
    (description "Explore Chicken documentation locally")
    (license license:bsd-2)))

(define-public
  chicken-kd-tree
  (package
    (name "chicken-kd-tree")
    (version "6.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "kd-tree" "6.1"))
        (sha256
          (base32 "14b1v6smk3gx1n0mqldnfjr5n6r9xhs56c8gvrssh5k0a41nk8j4"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-datatype" "chicken-yasos")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-random-mtzig")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "kd-tree"))
    (synopsis "K-D tree spatial indexing structure.")
    (home-page "https://wiki.call-cc.org/eggref/5/kd-tree")
    (description "K-D tree spatial indexing structure.")
    (license license:gpl3)))

(define-public
  chicken-gochan
  (package
    (name "chicken-gochan")
    (version "5.2.10")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "gochan" "5.2.10"))
        (sha256
          (base32 "1pyzr387zbbw7x9zk524qcs368hzxv4c46p24cz3x2nl30y84d5h"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable" "chicken-srfi-18" "chicken-queues")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "gochan"))
    (synopsis "golang channels in CHICKEN")
    (home-page "https://wiki.call-cc.org/eggref/5/gochan")
    (description "golang channels in CHICKEN")
    (license license:bsd-2)))

(define-public
  chicken-http-session
  (package
    (name "chicken-http-session")
    (version "2.10")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "http-session" "2.10"))
        (sha256
          (base32 "1yjzkax2m3jz05640la0ry11vafrqwdhn2sd1jr0w8yhgbwwfprs"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-intarweb"
              "chicken-simple-sha1"
              "chicken-spiffy"
              "chicken-srfi-1"
              "chicken-srfi-18"
              "chicken-srfi-69"
              "chicken-uri-common")))
    (native-inputs
      (specifications->packages
        (list "chicken-intarweb"
              "chicken-simple-sha1"
              "chicken-spiffy"
              "chicken-srfi-1"
              "chicken-srfi-18"
              "chicken-srfi-69"
              "chicken-uri-common")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "http-session"))
    (synopsis "Facilities for managing HTTP sessions")
    (home-page "https://wiki.call-cc.org/eggref/5/http-session")
    (description "Facilities for managing HTTP sessions")
    (license license:bsd-2)))

(define-public
  chicken-sxml-transforms
  (package
    (name "chicken-sxml-transforms")
    (version "1.4.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sxml-transforms" "1.4.3"))
        (sha256
          (base32 "0cvpqgjwz1p5vg8jwjr2p1l3hx9s02f083g84v16wv88y3d5rsbg"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sxml-transforms"))
    (synopsis
      "The SXML transformations (to XML, SXML, and HTML) from the SSAX project at Sourceforge")
    (home-page "https://wiki.call-cc.org/eggref/5/sxml-transforms")
    (description
      "The SXML transformations (to XML, SXML, and HTML) from the SSAX project at Sourceforge")
    (license license:public-domain)))

(define-public
  chicken-srfi-115
  (package
    (name "chicken-srfi-115")
    (version "0.3.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-115" "0.3.2"))
        (sha256
          (base32 "19vy0rbvmq7si758zlqqys94c2dicl8546fv3xhlpagas38wb4lb"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-14" "chicken-srfi-152")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-115"))
    (synopsis "SRFI 115: Scheme Regular Expressions")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-115")
    (description "SRFI 115: Scheme Regular Expressions")
    (license license:expat)))

(define-public
  chicken-strse
  (package
    (name "chicken-strse")
    (version "1.39")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "strse" "1.39"))
        (sha256
          (base32 "1abwb27l8ms7cwdc03wfa51jdqngjdfxdfayjynsvbhw5hp4rxmf"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable" "chicken-srfi-13" "chicken-miscmacros")))
    (native-inputs (specifications->packages (list "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "strse"))
    (synopsis "A string DSL")
    (home-page "https://wiki.call-cc.org/eggref/5/strse")
    (description "A string DSL")
    (license license:bsd-1)))

(define-public
  chicken-natural-sort
  (package
    (name "chicken-natural-sort")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "natural-sort" "1.1"))
        (sha256
          (base32 "002xxdqydn20aynsimgi3p5m7cm28c1cdyqmwxg6k59pd5c2djpx"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-13")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "natural-sort"))
    (synopsis "Natural sorting procedures")
    (home-page "https://wiki.call-cc.org/eggref/5/natural-sort")
    (description "Natural sorting procedures")
    (license license:expat)))

(define-public
  chicken-arrays
  (package
    (name "chicken-arrays")
    (version "1.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "arrays" "1.0.2"))
        (sha256
          (base32 "15ccg54vfimz8pn6rzvr7p2wgs8jarszkcs5wqahy7vy7w4r1pfr"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "arrays"))
    (synopsis "Functional arrays and sets")
    (home-page "https://wiki.call-cc.org/eggref/5/arrays")
    (description "Functional arrays and sets")
    (license license:bsd-2)))

(define-public
  chicken-debugger-protocol
  (package
    (name "chicken-debugger-protocol")
    (version "0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "debugger-protocol" "0.4"))
        (sha256
          (base32 "02iq3s4j2ar6hrqds6k3m9h4s3a6viwm4gj4m6fkrw0bpcyb6cny"))))
    (propagated-inputs (specifications->packages (list "chicken-matchable")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "debugger-protocol"))
    (synopsis "Low-level interface to debugger-protocol")
    (home-page "https://wiki.call-cc.org/eggref/5/debugger-protocol")
    (description "Low-level interface to debugger-protocol")
    (license license:bsd-2)))

(define-public
  chicken-iup
  (package
    (name "chicken-iup")
    (version "1.9.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "iup" "1.9.5"))
        (sha256
          (base32 "1b7pqkmqkavzjaf7hiyvyvqizrkx3l9j7dk449cnas27p5sczsgn"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-42"
              "chicken-srfi-69"
              "chicken-miscmacros")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "iup"))
    (synopsis "Bindings to the IUP GUI library")
    (home-page "https://wiki.call-cc.org/eggref/5/iup")
    (description "Bindings to the IUP GUI library")
    (license license:bsd-2)))

(define-public
  chicken-vlist
  (package
    (name "chicken-vlist")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "vlist" "1.1"))
        (sha256
          (base32 "0vmxll3x7b4inp3jwzvkzjkvqw79imkmsaygwvn9r3l1hzypxmas"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-srfi-69")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "vlist"))
    (synopsis
      "An implementation of vlists, a functional list-like data structure.")
    (home-page "https://wiki.call-cc.org/eggref/5/vlist")
    (description
      "An implementation of vlists, a functional list-like data structure.")
    (license license:lgpl3)))

(define-public
  chicken-timed-resource
  (package
    (name "chicken-timed-resource")
    (version "2.4.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "timed-resource" "2.4.2"))
        (sha256
          (base32 "1jycpy7vxl8d3acnjyz531nqyhgy4n8baqjzd5af1kxy69qvmzgs"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-record-variants"
              "chicken-check-errors"
              "chicken-thread-utils"
              "chicken-srfi-1"
              "chicken-srfi-18"
              "chicken-synch"
              "chicken-miscmacros")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-18")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "timed-resource"))
    (synopsis "Resource w/ Timeout")
    (home-page "https://wiki.call-cc.org/eggref/5/timed-resource")
    (description "Resource w/ Timeout")
    (license license:bsd-2)))

(define-public
  chicken-henrietta-cache-git
  (package
    (name "chicken-henrietta-cache-git")
    (version "0.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "henrietta-cache-git" "0.0.1"))
        (sha256
          (base32 "0mmx7b0xi0b95gz0z2j93r6fmm04y3m22x4n0n1klq8vm71vg5rx"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "henrietta-cache-git"))
    (synopsis
      "A tool to convert and keep henrietta's cache in a git repository")
    (home-page "https://wiki.call-cc.org/eggref/5/henrietta-cache-git")
    (description
      "A tool to convert and keep henrietta's cache in a git repository")
    (license license:bsd-2)))

(define-public
  chicken-mosquitto
  (package
    (name "chicken-mosquitto")
    (version "0.1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "mosquitto" "0.1.4"))
        (sha256
          (base32 "1pdhks3wii43l5wbmqich93zk6vy0b62h8qhv1k2wd8llv33gx6r"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "mosquitto"))
    (synopsis "Bindings to mosquitto MQTT client library")
    (home-page "https://wiki.call-cc.org/eggref/5/mosquitto")
    (description "Bindings to mosquitto MQTT client library")
    (license license:expat)))

(define-public
  chicken-byte-blob
  (package
    (name "chicken-byte-blob")
    (version "2.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "byte-blob" "2.3"))
        (sha256
          (base32 "18zppf0ikpj5mrc0kpgxbkcrk259xsl2s46snw1q73f7qnh0k8hv"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "byte-blob"))
    (synopsis "Byte array utility procedures for blobs.")
    (home-page "https://wiki.call-cc.org/eggref/5/byte-blob")
    (description "Byte array utility procedures for blobs.")
    (license license:lgpl3)))

(define-public
  chicken-regex-case
  (package
    (name "chicken-regex-case")
    (version "1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "regex-case" "1.3"))
        (sha256
          (base32 "1w6hs81ibjl0bc51c3sm9h5knkws5665mbhwi9akazfflfjgia5p"))))
    (propagated-inputs (specifications->packages (list "chicken-regex")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "regex-case"))
    (synopsis
      "Provides an easy to use <code>case</code> construct for regular expression matching")
    (home-page "https://wiki.call-cc.org/eggref/5/regex-case")
    (description
      "Provides an easy to use <code>case</code> construct for regular expression matching")
    (license license:bsd-2)))

(define-public
  chicken-henrietta-cache
  (package
    (name "chicken-henrietta-cache")
    (version "1.6.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "henrietta-cache" "1.6.1"))
        (sha256
          (base32 "0lkjrvldxps7ld4fv2c8p1vaw1nb4lbk85agq529j0ix7nzwfwxm"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-http-client" "chicken-matchable" "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "henrietta-cache"))
    (synopsis
      "Fetch and cache extensions from various sources for Henrietta to consume")
    (home-page "https://wiki.call-cc.org/eggref/5/henrietta-cache")
    (description
      "Fetch and cache extensions from various sources for Henrietta to consume")
    (license license:bsd-2)))

(define-public
  chicken-slib-compat
  (package
    (name "chicken-slib-compat")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "slib-compat" "1.0.0"))
        (sha256
          (base32 "0pk00087wbxwyyrn0qa1261ry2c55mxz9jgh95adl6lvgdvajchy"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "slib-compat"))
    (synopsis "CHICKEN SLIB compatibility library")
    (home-page "https://wiki.call-cc.org/eggref/5/slib-compat")
    (description "CHICKEN SLIB compatibility library")
    (license license:clarified-artistic)))

(define-public
  chicken-hopefully
  (package
    (name "chicken-hopefully")
    (version "0.2.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "hopefully" "0.2.6"))
        (sha256
          (base32 "1f0jas0liwbsd2gr7iirmxx357hykxjy0c2zw9d3j92g2c59xk77"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-18" "chicken-miscmacros")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "hopefully"))
    (synopsis "Simple software transactional memory.")
    (home-page "https://wiki.call-cc.org/eggref/5/hopefully")
    (description "Simple software transactional memory.")
    (license license:bsd-2)))

(define-public
  chicken-sequences
  (package
    (name "chicken-sequences")
    (version "0.6.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sequences" "0.6.1"))
        (sha256
          (base32 "1pg1y49r6mb68vky4vq1izvdk9aq911czc5sk8xyyyz3n1qg7dpl"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-fast-generic" "chicken-srfi-42")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sequences"))
    (synopsis "Generic sequence operators")
    (home-page "https://wiki.call-cc.org/eggref/5/sequences")
    (description "Generic sequence operators")
    (license license:bsd-2)))

(define-public
  chicken-colorize
  (package
    (name "chicken-colorize")
    (version "0.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "colorize" "0.5"))
        (sha256
          (base32 "1js0lrs9vksjk40acm29409k3837987iacim790lbsrhcr9cjb2v"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-13" "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "colorize"))
    (synopsis "Colorize programming code as HTML")
    (home-page "https://wiki.call-cc.org/eggref/5/colorize")
    (description "Colorize programming code as HTML")
    (license license:expat)))

(define-public
  chicken-stb-image-resize
  (package
    (name "chicken-stb-image-resize")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "stb-image-resize" "0.3"))
        (sha256
          (base32 "1lajh5gfwvxzi9x7jwzzfdq462ns5nvpqcdwr44v8j0fqcgjrdcb"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "stb-image-resize"))
    (synopsis "resize raw u8/u16/u32/f32-vector images")
    (home-page "https://wiki.call-cc.org/eggref/5/stb-image-resize")
    (description "resize raw u8/u16/u32/f32-vector images")
    (license license:public-domain)))

(define-public
  chicken-uuid
  (package
    (name "chicken-uuid")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "uuid" "0.1"))
        (sha256
          (base32 "0iv8z83zdpwxrvjrxjnvflqy5hj4x03ivm3f2dmcf82ylhvx0gd8"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "uuid"))
    (synopsis "native chicken uuid library")
    (home-page "https://wiki.call-cc.org/eggref/5/uuid")
    (description "native chicken uuid library")
    (license license:bsd-2)))

(define-public
  chicken-srfi-111
  (package
    (name "chicken-srfi-111")
    (version "0.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-111" "0.5"))
        (sha256
          (base32 "09nng5irszi02ly9gscczi1pjnffxl3s9sv9hn48iij7lqw2b47j"))))
    (propagated-inputs (specifications->packages (list "chicken-box")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-111"))
    (synopsis "SRFI-111: Boxes")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-111")
    (description "SRFI-111: Boxes")
    (license license:expat)))

(define-public
  chicken-graph-cycles
  (package
    (name "chicken-graph-cycles")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "graph-cycles" "2.0"))
        (sha256
          (base32 "084hfzx8m9vy3z3l7ipvbsp0j4rs80yx43zajbhnj0p5h38vkz90"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-iset"
              "chicken-matchable"
              "chicken-yasos"
              "chicken-digraph"
              "chicken-graph-scc")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "graph-cycles"))
    (synopsis "Enumerate all simple cycles in a graph.")
    (home-page "https://wiki.call-cc.org/eggref/5/graph-cycles")
    (description "Enumerate all simple cycles in a graph.")
    (license license:gpl3)))

(define-public
  chicken-records
  (package
    (name "chicken-records")
    (version "1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "records" "1.4"))
        (sha256
          (base32 "00nk7gyk8ikp6z5vlxb0my1a3b4fb9ym8x2dfqlh4gkf0r97rb61"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "records"))
    (synopsis "Procedural record-type interface")
    (home-page "https://wiki.call-cc.org/eggref/5/records")
    (description "Procedural record-type interface")
    (license license:public-domain)))

(define-public
  chicken-srfi-121
  (package
    (name "chicken-srfi-121")
    (version "1.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-121" "1.8"))
        (sha256
          (base32 "1jsf5h8yf53qygj8mygs0hdy89442d7cv19vmmaklylq2g0xq7ii"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-srfi-1" "chicken-srfi-13")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-121"))
    (synopsis "SRFI-121: Generators")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-121")
    (description "SRFI-121: Generators")
    (license license:bsd-2)))

(define-public
  chicken-srfi-174
  (package
    (name "chicken-srfi-174")
    (version "1.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-174" "1.0.2"))
        (sha256
          (base32 "0kl9x7q1wcy7jzjkajmqpf748aqfjysh0ygdvnbvg5bxzdfs4gh9"))))
    (propagated-inputs
      (specifications->packages (list "chicken-r7rs" "chicken-srfi-19")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-174"))
    (synopsis "srfi-174")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-174")
    (description "srfi-174")
    (license license:expat)))

(define-public
  chicken-ssax
  (package
    (name "chicken-ssax")
    (version "5.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ssax" "5.1.0"))
        (sha256
          (base32 "1yfaxi9wxsjj6mlf5m6zh7x1xafgglyzq3fbhx1zlf13zhvadjsj"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-input-parse" "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ssax"))
    (synopsis "Oleg Kiselyov's XML parser")
    (home-page "https://wiki.call-cc.org/eggref/5/ssax")
    (description "Oleg Kiselyov's XML parser")
    (license license:public-domain)))

(define-public
  chicken-srfi-37
  (package
    (name "chicken-srfi-37")
    (version "1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-37" "1.4"))
        (sha256
          (base32 "10n2qyyv7n4r0m20wyzd8y6s6knc67kdh9i8gp8jgz8b05p7xy8g"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-37"))
    (synopsis "A simple and flexible command-line option parsing facility")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-37")
    (description "A simple and flexible command-line option parsing facility")
    (license license:bsd-1)))

(define-public
  chicken-shell
  (package
    (name "chicken-shell")
    (version "0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "shell" "0.4"))
        (sha256
          (base32 "04gn93nsf3g8bxd7jb498qr629y7ql6j548s4c46wfwc5f4gjn5c"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "shell"))
    (synopsis "Convenient shell-command invocation")
    (home-page "https://wiki.call-cc.org/eggref/5/shell")
    (description "Convenient shell-command invocation")
    (license license:public-domain)))

(define-public
  chicken-test
  (package
    (name "chicken-test")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "test" "1.2"))
        (sha256
          (base32 "1l88lb8cnb0i49qvpdj1rnlj06srp5myg0vhs0fv23gzrzjspxh8"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "test"))
    (synopsis "Yet Another Testing Utility")
    (home-page "https://wiki.call-cc.org/eggref/5/test")
    (description "Yet Another Testing Utility")
    (license license:bsd-2)))

(define-public
  chicken-srfi-141
  (package
    (name "chicken-srfi-141")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-141" "1.0.0"))
        (sha256
          (base32 "1d4glc5zw7aidv2c294acvd18vjvmrrffd2dk0gchpaab93l24mg"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-141"))
    (synopsis "SRFI 141: Integer division")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-141")
    (description "SRFI 141: Integer division")
    (license license:bsd-2)))

(define-public
  chicken-tcp-server
  (package
    (name "chicken-tcp-server")
    (version "1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "tcp-server" "1.5"))
        (sha256
          (base32 "1lm7gd7s57d6vdb0xyd1mk3z213w8fisj7fl3cw1cbhmnqvfzqbf"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-18")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "tcp-server"))
    (synopsis "A simple generic multithreaded tcp-server")
    (home-page "https://wiki.call-cc.org/eggref/5/tcp-server")
    (description "A simple generic multithreaded tcp-server")
    (license license:bsd-2)))

(define-public
  chicken-match-generics
  (package
    (name "chicken-match-generics")
    (version "2.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "match-generics" "2.8"))
        (sha256
          (base32 "1js4kq8hp6n8182mzyrs7q7aa6hf9q5y8q3zp2lkplpp862x2sks"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-brev-separate"
              "chicken-matchable"
              "chicken-quasiwalk"
              "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "match-generics"))
    (synopsis "matchable generics")
    (home-page "https://wiki.call-cc.org/eggref/5/match-generics")
    (description "matchable generics")
    (license license:bsd-1)))

(define-public
  chicken-args
  (package
    (name "chicken-args")
    (version "1.6.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "args" "1.6.2"))
        (sha256
          (base32 "0knkg31d4dq9a8rq9g3ycmj0z6j9l7zp93qa9cnqc8ixd6jsymkm"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-13" "chicken-srfi-37")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "args"))
    (synopsis "Command-line argument handling, on top of SRFI 37")
    (home-page "https://wiki.call-cc.org/eggref/5/args")
    (description "Command-line argument handling, on top of SRFI 37")
    (license license:bsd-2)))

(define-public
  chicken-csm
  (package
    (name "chicken-csm")
    (version "0.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "csm" "0.5"))
        (sha256
          (base32 "1bvawrbslsfzxlhal5abyss0nj0jddqbs5ran58nygfc1myn3vfs"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14"
              "chicken-miscmacros")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "csm"))
    (synopsis "a build system")
    (home-page "https://wiki.call-cc.org/eggref/5/csm")
    (description "a build system")
    (license license:bsd-2)))

(define-public
  chicken-topham
  (package
    (name "chicken-topham")
    (version "0.1.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "topham" "0.1.7"))
        (sha256
          (base32 "18p3gjbzi95djyn1rm230ag5g4n4q70pqi670b215icjx91za63i"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-http-client"
              "chicken-intarweb"
              "chicken-medea"
              "chicken-openssl"
              "chicken-optimism"
              "chicken-simple-exceptions"
              "chicken-srfi-1")))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-module-declarations")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "topham"))
    (synopsis "Bindings for the sr.ht REST API")
    (home-page "https://wiki.call-cc.org/eggref/5/topham")
    (description "Bindings for the sr.ht REST API")
    (license license:bsd-2)))

(define-public
  chicken-elliptic-curves
  (package
    (name "chicken-elliptic-curves")
    (version "1.0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "elliptic-curves" "1.0.4"))
        (sha256
          (base32 "05jr977kx11dbs1lfxpkghi38hn37s9z526kg523ca5r1vamqzgh"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-99"
              "chicken-matchable"
              "chicken-modular-arithmetic")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "elliptic-curves"))
    (synopsis
      "Arithmetic and Cryptography on Elliptic Curve Groups over Finite Fields")
    (home-page "https://wiki.call-cc.org/eggref/5/elliptic-curves")
    (description
      "Arithmetic and Cryptography on Elliptic Curve Groups over Finite Fields")
    (license license:bsd-2)))

(define-public
  chicken-checks
  (package
    (name "chicken-checks")
    (version "1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "checks" "1.4"))
        (sha256
          (base32 "16m7s2iab5kvbkgkgyhnaclychx4pf8ar11ghdsflvnhm15yl9vq"))))
    (propagated-inputs
      (specifications->packages (list "chicken-simple-exceptions")))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "checks"))
    (synopsis
      "easy to use procondition and postcondition checks of procedures")
    (home-page "https://wiki.call-cc.org/eggref/5/checks")
    (description
      "easy to use procondition and postcondition checks of procedures")
    (license license:bsd-2)))

(define-public
  chicken-sxml-modifications
  (package
    (name "chicken-sxml-modifications")
    (version "0.3.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sxml-modifications" "0.3.1"))
        (sha256
          (base32 "0g9j8v0fqj6066rxn6fs8qg13bc4hi1bygf9bxx49hfwhh06178v"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-sxpath")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sxml-modifications"))
    (synopsis
      "The sxml-modification bits of sxml-tools from the SSAX project at Sourceforge")
    (home-page "https://wiki.call-cc.org/eggref/5/sxml-modifications")
    (description
      "The sxml-modification bits of sxml-tools from the SSAX project at Sourceforge")
    (license license:public-domain)))

(define-public
  chicken-toml
  (package
    (name "chicken-toml")
    (version "0.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "toml" "0.8"))
        (sha256
          (base32 "0235ihy5y34m5nw1n75y84hs9icjls77w99c000ysm6ahlhqmq0x"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-r7rs" "chicken-rfc3339" "chicken-coops")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "toml"))
    (synopsis "A Chicken binding to read TOML configuration files")
    (home-page "https://wiki.call-cc.org/eggref/5/toml")
    (description "A Chicken binding to read TOML configuration files")
    (license license:expat)))

(define-public
  chicken-comparse
  (package
    (name "chicken-comparse")
    (version "3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "comparse" "3"))
        (sha256
          (base32 "1marysqqvriycky83s6zh1nwiryrdwwi69l1jl0n090lg817mnzn"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-lazy-seq"
              "chicken-trie"
              "chicken-matchable"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14"
              "chicken-srfi-69")))
    (native-inputs
      (specifications->packages
        (list "chicken-srfi-14" "chicken-test" "chicken-lazy-seq")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "comparse"))
    (synopsis "Schemely parser combinators")
    (home-page "https://wiki.call-cc.org/eggref/5/comparse")
    (description "Schemely parser combinators")
    (license license:bsd-2)))

(define-public
  chicken-pwdb
  (package
    (name "chicken-pwdb")
    (version "1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pwdb" "1.4"))
        (sha256
          (base32 "0pj5s6xb34026mg5qajrsanvn4f05qh4zdj69900md1rm4d033na"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-stty"
              "chicken-tweetnacl"
              "chicken-args"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-69"
              "chicken-matchable")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pwdb"))
    (synopsis "A command-line-based password manager")
    (home-page "https://wiki.call-cc.org/eggref/5/pwdb")
    (description "A command-line-based password manager")
    (license license:bsd-2)))

(define-public
  chicken-gtk-server
  (package
    (name "chicken-gtk-server")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "gtk-server" "0.1"))
        (sha256
          (base32 "1c5gwypmhs2r6lcd30vycabqcccma5vgagrdxcfskfpzychv7lnk"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "gtk-server"))
    (synopsis "GTK-server binding")
    (home-page "https://wiki.call-cc.org/eggref/5/gtk-server")
    (description "GTK-server binding")
    (license license:gpl3)))

(define-public
  chicken-svnwiki-sxml
  (package
    (name "chicken-svnwiki-sxml")
    (version "0.2.14")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "svnwiki-sxml" "0.2.14"))
        (sha256
          (base32 "12pb7liy0g9kkhc5gci9q7569qy92m5cgkp9x09mpzxna4n0b18z"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable"
              "chicken-html-parser"
              "chicken-sxml-transforms"
              "chicken-srfi-13"
              "chicken-srfi-1"
              "chicken-regex")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "svnwiki-sxml"))
    (synopsis "Parse svnwiki to sxml")
    (home-page "https://wiki.call-cc.org/eggref/5/svnwiki-sxml")
    (description "Parse svnwiki to sxml")
    (license license:bsd-2)))

(define-public
  chicken-plot
  (package
    (name "chicken-plot")
    (version "2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "plot" "2.1"))
        (sha256
          (base32 "12f0jrj0xhaj6yggf8d89iqznc30j4bhivl25p5b4vrdkd4mac2v"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-datatype"
              "chicken-matchable")))
    (native-inputs (specifications->packages (list "chicken-compile-file")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "plot"))
    (synopsis
      "An interface to GNU libplot, a library for device-independent two-dimensional vector graphics.")
    (home-page "https://wiki.call-cc.org/eggref/5/plot")
    (description
      "An interface to GNU libplot, a library for device-independent two-dimensional vector graphics.")
    (license license:gpl3)))

(define-public
  chicken-apropos
  (package
    (name "chicken-apropos")
    (version "3.10.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "apropos" "3.10.1"))
        (sha256
          (base32 "1aciq2kbqnczhr1k8rcc7g39slb12ndwvnzs1y2ynk33wcvllnna"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-utf8"
              "chicken-string-utils"
              "chicken-symbol-utils"
              "chicken-check-errors")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "apropos"))
    (synopsis "CHICKEN apropos")
    (home-page "https://wiki.call-cc.org/eggref/5/apropos")
    (description "CHICKEN apropos")
    (license license:bsd-2)))

(define-public
  chicken-siphash
  (package
    (name "chicken-siphash")
    (version "0.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "siphash" "0.1.0"))
        (sha256
          (base32 "0g2is573xvli6cs6n8cppr9d5aq0dksa51n5d4cj983phnpylai5"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "siphash"))
    (synopsis "The SipHash family of hash functions")
    (home-page "https://wiki.call-cc.org/eggref/5/siphash")
    (description "The SipHash family of hash functions")
    (license license:bsd-2)))

(define-public
  chicken-r7rs-tools
  (package
    (name "chicken-r7rs-tools")
    (version "0.1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "r7rs-tools" "0.1.1"))
        (sha256
          (base32 "09l2h810av8l2ql0jv08jghdk3wvswddx6qxsxibv2frz1mplqi0"))))
    (propagated-inputs
      (specifications->packages (list "chicken-r7rs" "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "r7rs-tools"))
    (synopsis "\"Pure\" r7rs compiler and interpreter")
    (home-page "https://wiki.call-cc.org/eggref/5/r7rs-tools")
    (description "\"Pure\" r7rs compiler and interpreter")
    (license license:public-domain)))

(define-public
  chicken-message-digest
  (package
    (name "chicken-message-digest")
    (version "4.3.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "message-digest" "4.3.0"))
        (sha256
          (base32 "0fv3w34rqs2v4rh2haa0r9kfk1s2fzxrvsn33jsnzxxkdhm3zz4m"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-message-digest-primitive"
              "chicken-message-digest-type"
              "chicken-message-digest-utils")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "message-digest"))
    (synopsis "Message Digest (omnibus)")
    (home-page "https://wiki.call-cc.org/eggref/5/message-digest")
    (description "Message Digest (omnibus)")
    (license license:bsd-2)))

(define-public
  chicken-srfi-132
  (package
    (name "chicken-srfi-132")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-132" "1.0.0"))
        (sha256
          (base32 "1dp4m60zj8y8x4a6624xd1nk5kbdfyfb9alzp71yrna78ddmvikr"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-133")))
    (native-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-133" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-132"))
    (synopsis "SRFI-132: Sort Libraries")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-132")
    (description "SRFI-132: Sort Libraries")
    (license license:bsd-2)))

(define-public
  chicken-salmonella-feeds
  (package
    (name "chicken-salmonella-feeds")
    (version "0.1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "salmonella-feeds" "0.1.1"))
        (sha256
          (base32 "00p5j9sz862djl4xpj64cs2glxc6z8v3ifrsw1lzgxpv4flk9w03"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-atom"
              "chicken-rfc3339"
              "chicken-salmonella"
              "chicken-salmonella-diff"
              "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "salmonella-feeds"))
    (synopsis "A tool to generate atom feeds out of salmonella log files")
    (home-page "https://wiki.call-cc.org/eggref/5/salmonella-feeds")
    (description "A tool to generate atom feeds out of salmonella log files")
    (license license:bsd-2)))

(define-public
  chicken-noise
  (package
    (name "chicken-noise")
    (version "0.2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "noise" "0.2.0"))
        (sha256
          (base32 "10m0mfr02qx439mdniljsr98wgz26vz7dxpzw6wrv7rrkhsmsy6c"))))
    (propagated-inputs (specifications->packages (list "chicken-glls")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "noise"))
    (synopsis "Noise generation functions on the GPU")
    (home-page "https://wiki.call-cc.org/eggref/5/noise")
    (description "Noise generation functions on the GPU")
    (license license:bsd-2)))

(define-public
  chicken-awful-ssl
  (package
    (name "chicken-awful-ssl")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "awful-ssl" "0.3"))
        (sha256
          (base32 "1grfh0jlxmnhs4ic4qpiq2xaqwprmr52xwkl9r8mnhcw5d2ygwfc"))))
    (propagated-inputs
      (specifications->packages (list "chicken-awful" "chicken-openssl")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "awful-ssl"))
    (synopsis "SSL support for awful")
    (home-page "https://wiki.call-cc.org/eggref/5/awful-ssl")
    (description "SSL support for awful")
    (license license:bsd-2)))

(define-public
  chicken-locale
  (package
    (name "chicken-locale")
    (version "0.9.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "locale" "0.9.2"))
        (sha256
          (base32 "1mqdr1bw5w6nnrg5dxzc4m5qnbrvvkk9v8nm3a6y0qmpscaim9z5"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-utf8" "chicken-check-errors")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "locale"))
    (synopsis "Provides locale operations")
    (home-page "https://wiki.call-cc.org/eggref/5/locale")
    (description "Provides locale operations")
    (license license:bsd-2)))

(define-public
  chicken-srfi-232
  (package
    (name "chicken-srfi-232")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-232" "0.1"))
        (sha256
          (base32 "07639jfqa4y4c6prh3w364mmlyvi0z3pqcr3ampaabsmz527rxpg"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-232"))
    (synopsis "SRFI 232: Flexible curried procedures")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-232")
    (description "SRFI 232: Flexible curried procedures")
    (license license:expat)))

(define-public
  chicken-bitstring
  (package
    (name "chicken-bitstring")
    (version "1.37")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "bitstring" "1.37"))
        (sha256
          (base32 "102w2fbh3slksh55sb718wg2mimjgzb0xrchdl711w8lrxbrfjf8"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "bitstring"))
    (synopsis "Binary pattern matching")
    (home-page "https://wiki.call-cc.org/eggref/5/bitstring")
    (description "Binary pattern matching")
    (license license:bsd-2)))

(define-public
  chicken-glfw3
  (package
    (name "chicken-glfw3")
    (version "0.7.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "glfw3" "0.7.1"))
        (sha256
          (base32 "0vfjd3j908cclxnkkrj8g8ql8vhbfrs6ll4ryar6132yi1fs91ba"))))
    (propagated-inputs (specifications->packages (list "chicken-bind")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "glfw3"))
    (synopsis
      "Bindings to the GLFW3 OpenGL window and event management library")
    (home-page "https://wiki.call-cc.org/eggref/5/glfw3")
    (description
      "Bindings to the GLFW3 OpenGL window and event management library")
    (license license:bsd-2)))

(define-public
  chicken-spiffy-cookies
  (package
    (name "chicken-spiffy-cookies")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "spiffy-cookies" "1.2"))
        (sha256
          (base32 "1jf0g1i8sz09gwmvrvhp9kq0dr0cv2g4j1jhqf5z0177506z9x0j"))))
    (propagated-inputs
      (specifications->packages (list "chicken-spiffy" "chicken-intarweb")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "spiffy-cookies"))
    (synopsis "Procedures for managing cookies")
    (home-page "https://wiki.call-cc.org/eggref/5/spiffy-cookies")
    (description "Procedures for managing cookies")
    (license license:bsd-2)))

(define-public
  chicken-epoxy
  (package
    (name "chicken-epoxy")
    (version "0.2.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "epoxy" "0.2.2"))
        (sha256
          (base32 "036h1jm37chkcxzs95ypvsz3363qkszv1pr1sby3z4izck5039rl"))))
    (propagated-inputs (specifications->packages (list "chicken-bind")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "epoxy"))
    (synopsis "Bindings to OpenGL and OpenGL ES through the Epoxy library")
    (home-page "https://wiki.call-cc.org/eggref/5/epoxy")
    (description "Bindings to OpenGL and OpenGL ES through the Epoxy library")
    (license license:bsd-2)))

(define-public
  chicken-comic-snarfer
  (package
    (name "chicken-comic-snarfer")
    (version "1.23")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "comic-snarfer" "1.23"))
        (sha256
          (base32 "1pa566vfgwxl5nr56brn7rwkj63m2mgpqw1ma2228g4wyya7c8qn"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-anaphora"
              "chicken-brev-separate"
              "chicken-define-options"
              "chicken-http-client"
              "chicken-html-parser"
              "chicken-mathh"
              "chicken-srfi-42"
              "chicken-sxpath"
              "chicken-strse"
              "chicken-uri-generic")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "comic-snarfer"))
    (synopsis
      "Download files (such as web comic images) by recursing on XPath")
    (home-page "https://wiki.call-cc.org/eggref/5/comic-snarfer")
    (description
      "Download files (such as web comic images) by recursing on XPath")
    (license license:gpl3)))

(define-public
  chicken-rlimit
  (package
    (name "chicken-rlimit")
    (version "1.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "rlimit" "1.0.2"))
        (sha256
          (base32 "1yxdn9y11i8s9mj5dknlpz588d48bklylxcq73v0s48a5m7vfpwp"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "rlimit"))
    (synopsis "Setting resource limits")
    (home-page "https://wiki.call-cc.org/eggref/5/rlimit")
    (description "Setting resource limits")
    (license license:bsd-2)))

(define-public
  chicken-srfi-135
  (package
    (name "chicken-srfi-135")
    (version "1.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-135" "1.0.2"))
        (sha256
          (base32 "0iwhh3m99d2wl2wzcl6xzynyx2c5g62ck0svrlah5x7vh7vh8f9p"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-r7rs"
              "chicken-utf8"
              "chicken-srfi-141"
              "chicken-typed-records")))
    (native-inputs
      (specifications->packages
        (list "chicken-r7rs" "chicken-srfi-158" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-135"))
    (synopsis "SRFI 135: Immutable Texts")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-135")
    (description "SRFI 135: Immutable Texts")
    (license license:expat)))

(define-public
  chicken-botan
  (package
    (name "chicken-botan")
    (version "2.13.20191214-0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "botan" "2.13.20191214-0"))
        (sha256
          (base32 "1j2h6hhvwdr7d7kgm5b0nc5nmx23a35av7rvwcajlxxv9iafmdh2"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-13" "chicken-srfi-14")))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "botan"))
    (synopsis "Bindings to the Botan cryptographic library")
    (home-page "https://wiki.call-cc.org/eggref/5/botan")
    (description "Bindings to the Botan cryptographic library")
    (license license:bsd-2)))

(define-public
  chicken-redis
  (package
    (name "chicken-redis")
    (version "0.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "redis" "0.6"))
        (sha256
          (base32 "1p3q9216y0ddnghcy83h3xm0vi2qg17kv1v1xff2sfz4mzliy6qf"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-r7rs"
              "chicken-srfi-34"
              "chicken-srfi-35"
              "chicken-srfi-69"
              "chicken-srfi-99"
              "chicken-srfi-113"
              "chicken-srfi-128"
              "chicken-srfi-133"
              "chicken-srfi-152"
              "chicken-srfi-158")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "redis"))
    (synopsis "A Redis client library for Chicken Scheme")
    (home-page "https://wiki.call-cc.org/eggref/5/redis")
    (description "A Redis client library for Chicken Scheme")
    (license license:bsd-2)))

(define-public
  chicken-rbf
  (package
    (name "chicken-rbf")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "rbf" "1.1"))
        (sha256
          (base32 "1r41kpsw4syarj9fnajazhs4q1z8hxvh0zd4wf8q5yjv2jgc6pls"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "rbf"))
    (synopsis
      "Bindings for the Radial Basis Function interpolation routines by John Burkardt.")
    (home-page "https://wiki.call-cc.org/eggref/5/rbf")
    (description
      "Bindings for the Radial Basis Function interpolation routines by John Burkardt.")
    (license license:gpl3)))

(define-public
  chicken-arcadedb
  (package
    (name "chicken-arcadedb")
    (version "0.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "arcadedb" "0.8"))
        (sha256
          (base32 "1lhagnaxwvzax82k7qg8v5w7wj9mqi4y686j52fqiqnry99h73k0"))))
    (propagated-inputs (specifications->packages (list "chicken-medea")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "arcadedb"))
    (synopsis "An ArcadeDB database driver for CHICKEN Scheme.")
    (home-page "https://wiki.call-cc.org/eggref/5/arcadedb")
    (description "An ArcadeDB database driver for CHICKEN Scheme.")
    (license license:zlib)))

(define-public
  chicken-module-declarations
  (package
    (name "chicken-module-declarations")
    (version "0.3.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "module-declarations" "0.3.1"))
        (sha256
          (base32 "079zs0cc7bmc1macvsh79q1x4rbjqw25hcvlcis8xxg3952vlqfg"))))
    (propagated-inputs
      (specifications->packages (list "chicken-matchable" "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "module-declarations"))
    (synopsis "Module declarations")
    (home-page "https://wiki.call-cc.org/eggref/5/module-declarations")
    (description "Module declarations")
    (license license:bsd-2)))

(define-public
  chicken-foreigners
  (package
    (name "chicken-foreigners")
    (version "1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "foreigners" "1.5"))
        (sha256
          (base32 "1jl1cdd34qwsd9x7vqw2aqqgd2m2mii898ilg2vkb39nqfvg35b5"))))
    (propagated-inputs (specifications->packages (list "chicken-matchable")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "foreigners"))
    (synopsis "Foreign helper macros")
    (home-page "https://wiki.call-cc.org/eggref/5/foreigners")
    (description "Foreign helper macros")
    (license license:bsd-2)))

(define-public
  chicken-henrietta
  (package
    (name "chicken-henrietta")
    (version "1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "henrietta" "1.5"))
        (sha256
          (base32 "17ibkk6pq81hw2ydwd00jgg0zzbrcfzcbni60x95479c1xnzdb64"))))
    (propagated-inputs
      (specifications->packages (list "chicken-regex" "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "henrietta"))
    (synopsis "Serve extensions over HTTP")
    (home-page "https://wiki.call-cc.org/eggref/5/henrietta")
    (description "Serve extensions over HTTP")
    (license license:bsd-2)))

(define-public
  chicken-scheme-indent
  (package
    (name "chicken-scheme-indent")
    (version "0.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "scheme-indent" "0.6"))
        (sha256
          (base32 "1jjgi0wwfk3bx8ayc09y09pxg9awdx5hm397gqhg6gvjbn3sm3in"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "scheme-indent"))
    (synopsis "A Scheme code indenter")
    (home-page "https://wiki.call-cc.org/eggref/5/scheme-indent")
    (description "A Scheme code indenter")
    (license license:bsd-2)))

(define-public
  chicken-simple-tests
  (package
    (name "chicken-simple-tests")
    (version "3.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "simple-tests" "3.1"))
        (sha256
          (base32 "168n51hkmzxx5rl9qf8l739nbr1xcf7rrsngqj9sqygra4kgya0m"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "simple-tests"))
    (synopsis "Some simple test routines")
    (home-page "https://wiki.call-cc.org/eggref/5/simple-tests")
    (description "Some simple test routines")
    (license license:bsd-2)))

(define-public
  chicken-srfi-105
  (package
    (name "chicken-srfi-105")
    (version "0.1.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-105" "0.1.7"))
        (sha256
          (base32 "0wf57aiam3ym5qjhsz4sckdqsfp8lfqasb8jbgjblx77xzb3b3ad"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-13" "chicken-srfi-1" "chicken-srfi-123")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-105"))
    (synopsis "SRFI-105 - curly infix expressions")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-105")
    (description "SRFI-105 - curly infix expressions")
    (license license:expat)))

(define-public
  chicken-dwim-sort
  (package
    (name "chicken-dwim-sort")
    (version "1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "dwim-sort" "1.4"))
        (sha256
          (base32 "07xvngm9k3rlnhbgr0675xha3szyg4wn4y7x811fxycps9kq9lwn"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-brev-separate"
              "chicken-sequences"
              "chicken-srfi-1"
              "chicken-match-generics")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "dwim-sort"))
    (synopsis "dwimmy sort")
    (home-page "https://wiki.call-cc.org/eggref/5/dwim-sort")
    (description "dwimmy sort")
    (license license:bsd-1)))

(define-public
  chicken-trie
  (package
    (name "chicken-trie")
    (version "2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "trie" "2"))
        (sha256
          (base32 "1k7hq31px236s25wqfqh22wb4kpm97hl2kcvj4amsyvlxc1y4w96"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "trie"))
    (synopsis "A trie (prefix tree) implementation")
    (home-page "https://wiki.call-cc.org/eggref/5/trie")
    (description "A trie (prefix tree) implementation")
    (license license:bsd-2)))

(define-public
  chicken-amb
  (package
    (name "chicken-amb")
    (version "3.0.10")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "amb" "3.0.10"))
        (sha256
          (base32 "0n2wbxb23fai27hgk86jf9lnnrg0dvh989ysjkscdf9my96j448s"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "amb"))
    (synopsis "The non-deterministic backtracking ambivalence operator")
    (home-page "https://wiki.call-cc.org/eggref/5/amb")
    (description "The non-deterministic backtracking ambivalence operator")
    (license license:bsd-2)))

(define-public
  chicken-minissh
  (package
    (name "chicken-minissh")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "minissh" "1.0.0"))
        (sha256
          (base32 "1s1yy4wzwcg3g32dhz8al6h56mjnl34fzccl41513v0shlgmkk6q"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-tweetnacl"
              "chicken-matchable"
              "chicken-gochan"
              "chicken-base64"
              "chicken-queues"
              "chicken-srfi-13"
              "chicken-srfi-18"
              "chicken-srfi-69"
              "chicken-message-digest-utils"
              "chicken-sha2")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-matchable")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "minissh"))
    (synopsis "An SSH-2 server and client implementation")
    (home-page "https://wiki.call-cc.org/eggref/5/minissh")
    (description "An SSH-2 server and client implementation")
    (license license:bsd-2)))

(define-public
  chicken-ws-client
  (package
    (name "chicken-ws-client")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ws-client" "1.0.0"))
        (sha256
          (base32 "1w6cpf52ipw0irx7xhh9gnz13hp6h9babi7ymiwwn9k798mhc063"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-foreigners"
              "chicken-string-utils"
              "chicken-base64"
              "chicken-simple-sha1"
              "chicken-uri-common"
              "chicken-intarweb"
              "chicken-openssl")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ws-client"))
    (synopsis "websocket client library")
    (home-page "https://wiki.call-cc.org/eggref/5/ws-client")
    (description "websocket client library")
    (license license:bsd-2)))

(define-public
  chicken-qt-light
  (package
    (name "chicken-qt-light")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "qt-light" "1.0"))
        (sha256
          (base32 "1m84b11ak23z6vpi3hqs5b4v5c1n1yq5p4l31m8v8ajqayi6n0rm"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-bind"
              "chicken-protobj"
              "chicken-matchable"
              "chicken-miscmacros"
              "chicken-shell")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "qt-light"))
    (synopsis "A lightweight Qt 5 interface")
    (home-page "https://wiki.call-cc.org/eggref/5/qt-light")
    (description "A lightweight Qt 5 interface")
    (license license:bsd-2)))

(define-public
  chicken-filepath
  (package
    (name "chicken-filepath")
    (version "1.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "filepath" "1.6"))
        (sha256
          (base32 "14mrpq6g4hirj2qsirnxpj4b9b48m8fk80r23wm95wrcir9cjqmr"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14")))
    (native-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "filepath"))
    (synopsis "Cross-platform file path manipulation.")
    (home-page "https://wiki.call-cc.org/eggref/5/filepath")
    (description "Cross-platform file path manipulation.")
    (license license:bsd-2)))

(define-public
  chicken-directory-utils
  (package
    (name "chicken-directory-utils")
    (version "2.3.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "directory-utils" "2.3.0"))
        (sha256
          (base32 "0xiga98dddi5vg5h1m2vws5prk4ri96rx6l359lji62aq51h526i"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-utf8"
              "chicken-miscmacros"
              "chicken-moremacros"
              "chicken-stack"
              "chicken-list-utils"
              "chicken-check-errors")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "directory-utils"))
    (synopsis "directory-utils")
    (home-page "https://wiki.call-cc.org/eggref/5/directory-utils")
    (description "directory-utils")
    (license license:bsd-2)))

(define-public
  chicken-premodules
  (package
    (name "chicken-premodules")
    (version "0.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "premodules" "0.7"))
        (sha256
          (base32 "1ajip86bq872k8k7jra7nsm76vp3zzwwcy5n6467pvr3z16nsw2h"))))
    (propagated-inputs
      (specifications->packages (list "chicken-simple-tests")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "premodules"))
    (synopsis "Converting a premodule into module, test and doc files")
    (home-page "https://wiki.call-cc.org/eggref/5/premodules")
    (description "Converting a premodule into module, test and doc files")
    (license license:bsd-2)))

(define-public
  chicken-nanomsg
  (package
    (name "chicken-nanomsg")
    (version "1.0.0.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "nanomsg" "1.0.0.6"))
        (sha256
          (base32 "01ma6cxmbc0bmk4598q3ag28pnbqlmcfq11mbs4c87ir82bkvz7h"))))
    (propagated-inputs
      (specifications->packages (list "chicken-foreigners" "chicken-srfi-18")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "nanomsg"))
    (synopsis "unknown")
    (home-page "https://wiki.call-cc.org/eggref/5/nanomsg")
    (description "unknown")
    (license license:expat)))

(define-public
  chicken-sundials
  (package
    (name "chicken-sundials")
    (version "2.17")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sundials" "2.17"))
        (sha256
          (base32 "0v9bxclbm11glbv47pqbwi2gxx9555c04njy1cxigs6wyrvg54yh"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-srfi-69")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-mathh"
              "chicken-srfi-13"
              "chicken-compile-file")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sundials"))
    (synopsis
      "An interface to SUNDIALS (SUite of Nonlinear and DIfferential/ALgebraic equation Solvers).")
    (home-page "https://wiki.call-cc.org/eggref/5/sundials")
    (description
      "An interface to SUNDIALS (SUite of Nonlinear and DIfferential/ALgebraic equation Solvers).")
    (license license:bsd-2)))

(define-public
  chicken-crypt
  (package
    (name "chicken-crypt")
    (version "1.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "crypt" "1.0.1"))
        (sha256
          (base32 "1x7il9qz6m8kicgz57iw2yykfn9x6pa56m33rp5z70z4yfkrxqwz"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-compile-file")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "crypt"))
    (synopsis "Secure password hashing through the Unix crypt() function")
    (home-page "https://wiki.call-cc.org/eggref/5/crypt")
    (description "Secure password hashing through the Unix crypt() function")
    (license license:public-domain)))

(define-public
  chicken-skiplists
  (package
    (name "chicken-skiplists")
    (version "1.0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "skiplists" "1.0.2"))
        (sha256
          (base32 "0fi7x7yxavvjmg7nw0fzzba4sifvpifzxs5d1if93fiwbb0fmwc6"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "skiplists"))
    (synopsis "An implementation of skiplists")
    (home-page "https://wiki.call-cc.org/eggref/5/skiplists")
    (description "An implementation of skiplists")
    (license license:bsd-2)))

(define-public
  chicken-srfi-137
  (package
    (name "chicken-srfi-137")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-137" "0.2"))
        (sha256
          (base32 "10cdlzpr1yid8549d0zfzkmrw9k7qwgy0k5rs744vy65bfmq0k4g"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-137"))
    (synopsis "SRFI-137: Minimal Unique Types")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-137")
    (description "SRFI-137: Minimal Unique Types")
    (license license:expat)))

(define-public
  chicken-stty
  (package
    (name "chicken-stty")
    (version "0.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "stty" "0.6"))
        (sha256
          (base32 "195qkj1ckji115ih9ccfsn52hg8cbbwn19vblcggv3g0xmpncdak"))))
    (propagated-inputs
      (specifications->packages (list "chicken-foreigners" "chicken-srfi-69")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "stty"))
    (synopsis "stty-style interface to termios")
    (home-page "https://wiki.call-cc.org/eggref/5/stty")
    (description "stty-style interface to termios")
    (license license:bsd-2)))

(define-public
  chicken-blas
  (package
    (name "chicken-blas")
    (version "4.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "blas" "4.5"))
        (sha256
          (base32 "1gx22ycqc3jpcmv16644ay9cygh535di4j7znqjqxn2dyq29dmkm"))))
    (propagated-inputs (specifications->packages (list "chicken-bind")))
    (native-inputs
      (specifications->packages
        (list "chicken-test" "chicken-compile-file" "chicken-srfi-13")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "blas"))
    (synopsis "An interface to level 1, 2 and 3 BLAS routines")
    (home-page "https://wiki.call-cc.org/eggref/5/blas")
    (description "An interface to level 1, 2 and 3 BLAS routines")
    (license license:bsd-2)))

(define-public
  chicken-awful-postgresql
  (package
    (name "chicken-awful-postgresql")
    (version "0.7.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "awful-postgresql" "0.7.0"))
        (sha256
          (base32 "084n39rz3m2sjpah3hq03iybdf1z2af64cv5fb8kphqr6cb3m5d8"))))
    (propagated-inputs
      (specifications->packages (list "chicken-awful" "chicken-postgresql")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "awful-postgresql"))
    (synopsis "Postgresql support for awful")
    (home-page "https://wiki.call-cc.org/eggref/5/awful-postgresql")
    (description "Postgresql support for awful")
    (license license:bsd-2)))

(define-public
  chicken-operations
  (package
    (name "chicken-operations")
    (version "0.6")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "operations" "0.6"))
        (sha256
          (base32 "0zqcvbc4f6576y61kmyd9xz99pkj09fnb2mjdb8dfnxn5w3s8i86"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "operations"))
    (synopsis "The T object system")
    (home-page "https://wiki.call-cc.org/eggref/5/operations")
    (description "The T object system")
    (license license:bsd-2)))

(define-public
  chicken-sdl-base
  (package
    (name "chicken-sdl-base")
    (version "0.9.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sdl-base" "0.9.2"))
        (sha256
          (base32 "17kgjy2mmhvnm07kvavp2injvbjsn57kz72b9krkm5p4q3jvlvjf"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sdl-base"))
    (synopsis "Basic SDL support")
    (home-page "https://wiki.call-cc.org/eggref/5/sdl-base")
    (description "Basic SDL support")
    (license license:lgpl2.1)))

(define-public
  chicken-concurrent-native-callbacks
  (package
    (name "chicken-concurrent-native-callbacks")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "concurrent-native-callbacks" "1.0"))
        (sha256
          (base32 "1v333c7wm51bj24s52h5vr2yvznm4hzg9gjqg5sssjnnq08pfwym"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-typed-records"
              "chicken-matchable"
              "chicken-bind"
              "chicken-miscmacros"
              "chicken-srfi-18"
              "chicken-srfi-69")))
    (native-inputs
      (specifications->packages (list "chicken-shell" "chicken-make")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "concurrent-native-callbacks"))
    (synopsis "Invoke callbacks from other native threads")
    (home-page "https://wiki.call-cc.org/eggref/5/concurrent-native-callbacks")
    (description "Invoke callbacks from other native threads")
    (license license:bsd-2)))

(define-public
  chicken-simple-loops
  (package
    (name "chicken-simple-loops")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "simple-loops" "2.0"))
        (sha256
          (base32 "1mlya8mgpsf4irwba2ybv4s6z0y2hr4xfv4ghs8j0nifndzy18zf"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-simple-tests")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "simple-loops"))
    (synopsis "Some simple looping macros")
    (home-page "https://wiki.call-cc.org/eggref/5/simple-loops")
    (description "Some simple looping macros")
    (license license:bsd-2)))

(define-public
  chicken-dbus
  (package
    (name "chicken-dbus")
    (version "0.97")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "dbus" "0.97"))
        (sha256
          (base32 "0a1850gark0xjn8cw1gwxgqjpk17zjmk6wc5g23ikjh9gib8ry1q"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-miscmacros" "chicken-srfi-18" "chicken-foreigners")))
    (native-inputs
      (specifications->packages
        (list "chicken-scsh-process" "chicken-srfi-13" "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "dbus"))
    (synopsis "A binding for libdbus, the IPC mechanism")
    (home-page "https://wiki.call-cc.org/eggref/5/dbus")
    (description "A binding for libdbus, the IPC mechanism")
    (license license:expat)))

(define-public
  chicken-coops
  (package
    (name "chicken-coops")
    (version "1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "coops" "1.3"))
        (sha256
          (base32 "183pp1g5m06ss94ba1rq2rs4hqj92v6qz7ik3kzvl3b2aq77jk3z"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable"
              "chicken-miscmacros"
              "chicken-record-variants"
              "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "coops"))
    (synopsis "A featureful object system")
    (home-page "https://wiki.call-cc.org/eggref/5/coops")
    (description "A featureful object system")
    (license license:bsd-2)))

(define-public
  chicken-monocypher
  (package
    (name "chicken-monocypher")
    (version "4.0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "monocypher" "4.0.1"))
        (sha256
          (base32 "09q33a6b8v306j93kd67wk5gisca7sij0p98i7pd10xnimllc5hh"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "monocypher"))
    (synopsis "Monocypher cryptographic library")
    (home-page "https://wiki.call-cc.org/eggref/5/monocypher")
    (description "Monocypher cryptographic library")
    (license license:bsd-2)))

(define-public
  chicken-z3
  (package
    (name "chicken-z3")
    (version "2.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "z3" "2.0"))
        (sha256
          (base32 "147f2401ngpgg6pg0gf60vkj1gvhgmbjc3l8v5mqkyd47p5zjxgl"))))
    (propagated-inputs (specifications->packages (list "chicken-bind")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "z3"))
    (synopsis "A gzip (RFC1952) compression and decompression library")
    (home-page "https://wiki.call-cc.org/eggref/5/z3")
    (description "A gzip (RFC1952) compression and decompression library")
    (license license:bsd-2)))

(define-public
  chicken-spock
  (package
    (name "chicken-spock")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "spock" "0.2"))
        (sha256
          (base32 "0m17x7nbfp237mkn0l8nrcaqpf8nfkqcg5ws3p3jjdvr0zwaxjj3"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-jsmin" "chicken-matchable" "chicken-make")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "spock"))
    (synopsis
      "A compiler and runtime system for R5RS Scheme on top of JavaScript")
    (home-page "https://wiki.call-cc.org/eggref/5/spock")
    (description
      "A compiler and runtime system for R5RS Scheme on top of JavaScript")
    (license license:bsd-2)))

(define-public
  chicken-linenoise
  (package
    (name "chicken-linenoise")
    (version "1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "linenoise" "1.0"))
        (sha256
          (base32 "0is9j6hq6nmnsrn2g01ssxg8hwndc3y6fx02hsvfdsqqzj8qzjvr"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "linenoise"))
    (synopsis "A minimal, zero-config, BSD licensed, readline replacement.")
    (home-page "https://wiki.call-cc.org/eggref/5/linenoise")
    (description "A minimal, zero-config, BSD licensed, readline replacement.")
    (license license:bsd-2)))

(define-public
  chicken-brev-separate
  (package
    (name "chicken-brev-separate")
    (version "1.95")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "brev-separate" "1.95"))
        (sha256
          (base32 "0ycm95vcf1dj6m3kqii7b2a5kxyd1m6lzksz77ispay14srgw8rd"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable"
              "chicken-miscmacros"
              "chicken-srfi-1"
              "chicken-srfi-69")))
    (native-inputs (specifications->packages (list "chicken-srfi-13")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "brev-separate"))
    (synopsis "Hodge podge of macros and combinators")
    (home-page "https://wiki.call-cc.org/eggref/5/brev-separate")
    (description "Hodge podge of macros and combinators")
    (license license:bsd-1)))

(define-public
  chicken-levenshtein
  (package
    (name "chicken-levenshtein")
    (version "2.4.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "levenshtein" "2.4.1"))
        (sha256
          (base32 "1q09kml6igd010j630m52rg7vayfsab176k3vjcsjn7ccf3i7a31"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-63"
              "chicken-srfi-69"
              "chicken-vector-lib"
              "chicken-utf8"
              "chicken-miscmacros"
              "chicken-record-variants"
              "chicken-check-errors")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "levenshtein"))
    (synopsis "Levenshtein edit distance")
    (home-page "https://wiki.call-cc.org/eggref/5/levenshtein")
    (description "Levenshtein edit distance")
    (license license:bsd-2)))

(define-public
  chicken-salmonella-html-report
  (package
    (name "chicken-salmonella-html-report")
    (version "1.7.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "salmonella-html-report" "1.7.1"))
        (sha256
          (base32 "107n7sgzk91s25ih3k40y649fnv9n37xnf7igkkn5c642hjmfr6d"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages
        (list "chicken-salmonella"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-sxml-transforms")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "salmonella-html-report"))
    (synopsis "A tool to generate HTML ouput out of salmonella log files")
    (home-page "https://wiki.call-cc.org/eggref/5/salmonella-html-report")
    (description "A tool to generate HTML ouput out of salmonella log files")
    (license license:bsd-2)))

(define-public
  chicken-sha1
  (package
    (name "chicken-sha1")
    (version "4.1.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sha1" "4.1.7"))
        (sha256
          (base32 "0p48vv59lr1ydrn529fkpd7ybny9h4hggaav0b7zwyvpkhyd565q"))))
    (propagated-inputs
      (specifications->packages (list "chicken-message-digest-primitive")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-test-utils"
              "chicken-message-digest-type"
              "chicken-message-digest-utils"
              "chicken-message-digest-primitive")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sha1"))
    (synopsis "Computes SHA1 (FIPS-180-1) checksums")
    (home-page "https://wiki.call-cc.org/eggref/5/sha1")
    (description "Computes SHA1 (FIPS-180-1) checksums")
    (license license:public-domain)))

(define-public
  chicken-slib-arraymap
  (package
    (name "chicken-slib-arraymap")
    (version "1.1.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "slib-arraymap" "1.1.4"))
        (sha256
          (base32 "08djsc0j6kacf07a59f58clka94wq4lp8ry3p8203sx3lbx1s8qw"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-63" "chicken-slib-compat")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "slib-arraymap"))
    (synopsis "The SLIB applicative routines for the arrays library")
    (home-page "https://wiki.call-cc.org/eggref/5/slib-arraymap")
    (description "The SLIB applicative routines for the arrays library")
    (license license:bsd-2)))

(define-public
  chicken-forcible
  (package
    (name "chicken-forcible")
    (version "0.3.10")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "forcible" "0.3.10"))
        (sha256
          (base32 "0vsgfk5x247grwmn6vky0d43s76qiys8sd41bvk4gqv6yww4y1a7"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-18" "chicken-pigeon-hole" "chicken-simple-timer")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "forcible"))
    (synopsis
      "Thread- and exception aware, lazy-looking synchronization with timeouts - extending srfi-45")
    (home-page "https://wiki.call-cc.org/eggref/5/forcible")
    (description
      "Thread- and exception aware, lazy-looking synchronization with timeouts - extending srfi-45")
    (license license:bsd-2)))

(define-public
  chicken-graph-separators
  (package
    (name "chicken-graph-separators")
    (version "2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "graph-separators" "2.1"))
        (sha256
          (base32 "18w16lwxq4285ms4lm6j55wm14ggprsh3al106rx3480qz5wkvh0"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-yasos" "chicken-digraph")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-srfi-1")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "graph-separators"))
    (synopsis "Determine the separation vertices of a graph.")
    (home-page "https://wiki.call-cc.org/eggref/5/graph-separators")
    (description "Determine the separation vertices of a graph.")
    (license license:gpl3)))

(define-public
  chicken-mistie
  (package
    (name "chicken-mistie")
    (version "1.9")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "mistie" "1.9"))
        (sha256
          (base32 "0qfz8zc41wm2afwwbg1c8gmpzlph07nsj4r86lx01af9s03nvpfa"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "mistie"))
    (synopsis "A programmable filter")
    (home-page "https://wiki.call-cc.org/eggref/5/mistie")
    (description "A programmable filter")
    (license license:bsd-2)))

(define-public
  chicken-dollar
  (package
    (name "chicken-dollar")
    (version "3.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "dollar" "3.0.0"))
        (sha256
          (base32 "1nlsjri7fbf8jcxghvd47imqhc24rdfkik985md8h5d1h2j2mdqn"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-shell")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "dollar"))
    (synopsis "FFI convenience macro")
    (home-page "https://wiki.call-cc.org/eggref/5/dollar")
    (description "FFI convenience macro")
    (license license:bsd-2)))

(define-public
  chicken-tcp6
  (package
    (name "chicken-tcp6")
    (version "0.2.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "tcp6" "0.2.1"))
        (sha256
          (base32 "03amc9wfpk2r3aybm8llh0l89kiqi5bri132987jj59d4qvmv1rq"))))
    (propagated-inputs
      (specifications->packages (list "chicken-socket" "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "tcp6"))
    (synopsis "Interface to TCP over IPv4 and IPv6")
    (home-page "https://wiki.call-cc.org/eggref/5/tcp6")
    (description "Interface to TCP over IPv4 and IPv6")
    (license license:bsd-2)))

(define-public
  chicken-ldif-sexpr
  (package
    (name "chicken-ldif-sexpr")
    (version "0.3.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ldif-sexpr" "0.3.2"))
        (sha256
          (base32 "123d95vxkn11zdqfy73l2n26f6i8zcj97zhcc6yhia6f1x4qb61n"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-uri-common"
              "chicken-base64"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14"
              "chicken-matchable")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ldif-sexpr"))
    (synopsis
      "Convert (parse&write) LDIF, rfc4514 and LDAP filters (rfc2254) into S-expressions.")
    (home-page "https://wiki.call-cc.org/eggref/5/ldif-sexpr")
    (description
      "Convert (parse&write) LDIF, rfc4514 and LDAP filters (rfc2254) into S-expressions.")
    (license license:bsd-2)))

(define-public
  chicken-make-tests
  (package
    (name "chicken-make-tests")
    (version "1.12")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "make-tests" "1.12"))
        (sha256
          (base32 "174nbjy27iiz29g906p9rsg036mgwjnl7ll0qc2clqzq1svkgqc7"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-brev-separate" "chicken-srfi-1" "chicken-uri-common")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "make-tests"))
    (synopsis "Create unit tests from a file of expressions")
    (home-page "https://wiki.call-cc.org/eggref/5/make-tests")
    (description "Create unit tests from a file of expressions")
    (license license:public-domain)))

(define-public
  chicken-ioctl
  (package
    (name "chicken-ioctl")
    (version "0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ioctl" "0.4"))
        (sha256
          (base32 "0qs2daw16zw4jpqnb0q2nnb0qanki7nl0k437b9m4a7qslhdqw6r"))))
    (propagated-inputs (specifications->packages (list "chicken-foreigners")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ioctl"))
    (synopsis "ioctl system call interface")
    (home-page "https://wiki.call-cc.org/eggref/5/ioctl")
    (description "ioctl system call interface")
    (license license:bsd-2)))

(define-public
  chicken-internet-message
  (package
    (name "chicken-internet-message")
    (version "7.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "internet-message" "7.1"))
        (sha256
          (base32 "0h2avknylg7kyhi7z7vpvs9qzw7kh5k7yrwqv6lgqdsdzbjygni9"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-yasos" "chicken-utf8" "chicken-abnf")))
    (native-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-14"
              "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "internet-message"))
    (synopsis "Parser combinators for Internet Message Format (RFC 5322).")
    (home-page "https://wiki.call-cc.org/eggref/5/internet-message")
    (description "Parser combinators for Internet Message Format (RFC 5322).")
    (license license:gpl3)))

(define-public
  chicken-gmi
  (package
    (name "chicken-gmi")
    (version "0.0.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "gmi" "0.0.7"))
        (sha256
          (base32 "08c89r4cz4nh66crkfsxwdj1lxjmbxr2lls92ncnqlxd0mnmplq0"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "gmi"))
    (synopsis "Gemtext reader and writer")
    (home-page "https://wiki.call-cc.org/eggref/5/gmi")
    (description "Gemtext reader and writer")
    (license license:unlicense)))

(define-public
  chicken-gemini-client
  (package
    (name "chicken-gemini-client")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "gemini-client" "0.1"))
        (sha256
          (base32 "0l4rs91jsczjnna0yf8d1bsi9k1789jhjqcnhci2i63ls93p2iww"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-openssl" "chicken-r7rs" "chicken-uri-generic")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "gemini-client"))
    (synopsis "Client library for the gemini:// protocol")
    (home-page "https://wiki.call-cc.org/eggref/5/gemini-client")
    (description "Client library for the gemini:// protocol")
    (license license:isc)))

(define-public
  chicken-big-chicken
  (package
    (name "chicken-big-chicken")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "big-chicken" "1.1"))
        (sha256
          (base32 "1f36y05mz4hwp1jkkl9wawn72rql13cz7q6394zfpf008dizq69z"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "big-chicken"))
    (synopsis "Wrapper module for all core modules")
    (home-page "https://wiki.call-cc.org/eggref/5/big-chicken")
    (description "Wrapper module for all core modules")
    (license license:bsd-2)))

(define-public
  chicken-posix-regex
  (package
    (name "chicken-posix-regex")
    (version "0.1.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "posix-regex" "0.1.0"))
        (sha256
          (base32 "1zswh1d96q24271mkzx7fc8802z9h9bkcb8nmakpf8prl1d2yjvg"))))
    (propagated-inputs (specifications->packages (list "chicken-r7rs")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "posix-regex"))
    (synopsis "A thin wrapper around POSIX regular expression matching")
    (home-page "https://wiki.call-cc.org/eggref/5/posix-regex")
    (description "A thin wrapper around POSIX regular expression matching")
    (license license:gpl3)))

(define-public
  chicken-freetype
  (package
    (name "chicken-freetype")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "freetype" "0.3"))
        (sha256
          (base32 "0h072r758yjqz9msq49plkrgqm9xxlmx8fd15gvv9pkpiwp8jf41"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-foreigners"
              "chicken-matchable")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "freetype"))
    (synopsis "Freetype2 Interface")
    (home-page "https://wiki.call-cc.org/eggref/5/freetype")
    (description "Freetype2 Interface")
    (license license:bsd-2)))

(define-public
  chicken-unitex-named-chars
  (package
    (name "chicken-unitex-named-chars")
    (version "0.0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "unitex-named-chars" "0.0.4"))
        (sha256
          (base32 "00i7bax8mgw2r8l61iwvircxpynjf2d2yjxlaaa4l4m1mc12bzsv"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-utf8")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "unitex-named-chars"))
    (synopsis "Unicode & LaTeX Named Chars")
    (home-page "https://wiki.call-cc.org/eggref/5/unitex-named-chars")
    (description "Unicode & LaTeX Named Chars")
    (license license:bsd-2)))

(define-public
  chicken-srfi-27
  (package
    (name "chicken-srfi-27")
    (version "4.2.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-27" "4.2.3"))
        (sha256
          (base32 "11hb0hxhm74yjg7d95nj1wxjpi3hgkns7zy64as3xl3jbq3wlh60"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-vector-lib"
              "chicken-timed-resource"
              "chicken-miscmacros"
              "chicken-check-errors")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-27"))
    (synopsis "Sources of Random Bits")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-27")
    (description "Sources of Random Bits")
    (license license:bsd-2)))

(define-public
  chicken-zstd
  (package
    (name "chicken-zstd")
    (version "1.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "zstd" "1.2"))
        (sha256
          (base32 "06gvbk03xbrs5hihrysl2qaf7aag7zk3nvsyaqvfiaa6zg5y80mk"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "zstd"))
    (synopsis "ZStandard bindings")
    (home-page "https://wiki.call-cc.org/eggref/5/zstd")
    (description "ZStandard bindings")
    (license license:bsd-2)))

(define-public
  chicken-x11-colors
  (package
    (name "chicken-x11-colors")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "x11-colors" "1.1"))
        (sha256
          (base32 "1fj8swh4s4gwif2dp59ls0vbdi2d5w50b2q2q00yiyvlr7smm4hs"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-srfi-1" "chicken-srfi-13" "chicken-matchable")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "x11-colors"))
    (synopsis "named standard colors as available in X11")
    (home-page "https://wiki.call-cc.org/eggref/5/x11-colors")
    (description "named standard colors as available in X11")
    (license license:bsd-2)))

(define-public
  chicken-rss
  (package
    (name "chicken-rss")
    (version "1.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "rss" "1.7"))
        (sha256
          (base32 "1xk5v3cz1wvsryd3vkckqz0iw03l4w564y22dq0i5275vvyvb64w"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable" "chicken-srfi-1" "chicken-ssax")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "rss"))
    (synopsis "A RSS parser")
    (home-page "https://wiki.call-cc.org/eggref/5/rss")
    (description "A RSS parser")
    (license license:bsd-2)))

(define-public
  chicken-ssql
  (package
    (name "chicken-ssql")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "ssql" "0.3"))
        (sha256
          (base32 "1ps7kawzhg1yln0pn2jg1ka7nbcpi84k2cl8mnza6nza3g0bplwm"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable" "chicken-srfi-1" "chicken-srfi-13")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "ssql"))
    (synopsis "SQL as S-expressions")
    (home-page "https://wiki.call-cc.org/eggref/5/ssql")
    (description "SQL as S-expressions")
    (license license:bsd-2)))

(define-public
  chicken-pthreads
  (package
    (name "chicken-pthreads")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pthreads" "0.2"))
        (sha256
          (base32 "0972hryj13av238dwp02ich3sdydk4nivrqf3qkp3pvrlalpy5rl"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-18")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pthreads"))
    (synopsis "Maintain and talk to a pthread pool.")
    (home-page "https://wiki.call-cc.org/eggref/5/pthreads")
    (description "Maintain and talk to a pthread pool.")
    (license license:bsd-2)))

(define-public
  chicken-multipart-form-data
  (package
    (name "chicken-multipart-form-data")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "multipart-form-data" "0.2"))
        (sha256
          (base32 "10ik64k5hi7i78nwnc3q9ms49zvn794n6k3imnjr6hhvi9hxy0vy"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-intarweb" "chicken-comparse" "chicken-records")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "multipart-form-data"))
    (synopsis "Reads & decodes HTTP multipart/form-data requests.")
    (home-page "https://wiki.call-cc.org/eggref/5/multipart-form-data")
    (description "Reads & decodes HTTP multipart/form-data requests.")
    (license license:bsd-2)))

(define-public
  chicken-srfi-66
  (package
    (name "chicken-srfi-66")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-66" "0.1"))
        (sha256
          (base32 "0bin3cmgr4r7m3kp6amapqsxaizav3d4alijcfl3q9ahx23di67m"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-66"))
    (synopsis "SRFI-66: Octet Vectors")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-66")
    (description "SRFI-66: Octet Vectors")
    (license license:expat)))

(define-public
  chicken-posix-mq
  (package
    (name "chicken-posix-mq")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "posix-mq" "1.1"))
        (sha256
          (base32 "19la5grxxrlx853kcgnr47987yrrbmh1l5kbs5x6absj45ivzllk"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-compile-file")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "posix-mq"))
    (synopsis "POSIX message queues API")
    (home-page "https://wiki.call-cc.org/eggref/5/posix-mq")
    (description "POSIX message queues API")
    (license license:bsd-2)))

(define-public
  chicken-srfi-64
  (package
    (name "chicken-srfi-64")
    (version "1.0.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-64" "1.0.5"))
        (sha256
          (base32 "0ga9qksagm3fcvg3427w7zhl7g9lbxfb6sb98vl8b0swwz8wz8hr"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-64"))
    (synopsis "SRFI 64:\"A Scheme API for test suites\" implementation")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-64")
    (description "SRFI 64:\"A Scheme API for test suites\" implementation")
    (license license:bsd-1)))

(define-public
  chicken-lalr
  (package
    (name "chicken-lalr")
    (version "2.5.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "lalr" "2.5.2"))
        (sha256
          (base32 "1v4v2xzax7izhl6gnc2lpm8bw2igbp7m4d7n6c2iibm4422mv3nc"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "lalr"))
    (synopsis "An efficient LALR(1) parser generator")
    (home-page "https://wiki.call-cc.org/eggref/5/lalr")
    (description "An efficient LALR(1) parser generator")
    (license license:lgpl3)))

(define-public
  chicken-sha2
  (package
    (name "chicken-sha2")
    (version "4.2.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "sha2" "4.2.5"))
        (sha256
          (base32 "054bjn8wqqxn142cryp0jm18axr237lq9w6gip6hw37y66wpc6h6"))))
    (propagated-inputs
      (specifications->packages (list "chicken-message-digest-primitive")))
    (native-inputs
      (specifications->packages
        (list "chicken-test"
              "chicken-test-utils"
              "chicken-message-digest-primitive"
              "chicken-message-digest-utils"
              "chicken-srfi-1"
              "chicken-srfi-13")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "sha2"))
    (synopsis "Computes 256-, 385- and 512-bit SHA2 checksums")
    (home-page "https://wiki.call-cc.org/eggref/5/sha2")
    (description "Computes 256-, 385- and 512-bit SHA2 checksums")
    (license license:bsd-2)))

(define-public
  chicken-typeclass
  (package
    (name "chicken-typeclass")
    (version "1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "typeclass" "1.5"))
        (sha256
          (base32 "1zpf8dvyh8wfrilvnwmna8223g64brp6pvxpz9gx5vb9nb8yq7jk"))))
    (propagated-inputs
      (specifications->packages (list "chicken-srfi-1" "chicken-matchable")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "typeclass"))
    (synopsis "Type classes")
    (home-page "https://wiki.call-cc.org/eggref/5/typeclass")
    (description "Type classes")
    (license license:expat)))

(define-public
  chicken-advice
  (package
    (name "chicken-advice")
    (version "0.4")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "advice" "0.4"))
        (sha256
          (base32 "0sc9lwkc8pa06v30vhi1srfjsgxn4c4g57zbj6wk1y9adyvda9x7"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "advice"))
    (synopsis "'advise' functionality")
    (home-page "https://wiki.call-cc.org/eggref/5/advice")
    (description "'advise' functionality")
    (license license:bsd-2)))

(define-public
  chicken-thread-utils
  (package
    (name "chicken-thread-utils")
    (version "2.2.8")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "thread-utils" "2.2.8"))
        (sha256
          (base32 "0avr7r6caacmbr3gbb8rp23ddi0g74yz2jc2w2bbhxrqr01vqj0l"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-queues"
              "chicken-srfi-1"
              "chicken-srfi-18"
              "chicken-miscmacros"
              "chicken-moremacros"
              "chicken-record-variants"
              "chicken-check-errors"
              "chicken-synch")))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "thread-utils"))
    (synopsis "Thread Utilities")
    (home-page "https://wiki.call-cc.org/eggref/5/thread-utils")
    (description "Thread Utilities")
    (license license:bsd-2)))

(define-public
  chicken-srfi-94
  (package
    (name "chicken-srfi-94")
    (version "0.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "srfi-94" "0.1"))
        (sha256
          (base32 "1vz8g09csl9jlr0828p9z1p4mxrnlzz0qq4rwkadidcmr9mjfbwp"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-60")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "srfi-94"))
    (synopsis "SRFI 94: Type-Restricted Numerical Functions")
    (home-page "https://wiki.call-cc.org/eggref/5/srfi-94")
    (description "SRFI 94: Type-Restricted Numerical Functions")
    (license license:expat)))

(define-public
  chicken-packrat
  (package
    (name "chicken-packrat")
    (version "1.5")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "packrat" "1.5"))
        (sha256
          (base32 "0d7ly5zvswg07gzm504min730qy16yafz3acyq45smd7q52s47fp"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-1")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "packrat"))
    (synopsis "A packrat parsing library")
    (home-page "https://wiki.call-cc.org/eggref/5/packrat")
    (description "A packrat parsing library")
    (license license:expat)))

(define-public
  chicken-with-current-directory
  (package
    (name "chicken-with-current-directory")
    (version "1.0.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "with-current-directory" "1.0.0"))
        (sha256
          (base32 "1ryl7l2jw5m34fmvv1nr0rf2mwkxrds8xkz7msfzi4gy36i5zja9"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-module-declarations")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "with-current-directory"))
    (synopsis "Convenience procedure for temporarily changing directories")
    (home-page "https://wiki.call-cc.org/eggref/5/with-current-directory")
    (description "Convenience procedure for temporarily changing directories")
    (license license:bsd-2)))

(define-public
  chicken-xj
  (package
    (name "chicken-xj")
    (version "1.29")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "xj" "1.29"))
        (sha256
          (base32 "15a7p9qq33mlxa3h50s142zy9zchpdpkdkx51kfcadh0rbj0x7bi"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-fmt"
              "chicken-html-parser"
              "chicken-srfi-1"
              "chicken-utf8"
              "chicken-brev-separate")))
    (native-inputs (specifications->packages (list "chicken-scsh-process")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "xj"))
    (synopsis "Unix filter that turns XML into JSON")
    (home-page "https://wiki.call-cc.org/eggref/5/xj")
    (description "Unix filter that turns XML into JSON")
    (license license:bsd-3)))

(define-public
  chicken-clucker
  (package
    (name "chicken-clucker")
    (version "0.12")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "clucker" "0.12"))
        (sha256
          (base32 "0b61yfh4m3xigipwjrp476nx1i8xyhwdv1cpyiaz9pfzfhmfd59x"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-oauth" "chicken-uri-common" "chicken-rest-bind")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "clucker"))
    (synopsis "Twitter API for Chicken Scheme")
    (home-page "https://wiki.call-cc.org/eggref/5/clucker")
    (description "Twitter API for Chicken Scheme")
    (license license:bsd-2)))

(define-public
  chicken-mdh
  (package
    (name "chicken-mdh")
    (version "0.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "mdh" "0.2"))
        (sha256
          (base32 "0xkrjq9ng0rxcxllmn9nvjqilkdgmliwaw9pbrgyqsxdi9s9z7z3"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "mdh"))
    (synopsis "interface to the MDH database")
    (home-page "https://wiki.call-cc.org/eggref/5/mdh")
    (description "interface to the MDH database")
    (license license:gpl3)))

(define-public
  chicken-pastiche
  (package
    (name "chicken-pastiche")
    (version "1.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pastiche" "1.3"))
        (sha256
          (base32 "1y5bi6zghymz3k3ynj21by4p6550qc2sk2a2xxgbiifz56pkh786"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-awful"
              "chicken-awful-sql-de-lite"
              "chicken-simple-sha1"
              "chicken-intarweb"
              "chicken-html-parser"
              "chicken-colorize"
              "chicken-miscmacros"
              "chicken-utf8")))
    (native-inputs
      (specifications->packages
        (list "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-http-client"
              "chicken-test"
              "chicken-server-test"
              "chicken-sxpath")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pastiche"))
    (synopsis "A small awful app implementing a pastebin service")
    (home-page "https://wiki.call-cc.org/eggref/5/pastiche")
    (description "A small awful app implementing a pastebin service")
    (license license:bsd-3)))

(define-public
  chicken-salt
  (package
    (name "chicken-salt")
    (version "0.28")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "salt" "0.28"))
        (sha256
          (base32 "17vzsip5xyfqhyrhsrzda0bkqp6pxfday3idrgjqxm5lnm0wbzns"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-datatype"
              "chicken-matchable"
              "chicken-make"
              "chicken-mathh"
              "chicken-lalr"
              "chicken-datatype"
              "chicken-unitconv"
              "chicken-fmt")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "salt"))
    (synopsis "Hybrid dynamical systems modeling.")
    (home-page "https://wiki.call-cc.org/eggref/5/salt")
    (description "Hybrid dynamical systems modeling.")
    (license license:gpl3)))

(define-public
  chicken-accents-substitute
  (package
    (name "chicken-accents-substitute")
    (version "0.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "accents-substitute" "0.7"))
        (sha256
          (base32 "1fbvm18m6ik1x4wn1q226lhv03pvhzgcdzzy4i0xns3c9pyqi7g0"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "accents-substitute"))
    (synopsis "Substitute accented characters in strings")
    (home-page "https://wiki.call-cc.org/eggref/5/accents-substitute")
    (description "Substitute accented characters in strings")
    (license license:bsd-2)))

(define-public
  chicken-nanosleep
  (package
    (name "chicken-nanosleep")
    (version "0.3.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "nanosleep" "0.3.0"))
        (sha256
          (base32 "1nynvd6sv8ffxk0jlvr77mgm0r1rww4c1n5k5m799b36w4gs6df9"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "nanosleep"))
    (synopsis "Interface to POSIX nanosleep")
    (home-page "https://wiki.call-cc.org/eggref/5/nanosleep")
    (description "Interface to POSIX nanosleep")
    (license license:bsd-2)))

(define-public
  chicken-check-errors
  (package
    (name "chicken-check-errors")
    (version "3.8.2")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "check-errors" "3.8.2"))
        (sha256
          (base32 "1xgchkpcmk7cwvbr87xmmwnw7z9ah8r8p6hv7kdkpjy66bas0yhj"))))
    (propagated-inputs (specifications->packages (list)))
    (native-inputs
      (specifications->packages (list "chicken-test" "chicken-test-utils")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "check-errors"))
    (synopsis "Argument checks & errors")
    (home-page "https://wiki.call-cc.org/eggref/5/check-errors")
    (description "Argument checks & errors")
    (license license:bsd-2)))

(define-public
  chicken-espeak
  (package
    (name "chicken-espeak")
    (version "0.1.7")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "espeak" "0.1.7"))
        (sha256
          (base32 "0cd0viivrvjz3qq8v9nrlix2jryghyg338g9ihnc43xsmmgfdcz9"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-utf8" "chicken-foreigners" "chicken-srfi-18")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "espeak"))
    (synopsis "Chicken bindings for espeak-ng's speak_lib.h")
    (home-page "https://wiki.call-cc.org/eggref/5/espeak")
    (description "Chicken bindings for espeak-ng's speak_lib.h")
    (license license:gpl3)))

(define-public
  chicken-pathname-expand
  (package
    (name "chicken-pathname-expand")
    (version "0.3")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "pathname-expand" "0.3"))
        (sha256
          (base32 "1dywjbim23k12fcvdiypq2g5p8wyljgq7zmsvlf8h2anaaq34sm1"))))
    (propagated-inputs (specifications->packages (list "chicken-srfi-13")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "pathname-expand"))
    (synopsis "unknown")
    (home-page "https://wiki.call-cc.org/eggref/5/pathname-expand")
    (description "unknown")
    (license license:bsd-2)))

(define-public
  chicken-live-define
  (package
    (name "chicken-live-define")
    (version "1.1")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "live-define" "1.1"))
        (sha256
          (base32 "07jlsrw0v9d1584zqn6clbyc5qawmibqjnzpn7vb6z65smk4036j"))))
    (propagated-inputs (specifications->packages (list "chicken-matchable")))
    (native-inputs (specifications->packages (list "chicken-test")))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "live-define"))
    (synopsis
      "Hack that replaces “define” with a version that mutates existing procedures.")
    (home-page "https://wiki.call-cc.org/eggref/5/live-define")
    (description
      "Hack that replaces “define” with a version that mutates existing procedures.")
    (license license:public-domain)))

(define-public
  chicken-chicken-doc-admin
  (package
    (name "chicken-chicken-doc-admin")
    (version "0.5.0")
    (source
      (origin
        (method url-fetch)
        (uri (egg-uri "chicken-doc-admin" "0.5.0"))
        (sha256
          (base32 "0jv9809cxhw5qj21w0ja12dqv9qavl3d8084rcd4dn8mia382qmk"))))
    (propagated-inputs
      (specifications->packages
        (list "chicken-matchable"
              "chicken-chicken-doc"
              "chicken-html-parser"
              "chicken-sxml-transforms"
              "chicken-svnwiki-sxml"
              "chicken-srfi-1"
              "chicken-srfi-13"
              "chicken-srfi-69"
              "chicken-regex")))
    (native-inputs (specifications->packages (list)))
    (build-system chicken-build-system)
    (arguments '(#:egg-name "chicken-doc-admin"))
    (synopsis "Administer Chicken documentation locally")
    (home-page "https://wiki.call-cc.org/eggref/5/chicken-doc-admin")
    (description "Administer Chicken documentation locally")
    (license license:bsd-2)))

